@@ -30,7 +30,7 @@ class auth_basic {
     'getUserCount'=> false, // can the number of users be retrieved?
     'getGroups'   => false, // can a list of available groups be retrieved?
     'external'    => false, // does the module do external auth checking?
-    'logoff'      => false, // has the module some special logoff method?
+    'logout'      => true,  // can the user logout again? (eg. not possible with HTTP auth)
   );
 
 
@@ -128,7 +128,7 @@ class auth_basic {
    * only be needed when trustExternal is implemented.
    *
    * @see     auth_logoff()
-   * @author  Andreas Gohr
+   * @author  Andreas Gohr <andi@splitbrain.org>
    */
   function logOff(){
   }
@@ -322,12 +322,58 @@ class auth_basic {
     return array();
   }
 
+  /**
+   * Return case sensitivity of the backend [OPTIONAL]
+   *
+   * When your backend is caseinsensitive (eg. you can login with USER and
+   * user) then you need to overwrite this method and return false
+   */
+  function isCaseSensitive(){
+    return true;
+  }
+
+  /**
+   * Sanitize a given username [OPTIONAL]
+   *
+   * This function is applied to any user name that is given to
+   * the backend and should also be applied to any user name within
+   * the backend before returning it somewhere.
+   *
+   * This should be used to enforce username restrictions.
+   *
+   * @author Andreas Gohr <andi@splitbrain.org>
+   * @param string $user - username
+   * @param string - the cleaned username
+   */
+  function cleanUser($user){
+    return $user;
+  }
+
+  /**
+   * Sanitize a given groupname [OPTIONAL]
+   *
+   * This function is applied to any groupname that is given to
+   * the backend and should also be applied to any groupname within
+   * the backend before returning it somewhere.
+   *
+   * This should be used to enforce groupname restrictions.
+   *
+   * Groupnames are to be passed without a leading '@' here.
+   *
+   * @author Andreas Gohr <andi@splitbrain.org>
+   * @param string $group - groupname
+   * @param string - the cleaned groupname
+   */
+  function cleanGroup($group){
+    return $group;
+  }
+
 
   /**
    * Check Session Cache validity [implement only where required/possible]
    *
    * DokuWiki caches user info in the user's session for the timespan defined
-   * in $conf['securitytimeout'].
+   * in $conf['auth_security_timeout'].
    *
    * This makes sure slow authentication backends do not slow down DokuWiki.
    * This also means that changes to the user database will not be reflected
@@ -354,4 +400,4 @@ class auth_basic {
   }
 
 }
-//Setup VIM: ex: et ts=2 enc=utf-8 :
+//Setup VIM: ex: et ts=2 :
