@@ -4,11 +4,11 @@
  *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author Antono Vasiljev <esperanto.minsk ĈE tut.by>
- * @author Felipe Castro <fefcas CXE yahoo.com.br>
+ * @author Felipe Castro <fefcas@yahoo.com.br>
  * @author Felipe Castro <fefcas@uol.com.br>
  * @author Felipe Castro <fefcas@gmail.com>
- * @author Felipe Castro <fefcas (cxe) gmail (punkto) com>
- * @author Felipo Kastro <fefcas@gmail.com>
+ * @author Robert Bogenschneider <robog@gmx.de>
+ * @author Erik Pedersen <erik.pedersen@shaw.ca>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -41,62 +41,93 @@ $lang['btn_delete']            = 'Forigi';
 $lang['btn_back']              = 'Retroiri';
 $lang['btn_backlink']          = 'Retroligoj';
 $lang['btn_backtomedia']       = 'Retroiri al elekto de dosiero';
-$lang['btn_subscribe']         = 'Aliĝi al Paĝaj Modifoj';
-$lang['btn_unsubscribe']       = 'Malaliĝi al Paĝaj Modifoj';
-$lang['btn_subscribens']       = 'Aliĝi al Nomspacaj Modifoj';
-$lang['btn_unsubscribens']     = 'Malaliĝi al Nomspacaj Modifoj';
+$lang['btn_subscribe']         = 'Aliĝi al paĝaj modifoj';
 $lang['btn_profile']           = 'Ĝisdatigi profilon';
-$lang['btn_reset']             = 'Rekomencigi';
+$lang['btn_reset']             = 'Rekomenci';
 $lang['btn_resendpwd']         = 'Sendi novan pasvorton';
 $lang['btn_draft']             = 'Redakti skizon';
 $lang['btn_recover']           = 'Restarigi skizon';
 $lang['btn_draftdel']          = 'Forigi skizon';
+$lang['btn_revert']            = 'Restarigi';
+$lang['btn_register']          = 'Registriĝi';
 $lang['loggedinas']            = 'Ensalutita kiel';
 $lang['user']                  = 'Uzant-nomo';
 $lang['pass']                  = 'Pasvorto';
 $lang['newpass']               = 'Nova pasvorto';
-$lang['oldpass']               = 'Konfirmu validantan pasvorton';
-$lang['passchk']               = 'pli unu fojo';
+$lang['oldpass']               = 'Konfirmu la nunan pasvorton';
+$lang['passchk']               = 'plian fojon';
 $lang['remember']              = 'Rememoru min';
 $lang['fullname']              = 'Kompleta nomo';
 $lang['email']                 = 'Retpoŝto';
-$lang['register']              = 'Registro';
-$lang['profile']               = 'Profilo de uzanto';
+$lang['profile']               = 'Uzanto-profilo';
 $lang['badlogin']              = 'Pardonu, uzant-nomo aŭ pasvorto estis erara.';
-$lang['minoredit']             = 'Etaj Modifoj';
+$lang['minoredit']             = 'Etaj modifoj';
 $lang['draftdate']             = 'Lasta konservo de la skizo:';
-$lang['nosecedit']             = 'La paĝo ŝanĝis intertempe, sekcio-informo estis malĝisdata, ni ŝargas la tutan paĝon anstataŭe.';
+$lang['nosecedit']             = 'La paĝo ŝanĝiĝis intertempe, sekcio-informo estis malĝisdata, ni ŝargas la tutan paĝon anstataŭe.';
 $lang['regmissing']            = 'Pardonu, vi devas plenigi ĉiujn kampojn.';
-$lang['reguexists']            = 'Pardonu, ĉi tiu uzulnomo jam estas okupita.';
+$lang['reguexists']            = 'Pardonu, ĉi tiu uzanto-nomo jam estas okupita.';
 $lang['regsuccess']            = 'La uzanto estas kreita kaj la pasvorto estis elsendita per retpoŝto.';
 $lang['regsuccess2']           = 'La uzanto estas kreita.';
-$lang['regmailfail']           = 'Ŝajne okazis eraro dum elsendo de la pasvorto. Bonvole informu administranton pri tio!';
-$lang['regbadmail']            = 'Entajpita retpoŝta adreso ne ŝajnas valida. Se vi pensas, ke estas eraro, kontaktu la administranton.';
-$lang['regbadpass']            = 'La du pasvortoj ne interegalas, bonvolu provi refoje.';
-$lang['regpwmail']             = 'Via pasvorto DokuWiki';
-$lang['reghere']               = 'Se vi ne havas konton, do vi povos akiri ĝin';
+$lang['regmailfail']           = 'Ŝajne okazis eraro dum elsendo de la pasvorto. Bonvolu informi administranton pri tio!';
+$lang['regbadmail']            = 'Entajpita retpoŝta adreso ne ŝajnas valida. Se vi pensas, ke tio estas eraro, kontaktu la administranton.';
+$lang['regbadpass']            = 'La du pasvortoj ne samas, bonvolu provi refoje.';
+$lang['regpwmail']             = 'Via DokuWiki-pasvorto';
+$lang['reghere']               = 'Se vi ne havas konton, do vi povas akiri ĝin';
 $lang['profna']                = 'Tiu ĉi vikio ne ebligas modifon en la profiloj.';
 $lang['profnochange']          = 'Neniu ŝanĝo, nenio farinda.';
 $lang['profnoempty']           = 'Malplena nomo aŭ retadreso ne estas permesataj.';
-$lang['profchanged']           = 'La profilo de la uzulo estas sukcese ĝisdatigita.';
+$lang['profchanged']           = 'La profilo de la uzanto estas sukcese ĝisdatigita.';
 $lang['pwdforget']             = 'Ĉu vi forgesis vian pasvorton? Prenu novan';
 $lang['resendna']              = 'Tiu ĉi vikio ne ebligas resendon de la pasvortoj.';
 $lang['resendpwd']             = 'Sendi novan pasvorton al';
 $lang['resendpwdmissing']      = 'Pardonu, vi devas plenigi ĉiujn kampojn.';
-$lang['resendpwdnouser']       = 'Pardonu, ni ne trovas tiun uzulon en nia datenbazo.';
-$lang['resendpwdbadauth']      = 'Pardonu, tiu "aŭtentikiga kodo" ne validas. Certiĝu, ke vi uzis la kompletan konfirmigan ligilon.';
+$lang['resendpwdnouser']       = 'Pardonu, ni ne trovas tiun uzanton en nia datenbazo.';
+$lang['resendpwdbadauth']      = 'Pardonu, tiu aŭtentiga kodo ne validas. Certiĝu, ke vi uzis la kompletan konfirmigan ligilon.';
 $lang['resendpwdconfirm']      = 'Konfirmiga ligilo estas sendita per retpoŝto.';
 $lang['resendpwdsuccess']      = 'Via nova pasvorto estas sendita per retpoŝto.';
 $lang['license']               = 'Krom kie rekte indikite, enhavo de tiu ĉi vikio estas publikigita laŭ la jena permesilo:';
 $lang['licenseok']             = 'Rimarku: redaktante tiun ĉi paĝon vi konsentas publikigi vian enhavon laŭ la jena permesilo:';
+$lang['searchmedia']           = 'Serĉi dosiernomon:';
+$lang['searchmedia_in']        = 'Serĉi en %s';
 $lang['txt_upload']            = 'Elektu dosieron por alŝuto';
 $lang['txt_filename']          = 'Alŝuti kiel (laŭvole)';
 $lang['txt_overwrt']           = 'Anstataŭigi ekzistantan dosieron';
 $lang['lockedby']              = 'Nune ŝlosita de';
 $lang['lockexpire']            = 'Ŝlosado ĉesos en';
 $lang['willexpire']            = 'Vi povos redakti ĉi tiun paĝon post unu minuto.\nSe vi volas nuligi tempkontrolon de la ŝlosado, do premu butonon "Antaŭrigardi".';
-$lang['notsavedyet']           = 'Ne konservitaj modifoj perdiĝos.\nĈu vi certe volas daŭrigi la procezon?';
-$lang['rssfailed']             = 'Okazis eraro dum ricevado de la novaĵ-strio: ';
+$lang['js']['notsavedyet']     = 'Ne konservitaj modifoj perdiĝos.
+Ĉu vi certe volas daŭrigi la procezon?';
+$lang['js']['searchmedia']     = 'Serĉi dosierojn';
+$lang['js']['keepopen']        = 'Tenu la fenestron malfermata dum elekto';
+$lang['js']['hidedetails']     = 'Kaŝi detalojn';
+$lang['js']['mediatitle']      = 'Ligilaj agordoj';
+$lang['js']['mediadisplay']    = 'Ligila tipo';
+$lang['js']['mediaalign']      = 'Poziciigo';
+$lang['js']['mediasize']       = 'Bildgrandeco';
+$lang['js']['mediatarget']     = 'Ligila celo';
+$lang['js']['mediaclose']      = 'Fermi';
+$lang['js']['mediainsert']     = 'Enmeti';
+$lang['js']['mediadisplayimg'] = 'Montri la bildon.';
+$lang['js']['mediadisplaylnk'] = 'Montri nur la ligilon.';
+$lang['js']['mediasmall']      = 'Malgranda versio';
+$lang['js']['mediamedium']     = 'Meza versio';
+$lang['js']['medialarge']      = 'Granda versio';
+$lang['js']['mediaoriginal']   = 'Origina versio';
+$lang['js']['medialnk']        = 'Ligilo al detala paĝo';
+$lang['js']['mediadirect']     = 'Rekta ligilo al la origino';
+$lang['js']['medianolnk']      = 'Neniu ligilo';
+$lang['js']['medianolink']     = 'Ne ligi la bildon';
+$lang['js']['medialeft']       = 'Meti la bildon maldekstren.';
+$lang['js']['mediaright']      = 'Meti la bildon dekstren.';
+$lang['js']['mediacenter']     = 'Meti la bildon mezen.';
+$lang['js']['medianoalign']    = 'Ne uzi poziciigon.';
+$lang['js']['nosmblinks']      = 'Tio ĉi nur funkcias en la Vindozaĉa "Microsoft Internet Explorer".
+Vi ankoraŭ povas kopii kaj almeti la ligilon.';
+$lang['js']['linkwiz']         = 'Ligil-Asistanto';
+$lang['js']['linkto']          = 'Ligilo al:';
+$lang['js']['del_confirm']     = 'Ĉu vere forigi elektitajn ero(j)n?';
+$lang['js']['mu_btn']          = 'Alŝuti plurajn dosierojn multope.';
+$lang['rssfailed']             = 'Okazis eraro dum ricevado de la novaĵ-fluo: ';
 $lang['nothingfound']          = 'Ankoraŭ nenio troviĝas tie ĉi.';
 $lang['mediaselect']           = 'Elekto de aŭdvidaĵa dosiero';
 $lang['fileupload']            = 'Alŝuto de aŭdvidaĵa dosiero';
@@ -113,15 +144,11 @@ $lang['deletefail']            = '"%s" ne povis esti forigita - kontrolu permes-
 $lang['mediainuse']            = 'La dosiero "%s" ne estis forigita - ĝi ankoraŭ estas uzata.';
 $lang['namespaces']            = 'Nomspacoj';
 $lang['mediafiles']            = 'Disponeblaj dosieroj';
-$lang['js']['keepopen']        = 'Tenu la fenestron malfermata dum elekto';
-$lang['js']['hidedetails']     = 'Kaŝi detalojn';
-$lang['js']['nosmblinks']      = 'Tio ĉi nur funkcias en la Vindozaĉa "Microsoft Internet Explorer".
-Vi ankoraŭ povas kopii kaj almeti la ligilon.';
-$lang['js']['mu_btn']          = 'Alŝuti plurajn dosierojn multope.';
+$lang['accessdenied']          = 'Vi ne rajtas vidi tiun paĝon.';
 $lang['mediausage']            = 'Uzu la jenan sintakson por referenci tiun ĉi dosieron:';
 $lang['mediaview']             = 'Rigardi originalan dosieron';
 $lang['mediaroot']             = 'ĉefo (root)';
-$lang['mediaupload']           = 'Alŝutu dosieron al la kuranta nomspaco tie ĉi. Por krei subnomspacojn, antaŭmetu ilin al via "Alŝuti kiel" dosiernomo, apartigante per dupunktoj (:).';
+$lang['mediaupload']           = 'Alŝutu dosieron al la kuranta nomspaco tien ĉi. Por krei subnomspacojn, antaŭmetu ilin al via "Alŝuti kiel" dosiernomo, apartigante per dupunktoj (:).';
 $lang['mediaextchange']        = 'La dosiersufikso ŝanĝis de .%s al .%s!';
 $lang['reference']             = 'Referencoj por';
 $lang['ref_inuse']             = 'La dosiero ne povas esti forigita, ĉar ĝi ankoraŭ estas uzata de la jenaj paĝoj:';
@@ -133,9 +160,13 @@ $lang['current']               = 'aktuala';
 $lang['yours']                 = 'Via Versio';
 $lang['diff']                  = 'Montri diferencojn el la aktuala versio';
 $lang['diff2']                 = 'Montri diferencojn inter la elektitaj revizioj';
+$lang['difflink']              = 'Ligilo al kompara rigardo';
+$lang['diff_type']             = 'Rigardi malsamojn:';
+$lang['diff_inline']           = 'Samlinie';
+$lang['diff_side']             = 'Apude';
 $lang['line']                  = 'Linio';
 $lang['breadcrumb']            = 'Paŝoj';
-$lang['youarehere']            = 'Vi ĉi tie';
+$lang['youarehere']            = 'Vi estas ĉi tie';
 $lang['lastmod']               = 'Lastaj ŝanĝoj';
 $lang['by']                    = 'de';
 $lang['deleted']               = 'forigita';
@@ -144,21 +175,27 @@ $lang['restored']              = 'malnova revizio restarigita';
 $lang['external_edit']         = 'ekstera redakto';
 $lang['summary']               = 'Bulteno de ŝanĝoj';
 $lang['noflash']               = 'La <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> estas bezonata por montrigi tiun ĉi enhavon.';
+$lang['download']              = 'Elŝuti eltiraĵon';
 $lang['mail_newpage']          = 'paĝo aldonita:';
 $lang['mail_changed']          = 'paĝo modifita:';
+$lang['mail_subscribe_list']   = 'ŝanĝitaj paĝoj en nomspaco:';
 $lang['mail_new_user']         = 'Nova uzanto:';
 $lang['mail_upload']           = 'dosiero alŝutita:';
-$lang['qb_alert']              = 'Bonvolu enskribi formatotan tekston.\nĜi estos aldonita ĉe la fino de la dokumento.';
-$lang['qb_bold']               = 'Dika Teksto';
-$lang['qb_italic']             = 'Dekliva Teksto';
-$lang['qb_underl']             = 'Substrekita Teksto';
-$lang['qb_code']               = 'Koduma Teksto';
-$lang['qb_strike']             = 'Trastrekita Teksto';
+$lang['qb_bold']               = 'Dika teksto';
+$lang['qb_italic']             = 'Dekliva teksto';
+$lang['qb_underl']             = 'Substrekita teksto';
+$lang['qb_code']               = 'Koduma teksto';
+$lang['qb_strike']             = 'Trastrekita teksto';
 $lang['qb_h1']                 = 'Titolo de 1-a nivelo';
 $lang['qb_h2']                 = 'Titolo de 2-a nivelo';
 $lang['qb_h3']                 = 'Titolo de 3-a nivelo';
 $lang['qb_h4']                 = 'Titolo de 4-a nivelo';
 $lang['qb_h5']                 = 'Titolo de 5-a nivelo';
+$lang['qb_h']                  = 'Ĉeftitolo';
+$lang['qb_hs']                 = 'Elektu ĉeftitolon';
+$lang['qb_hplus']              = 'Altnivela titolo';
+$lang['qb_hminus']             = 'Subnivela titolo';
+$lang['qb_hequal']             = 'Samnivela titolo';
 $lang['qb_link']               = 'Interna ligilo';
 $lang['qb_extlink']            = 'Ekstera ligilo';
 $lang['qb_hr']                 = 'Horizontala streko';
@@ -168,11 +205,11 @@ $lang['qb_media']              = 'Aldoni bildojn kaj aliajn dosierojn';
 $lang['qb_sig']                = 'Inkluzivi subskribon';
 $lang['qb_smileys']            = 'Ridetuloj';
 $lang['qb_chars']              = 'Specialaj signaĵoj';
-$lang['del_confirm']           = 'Ĉu vere forigi elektitajn ero(j)n?';
-$lang['admin_register']        = 'Aldoni novan uzulon';
+$lang['upperns']               = 'saltu al la parenca nomspaco';
+$lang['admin_register']        = 'Aldoni novan uzanton';
 $lang['metaedit']              = 'Redakti metadatenaron';
 $lang['metasaveerr']           = 'La konservo de metadatenaro malsukcesis';
-$lang['metasaveok']            = 'La metadatenaron estis konservita';
+$lang['metasaveok']            = 'La metadatenaro estis konservita';
 $lang['img_backto']            = 'Retroiri al';
 $lang['img_title']             = 'Titolo';
 $lang['img_caption']           = 'Priskribo';
@@ -183,36 +220,48 @@ $lang['img_artist']            = 'Fotisto';
 $lang['img_copyr']             = 'Kopirajtoj';
 $lang['img_format']            = 'Formato';
 $lang['img_camera']            = 'Kamerao';
-$lang['img_keywords']          = 'Ĉefvortoj';
-$lang['subscribe_success']     = '%s estis aldonita al dissendolisto por %s';
-$lang['subscribe_error']       = 'Estas eraro je aldono de %s al dissendolisto por %s';
-$lang['subscribe_noaddress']   = 'Estas neniu retadreso asociita al via identiĝ-nomo, do vi ne povas esti aldonata al la dissendolisto.';
-$lang['unsubscribe_success']   = '%s estas forigita de la dissendolisto por %s';
-$lang['unsubscribe_error']     = 'Estas eraro je forigo de %s el dissendolisto por %s';
-$lang['authmodfailed']         = 'Malbona agordo por identigi la uzulon. Bonvolu informi la administranton de la vikio.';
-$lang['authtempfail']          = 'La identigo de via uzulnomo estas intertempe maldisponebla. Se tiu ĉi situacio daŭros, bonvolu informi al la adminstranto de la vikio.';
+$lang['img_keywords']          = 'Ŝlosilvortoj';
+$lang['subscr_subscribe_success'] = 'Aldonis %s al la abonlisto por %s';
+$lang['subscr_subscribe_error'] = 'Eraro dum aldono de %s al la abonlisto por %s';
+$lang['subscr_subscribe_noaddress'] = 'Ne estas adreso ligita al via ensaluto, ne eblas aldoni vin al la abonlisto';
+$lang['subscr_unsubscribe_success'] = 'Forigis %s de la abonlisto por %s';
+$lang['subscr_unsubscribe_error'] = 'Eraro dum forigo de %s de la abonlisto por %s';
+$lang['subscr_already_subscribed'] = '%s jam estas abonanta al %s';
+$lang['subscr_not_subscribed'] = '%s ne abonas al %s';
+$lang['subscr_m_not_subscribed'] = 'Momente vi ne abonas la aktualan paĝon aŭ nomspacon.';
+$lang['subscr_m_new_header']   = 'Aldoni abonon';
+$lang['subscr_m_current_header'] = 'Momentaj abonoj';
+$lang['subscr_m_unsubscribe']  = 'Malaboni';
+$lang['subscr_m_subscribe']    = 'Aboni';
+$lang['subscr_m_receive']      = 'Ricevi';
+$lang['subscr_style_every']    = 'retpoŝtaĵo pro ĉiu ŝanĝo';
+$lang['subscr_style_digest']   = 'kolekta retpoŝtaĵo de ŝanĝoj por ĉiu paĝo';
+$lang['subscr_style_list']     = 'listo de ŝanĝitaj paĝoj ekde la lasta retpoŝtaĵo';
+$lang['authmodfailed']         = 'Malbona agordo por identigi la uzanton. Bonvolu informi la administranton de la vikio.';
+$lang['authtempfail']          = 'La identigo de via uzantonomo estas intertempe maldisponebla. Se tiu ĉi situacio daŭros, bonvolu informi la adminstranton de la vikio.';
 $lang['i_chooselang']          = 'Elektu vian lingvon';
 $lang['i_installer']           = 'Instalilo de DokuWiki';
 $lang['i_wikiname']            = 'Nomo de la vikio';
-$lang['i_enableacl']           = 'Ebligi "ACL" (rekomendinde)';
+$lang['i_enableacl']           = 'Ebligi "ACL" (alirkontrolo, rekomendinde)';
 $lang['i_superuser']           = 'Superuzanto';
-$lang['i_problems']            = 'La instalilo trovis kelkajn problemojn, indikitaj sube. Vi ne povas pluiri ĝis ili estu iel korektitaj.';
-$lang['i_modified']            = 'Por sekureco tiu ĉi instalilo nur funkcias por nova kaj nemodifita Dokuwiki-pakaĵo.
+$lang['i_problems']            = 'La instalilo trovis kelkajn problemojn, indikitaj sube. Vi ne povas pluiri ĝis ili estos iel korektitaj.';
+$lang['i_modified']            = 'Pro sekureco tiu ĉi instalilo nur funkcias por nova kaj nemodifita Dokuwiki-pakaĵo.
 Vi devas aŭ redemeti la dosierojn el la elŝutita pakaĵo aŭ plibone informiĝi pri la instalada procezo.';
-$lang['i_funcna']              = 'La PHP-a funkcio <code>%s</code> ne estas uzebla. Eble via retprovizanto ial malpermesis tion, ĉu ne?';
+$lang['i_funcna']              = 'La PHP-a funkcio <code>%s</code> ne estas uzebla. Eble via retprovizanto ial malpermesis tion?';
 $lang['i_phpver']              = 'La versio de la PHP <code>%s</code> estas pli malnova ol la bezonata <code>%s</code>. Vi bezonas ĝisdatigi la PHP-an instalon.';
 $lang['i_permfail']            = '<code>%s</code> ne estas skribebla por DokuWiki. Vi devas redifini la permes-atributojn de tiu ĉi dosierujo!';
 $lang['i_confexists']          = '<code>%s</code> jam ekzistas';
-$lang['i_writeerr']            = 'Ne eblas krei "<code>%s</code>"-on. Vi bezonas kontroli la permesojn de la dosir(uj)oj kaj mem krej la dosieron.';
+$lang['i_writeerr']            = 'Ne eblas krei "<code>%s</code>"-on. Vi bezonas kontroli la permesojn de la dosier(uj)oj kaj mem krej la dosieron.';
 $lang['i_badhash']             = 'dokuwiki.php ne estas rekonebla aŭ ĝi estas modifita (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - malvalida aŭ malplena valoro';
 $lang['i_success']             = 'La agordado estas sukcese kompletita. Vi povas forigi la dosieron nun. Pluiru al <a href="doku.php">via nova DokuWiki</a>.';
 $lang['i_failure']             = 'Kelkaj eraroj okazis dum la konservo de la agordaj dosieroj. Vi devas senpere korekti ilin antaŭ ol vi povos uzi <a href="doku.php">vian novan DokuWiki-on</a>.                       ';
 $lang['i_policy']              = 'Apriora ACL-a agordo';
 $lang['i_pol0']                = 'Malferma Vikio (legi, skribi, alŝuti povas ĉiuj)';
-$lang['i_pol1']                = 'Publika Vikio (legi povas ĉiuj, skribi kaj alŝuti povas registritaj uzuloj)';
-$lang['i_pol2']                = 'Ferma Vikio (legi, skribi, alŝuti nur povas registritaj uzuloj)';
+$lang['i_pol1']                = 'Publika Vikio (legi povas ĉiuj, skribi kaj alŝuti povas registritaj uzantoj)';
+$lang['i_pol2']                = 'Ferma Vikio (legi, skribi, alŝuti nur povas registritaj uzantoj)';
 $lang['i_retry']               = 'Reprovi';
+$lang['i_license']             = 'Bonvolu elekti la permesilon, sub kiun vi volas meti vian enhavon:';
 $lang['mu_intro']              = 'Ĉi tie vi povas alŝuti plurajn dosierojn multope. Klaku la esplor-butonon por aldoni ilin al la vico. Premu alŝuti kiam prete.';
 $lang['mu_gridname']           = 'Dosiernomo';
 $lang['mu_gridsize']           = 'Grandeco';
@@ -220,10 +269,20 @@ $lang['mu_gridstat']           = 'Stato';
 $lang['mu_namespace']          = 'Nomspaco';
 $lang['mu_browse']             = 'Esplori';
 $lang['mu_toobig']             = 'tro granda';
-$lang['mu_ready']              = 'prete por alŝuti';
+$lang['mu_ready']              = 'preta por alŝuti';
 $lang['mu_done']               = 'plenumite';
-$lang['mu_fail']               = 'malsukcesite';
+$lang['mu_fail']               = 'malsukcesinte';
 $lang['mu_authfail']           = 'sekcio tro longdaŭris';
 $lang['mu_progress']           = '@PCT@% alŝutite';
-$lang['mu_filetypes']          = 'Permesitaj Dosiertipoj';
-$lang['recent_global']         = 'Vi nune rigardas la ŝanĝojn ene de la nomspaco <b>%s</b>. Vi povas ankaŭ <a href="%s">vidi la freŝajn ŝanĝojn de la tuta vikio</a>.';
+$lang['mu_filetypes']          = 'Permesitaj dosiertipoj';
+$lang['mu_info']               = 'alŝutitaj dosieroj.';
+$lang['mu_lasterr']            = 'Lasta eraro:';
+$lang['recent_global']         = 'Vi nun rigardas la ŝanĝojn ene de la nomspaco <b>%s</b>. Vi povas ankaŭ <a href="%s">vidi la freŝajn ŝanĝojn de la tuta vikio</a>.';
+$lang['years']                 = 'antaŭ %d jaroj';
+$lang['months']                = 'antaŭ %d monatoj';
+$lang['weeks']                 = 'antaŭ %d semajnoj';
+$lang['days']                  = 'antaŭ %d tagoj';
+$lang['hours']                 = 'antaŭ %d horoj';
+$lang['minutes']               = 'antaŭ %d minutoj';
+$lang['seconds']               = 'antaŭ %d sekundoj';
+$lang['wordblock']             = 'Via ŝanĝo ne estis savita, ĉar ĝi enhavas blokitan tekston (spamon).';
