@@ -38,15 +38,14 @@ $lang['btn_back']              = 'Atzera';
 $lang['btn_backlink']          = 'Itzulera estekak';
 $lang['btn_backtomedia']       = 'Atzera Multimedia Fitxategiaren Aukeraketara';
 $lang['btn_subscribe']         = 'Harpidetu Orri Aldaketetara';
-$lang['btn_unsubscribe']       = 'Utzi Harpidetza Orri Aldaketetara';
-$lang['btn_subscribens']       = 'Harpidetu Izen-espazio Aldaketetara';
-$lang['btn_unsubscribens']     = 'Utzi Harpidetza Izen-espazio Aldaketetara';
 $lang['btn_profile']           = 'Eguneratu Profila ';
 $lang['btn_reset']             = 'Aldaketak Desegin';
 $lang['btn_resendpwd']         = 'Pasahitz berria bidali';
 $lang['btn_draft']             = 'Editatu zirriborroa';
 $lang['btn_recover']           = 'Berreskuratu zirriborroa';
 $lang['btn_draftdel']          = 'Ezabatu zirriborroa';
+$lang['btn_revert']            = 'Berrezarri';
+$lang['btn_register']          = 'Erregistratu';
 $lang['loggedinas']            = 'Erabiltzailea';
 $lang['user']                  = 'Erabiltzailea';
 $lang['pass']                  = 'Pasahitza';
@@ -56,7 +55,6 @@ $lang['passchk']               = 'berriz';
 $lang['remember']              = 'Gogoratu';
 $lang['fullname']              = 'Izen Deiturak';
 $lang['email']                 = 'E-Maila';
-$lang['register']              = 'Erregistratu';
 $lang['profile']               = 'Erabiltzaile Profila';
 $lang['badlogin']              = 'Barkatu, prozesuak huts egin du; saiatu berriz';
 $lang['minoredit']             = 'Aldaketa Txikiak';
@@ -85,13 +83,46 @@ $lang['resendpwdconfirm']      = 'Baieztapen esteka bat e-postaz bidali da.';
 $lang['resendpwdsuccess']      = 'Zure pasahitz berria e-postaz bidali da.';
 $lang['license']               = 'Besterik esan ezean, wiki hontako edukia ondorengo lizentziapean argitaratzen da:';
 $lang['licenseok']             = 'Oharra: Orri hau editatzean, zure edukia ondorengo lizentziapean argitaratzea onartzen duzu: ';
+$lang['searchmedia']           = 'Bilatu fitxategi izena:';
+$lang['searchmedia_in']        = 'Bilatu %s-n';
 $lang['txt_upload']            = 'Ireki nahi den fitxategia aukeratu';
 $lang['txt_filename']          = 'Idatzi wikiname-a (aukerazkoa)';
 $lang['txt_overwrt']           = 'Oraingo fitxategiaren gainean idatzi';
 $lang['lockedby']              = 'Momentu honetan blokeatzen:';
 $lang['lockexpire']            = 'Blokeaketa iraungitzen da:';
 $lang['willexpire']            = 'Zure blokeaketa orri hau aldatzeko minutu batean iraungitzen da.\nGatazkak saihesteko, aurreikusi botoia erabili blokeaketa denboragailua berrabiarazteko.';
-$lang['notsavedyet']           = 'Gorde gabeko aldaketak galdu egingo dira.\nBenetan jarraitu nahi duzu?';
+$lang['js']['notsavedyet']     = 'Gorde gabeko aldaketak galdu egingo dira.
+Benetan jarraitu nahi duzu?';
+$lang['js']['searchmedia']     = 'Bilatu fitxategiak';
+$lang['js']['keepopen']        = 'Mantendu leihoa irekita aukeraketan';
+$lang['js']['hidedetails']     = 'Xehetasunak Ezkutatu';
+$lang['js']['mediatitle']      = 'Esteken ezarpenak';
+$lang['js']['mediadisplay']    = 'Esteka mota';
+$lang['js']['mediaalign']      = 'Lerrokatzea';
+$lang['js']['mediasize']       = 'Irudi tamaina';
+$lang['js']['mediatarget']     = 'Estekaren helburua';
+$lang['js']['mediaclose']      = 'Itxi';
+$lang['js']['mediainsert']     = 'Txertatu';
+$lang['js']['mediadisplayimg'] = 'Irudia erakutsi';
+$lang['js']['mediadisplaylnk'] = 'Esteka bakarrik erakutsi';
+$lang['js']['mediasmall']      = 'Bertsio txikia';
+$lang['js']['mediamedium']     = 'Bertsio ertaina';
+$lang['js']['medialarge']      = 'Bertsio handia';
+$lang['js']['mediaoriginal']   = 'Jatorrizko bertsioa';
+$lang['js']['medialnk']        = 'Esteka xehetasunen orrira';
+$lang['js']['mediadirect']     = 'Jatorrizkora esteka zuzena';
+$lang['js']['medianolnk']      = 'Estekarik ez';
+$lang['js']['medianolink']     = 'Ez estekatu irudia';
+$lang['js']['medialeft']       = 'Irudia ezkerrean lerrokatu';
+$lang['js']['mediaright']      = 'Irudia eskuinean lerrokatu';
+$lang['js']['mediacenter']     = 'Irudia erdian lerrokatu';
+$lang['js']['medianoalign']    = 'Ez erabili lerrokatzerik';
+$lang['js']['nosmblinks']      = 'Window baliabide konpartituetara estekek Microsoft Internet Explorer-en bakarrik balio dute.
+Esteka kopiatu eta itsatsi dezakezu dena den.';
+$lang['js']['linkwiz']         = 'Estekatze Laguntzailea';
+$lang['js']['linkto']          = 'Estekatu hona:';
+$lang['js']['del_confirm']     = 'Benetan ezabatu aukeratutako fitxategia(k)?';
+$lang['js']['mu_btn']          = 'Igo hainbat fitxategi aldi berean';
 $lang['rssfailed']             = 'Errorea gertatu da feed hau irakurtzean:';
 $lang['nothingfound']          = 'Ez da ezer aurkitu.';
 $lang['mediaselect']           = 'Aukeratu Multimedia fitxategia';
@@ -109,11 +140,7 @@ $lang['deletefail']            = 'Ezin izan da "%s" ezabatu - egiaztatu baimenak
 $lang['mediainuse']            = 'Ez da "%s" fitxategia ezabatu - oraindik erabilia izaten ari da.';
 $lang['namespaces']            = 'Izen-espazioak';
 $lang['mediafiles']            = 'Fitxategiak eskuragarri hemen:';
-$lang['js']['keepopen']        = 'Mantendu leihoa irekita aukeraketan';
-$lang['js']['hidedetails']     = 'Xehetasunak Ezkutatu';
-$lang['js']['nosmblinks']      = 'Window baliabide konpartituetara estekek Microsoft Internet Explorer-en bakarrik balio dute.
-Esteka kopiatu eta itsatsi dezakezu dena den.';
-$lang['js']['mu_btn']          = 'Igo hainbat fitxategi aldi berean';
+$lang['accessdenied']          = 'Ez zaude orri hau ikusteko baimendua';
 $lang['mediausage']            = 'Erabili ondoko sintaxia fitxategi honi erreferentzia egiteko:';
 $lang['mediaview']             = 'Ikusi jatorrizko fitxategia';
 $lang['mediaroot']             = 'root';
@@ -129,6 +156,10 @@ $lang['current']               = 'egungoa';
 $lang['yours']                 = 'Zure Bertsioa';
 $lang['diff']                  = 'egungo bertsioarekin dituen aldaketak aurkezten ditu';
 $lang['diff2']                 = 'Erakutsi desberdintasunak aukeratutako bertsioen artean';
+$lang['difflink']              = 'Estekatu konparaketa bista honetara';
+$lang['diff_type']             = 'Ikusi diferentziak:';
+$lang['diff_inline']           = 'Lerro tartean';
+$lang['diff_side']             = 'Ondoz ondo';
 $lang['line']                  = 'Marra';
 $lang['breadcrumb']            = 'Traza';
 $lang['youarehere']            = 'Hemen zaude';
@@ -140,11 +171,12 @@ $lang['restored']              = 'bertsio zaharra berrezarria';
 $lang['external_edit']         = 'kanpoko aldaketa';
 $lang['summary']               = 'Aldatu laburpena';
 $lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> beharrezkoa da eduki hau bistaratzeko.';
+$lang['download']              = 'Deskarga Snippet-a';
 $lang['mail_newpage']          = '[DokuWiki] gehitutako orria:';
 $lang['mail_changed']          = '[DokuWiki] aldatutako orria:';
+$lang['mail_subscribe_list']   = 'izen-espazioan aldatutako orriak:';
 $lang['mail_new_user']         = 'erabiltzaile berria:';
 $lang['mail_upload']           = 'fitxategia igota:';
-$lang['qb_alert']              = 'Mesedez, sartu formatua eman nahi diozun testua.\nDokumentuaren bukaeran txertatuko da.';
 $lang['qb_bold']               = 'Letra beltzez';
 $lang['qb_italic']             = 'Letra italiarrez';
 $lang['qb_underl']             = 'Azpimarratua';
@@ -155,6 +187,11 @@ $lang['qb_h2']                 = 'Izenburua 2';
 $lang['qb_h3']                 = 'Izenburua 3';
 $lang['qb_h4']                 = 'Izenburua 4';
 $lang['qb_h5']                 = 'Izenburua 5';
+$lang['qb_h']                  = 'Izenburua';
+$lang['qb_hs']                 = 'Izenburua Aukeratu';
+$lang['qb_hplus']              = 'Izenburu Handiagoa';
+$lang['qb_hminus']             = 'Izenburu Txikiagoa';
+$lang['qb_hequal']             = 'Maila Berdineko Izenburua';
 $lang['qb_link']               = 'Barruko Lotura';
 $lang['qb_extlink']            = 'Kanpoko Lotura';
 $lang['qb_hr']                 = 'Horizontal Marra';
@@ -164,7 +201,7 @@ $lang['qb_media']              = 'Irudiak eta beste fitxategiak gehitu';
 $lang['qb_sig']                = 'Gehitu sinadura';
 $lang['qb_smileys']            = 'Irrifartxoak';
 $lang['qb_chars']              = 'Karaktere Bereziak';
-$lang['del_confirm']           = 'Benetan ezabatu aukeratutako fitxategia(k)?';
+$lang['upperns']               = 'Jauzi izen-espazio gurasora';
 $lang['admin_register']        = 'Erabiltzaile berria gehitu';
 $lang['metaedit']              = 'Metadatua Aldatu';
 $lang['metasaveerr']           = 'Metadatuaren idazketak huts egin du';
@@ -180,11 +217,22 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Formatua';
 $lang['img_camera']            = 'Kamera';
 $lang['img_keywords']          = 'Hitz-gakoak';
-$lang['subscribe_success']     = 'Gehitua %s %s harpidetza zerrendara';
-$lang['subscribe_error']       = 'Errorea %s gehitzen %s harpidetza zerrendara';
-$lang['subscribe_noaddress']   = 'Ez dago posta elektroniko helbiderik zure erabiltzaile izenarekin erlazionatuta, ezin zara harpidetza zerrendara gehitua izan';
-$lang['unsubscribe_success']   = 'Ezabatua %s %s harpidetza zerrendatik';
-$lang['unsubscribe_error']     = 'Errorea %s ezabatzen %s harpidetza zerrendatik';
+$lang['subscr_subscribe_success'] = '%s gehitua %s-ren harpidetza zerrendara';
+$lang['subscr_subscribe_error'] = 'Errorea %s gehitzen %s-ren harpidetza zerrendara';
+$lang['subscr_subscribe_noaddress'] = 'Ez dago helbiderik zure login-arekin lotuta, ezin zara harpidetza zerrendara gehitua izan.';
+$lang['subscr_unsubscribe_success'] = '%s ezabatua %s-ren harpidetza zerrendatik';
+$lang['subscr_unsubscribe_error'] = 'Errorea %s ezabatzen %s-ren harpidetza zerrendatik';
+$lang['subscr_already_subscribed'] = '%s lehendik harpidetua dago %s-n';
+$lang['subscr_not_subscribed'] = '%s ez dago %s-n harpidetua';
+$lang['subscr_m_not_subscribed'] = 'Momentu honetan ez zaude orri honetara edo izen-espazio honetara harpidetua.';
+$lang['subscr_m_new_header']   = 'Gehitu harpidetza';
+$lang['subscr_m_current_header'] = 'Uneko harpidetzak';
+$lang['subscr_m_unsubscribe']  = 'Kendu harpidetza';
+$lang['subscr_m_subscribe']    = 'Harpidetu';
+$lang['subscr_m_receive']      = 'Jaso';
+$lang['subscr_style_every']    = 'e-posta aldaketa bakoitzean';
+$lang['subscr_style_digest']   = 'e-posta laburbildua orri bakoitzeko aldaketentzat (%.2f egunero)';
+$lang['subscr_style_list']     = 'aldatutako orrien zerrenda azken e-postatik (%.2f egunero)';
 $lang['authmodfailed']         = 'Erabiltzaile kautotzearen konfigurazioa okerra da. Mesedez, eman honen berri Wiki administratzaileari';
 $lang['authtempfail']          = 'Erabiltzaile kautotzea denboraldi batez ez dago erabilgarri. Egoerak hala jarraitzen badu, mesedez, eman honen berri Wiki administratzaileari';
 $lang['i_chooselang']          = 'Hautatu zure hizkuntza';
@@ -208,6 +256,7 @@ $lang['i_pol0']                = 'Wiki Irekia (irakurri, idatzi, fitxategiak igo
 $lang['i_pol1']                = 'Wiki Publikoa (irakurri edonorentzat, idatzi eta fitxategiak igo erregistratutako erabiltzaileentzat)';
 $lang['i_pol2']                = 'Wiki Itxia (irakurri, idatzi, fitxategiak igo erregistratutako erabiltzaileentzat soilik)';
 $lang['i_retry']               = 'Berriz saiatu';
+$lang['i_license']             = 'Mesedez, aukeratu zein lizentzipean ezarri nahi duzun zure edukia:';
 $lang['mu_intro']              = 'Hemen hainbat fitxategi aldi berean igo ditzakezu. Egin klik nabigazio botoian hauek ilarara gehitzeko. Sakatu igo botoia prest egotean.';
 $lang['mu_gridname']           = 'Fitxategi izena';
 $lang['mu_gridsize']           = 'Tamaina';
@@ -221,4 +270,14 @@ $lang['mu_fail']               = 'hutsegitea';
 $lang['mu_authfail']           = 'saioa iraungita';
 $lang['mu_progress']           = '@PCT@% igota';
 $lang['mu_filetypes']          = 'Onartutako Fitxategi Motak';
+$lang['mu_info']               = 'igotako fitxategiak.';
+$lang['mu_lasterr']            = 'Azken errorea;';
 $lang['recent_global']         = 'Une honetan <b>%s</b> izen-espazioaren barneko aldaketak ikusten ari zara.<a href="%s"> Wiki osoaren azken aldaketak</a> ere ikusi ditzakezu.';
+$lang['years']                 = 'duela %d urte';
+$lang['months']                = 'duela %d hilabete';
+$lang['weeks']                 = 'duela %d aste';
+$lang['days']                  = 'duela %d egun';
+$lang['hours']                 = 'duela %d ordu';
+$lang['minutes']               = 'duela %d minutu';
+$lang['seconds']               = 'duela %d segundu';
+$lang['wordblock']             = 'Zure aldaketa ez da aldatua izan blokeatutako testua (spam) daukalako.';
