@@ -5,7 +5,10 @@
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author Ziegler Gábor <gziegler@freemail.hu>
  * @author Sandor TIHANYI <stihanyi+dw@gmail.com>
- * @author Siaynoq Siaynoq <siaynoqmage@gmail.com>
+ * @author Siaynoq Mage <siaynoqmage@gmail.com>
+ * @author schilling.janos@gmail.com
+ * @author Szabó Dávid <szabo.david@gyumolcstarhely.hu>
+ * @author Sándor TIHANYI <stihanyi+dw@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -39,15 +42,14 @@ $lang['btn_back']              = 'Vissza';
 $lang['btn_backlink']          = 'Hivatkozások';
 $lang['btn_backtomedia']       = 'Vissza a médiafájlok kezeléséhez';
 $lang['btn_subscribe']         = 'Oldalváltozások-hírlevél feliratkozás';
-$lang['btn_unsubscribe']       = 'Oldalváltozások-hírlevél leiratkozás';
-$lang['btn_subscribens']       = 'Névtér-változás hírlevél feliratkozás';
-$lang['btn_unsubscribens']     = 'Névtér-változás hírlevél leiratkozás';
 $lang['btn_profile']           = 'Személyes beállítások';
 $lang['btn_reset']             = 'Alaphelyzet';
 $lang['btn_resendpwd']         = 'Új jelszó küldése';
 $lang['btn_draft']             = 'Piszkozat szerkesztése';
 $lang['btn_recover']           = 'Piszkozat folytatása';
 $lang['btn_draftdel']          = 'Piszkozat törlése';
+$lang['btn_revert']            = 'Helyreállítás';
+$lang['btn_register']          = 'Regisztráció';
 $lang['loggedinas']            = 'Belépett felhasználó: ';
 $lang['user']                  = 'Azonosító';
 $lang['pass']                  = 'Jelszó';
@@ -57,7 +59,6 @@ $lang['passchk']               = 'még egyszer';
 $lang['remember']              = 'Emlékezz rám';
 $lang['fullname']              = 'Teljes név';
 $lang['email']                 = 'E-Mail';
-$lang['register']              = 'Regisztráció';
 $lang['profile']               = 'Személyes beállítások';
 $lang['badlogin']              = 'Sajnáljuk, az azonosító, vagy a jelszó nem jó.';
 $lang['minoredit']             = 'Apróbb változások';
@@ -86,13 +87,46 @@ $lang['resendpwdconfirm']      = 'A megerősítés linket e-mailben elküldtük.
 $lang['resendpwdsuccess']      = 'Az új jelszavadat elküldtük e-mailben.';
 $lang['license']               = 'Hacsak máshol nincs egyéb rendelkezés, ezen wiki tartalma a következő licenc alatt érhető el:';
 $lang['licenseok']             = 'Megjegyzés: az oldal szerkesztésével elfogadja, hogy a tartalom a következő licenc alatt lesz elérhető:';
+$lang['searchmedia']           = 'Keresett fájl neve:';
+$lang['searchmedia_in']        = 'Keresés a következőben: %s';
 $lang['txt_upload']            = 'Válaszd ki a feltöltendő fájlt';
 $lang['txt_filename']          = 'feltöltési név (elhagyható)';
 $lang['txt_overwrt']           = 'Létező fájl felülírása';
 $lang['lockedby']              = 'Jelenleg zárolta:';
 $lang['lockexpire']            = 'A zárolás lejár:';
 $lang['willexpire']            = 'Az oldalszerkesztési zárolásod körülbelül egy percen belül lejár.\nAz ütközések elkerülése végett használd az előnézet gombot a zárolási időzítés frissítéséhez.';
-$lang['notsavedyet']           = 'Elmentetlen változások vannak, amelyek el fognak veszni.\nTényleg ezt akarod?';
+$lang['js']['notsavedyet']     = 'Elmentetlen változások vannak, amelyek el fognak veszni.
+Tényleg ezt akarod?';
+$lang['js']['searchmedia']     = 'Fájlok keresése';
+$lang['js']['keepopen']        = 'Tartsd nyitva ezt az ablakot a kijelöléshez!';
+$lang['js']['hidedetails']     = 'Részletek elrejtése';
+$lang['js']['mediatitle']      = 'Link beállítások';
+$lang['js']['mediadisplay']    = 'Link típusa';
+$lang['js']['mediaalign']      = 'Igazítás';
+$lang['js']['mediasize']       = 'Képméret';
+$lang['js']['mediatarget']     = 'Link';
+$lang['js']['mediaclose']      = 'Bezárás';
+$lang['js']['mediainsert']     = 'Beillesztés';
+$lang['js']['mediadisplayimg'] = 'Kép megtekintése.';
+$lang['js']['mediadisplaylnk'] = 'Link megtekintése.';
+$lang['js']['mediasmall']      = 'Kisebb méret';
+$lang['js']['mediamedium']     = 'Közepes méret';
+$lang['js']['medialarge']      = 'Nagyobb méret';
+$lang['js']['mediaoriginal']   = 'Eredeti';
+$lang['js']['medialnk']        = 'Link a részletekre';
+$lang['js']['mediadirect']     = 'Közvetlen link az eredetire';
+$lang['js']['medianolnk']      = 'Nincsen link';
+$lang['js']['medianolink']     = 'Ne linkelje a képet';
+$lang['js']['medialeft']       = 'Kép igazítása balra.';
+$lang['js']['mediaright']      = 'Kép igazítása jobbra.';
+$lang['js']['mediacenter']     = 'Kép igazítása középre.';
+$lang['js']['medianoalign']    = 'Nem legyen igazítás.';
+$lang['js']['nosmblinks']      = 'A Windows megosztott könyvtárak kereszthivatkozása csak  Microsoft Internet Explorerben működik közvetlenül.
+A hivatkozást másolni és beszúrni ettől fügetlenül mndig tudod.';
+$lang['js']['linkwiz']         = 'Hivatkozás varázsló';
+$lang['js']['linkto']          = 'Hivatkozás erre:';
+$lang['js']['del_confirm']     = 'Valóban törölni akarod a kiválasztott elem(ek)et?';
+$lang['js']['mu_btn']          = 'Több fájl feltöltése egyszerre';
 $lang['rssfailed']             = 'Hiba történt ennek a betöltésekor: ';
 $lang['nothingfound']          = 'Semmit sem találtam.';
 $lang['mediaselect']           = 'Médiafájl kiválasztása';
@@ -110,11 +144,7 @@ $lang['deletefail']            = 'A "%s" fájl nem törölhető. - Ellenőrizd a
 $lang['mediainuse']            = 'A "%s" fájl nem törlődött - még használat alatt van.';
 $lang['namespaces']            = 'Névtér';
 $lang['mediafiles']            = 'Elérhető fájlok itt:';
-$lang['js']['keepopen']        = 'Tartsd nyitva ezt az ablakot a kijelöléshez!';
-$lang['js']['hidedetails']     = 'Részletek elrejtése';
-$lang['js']['nosmblinks']      = 'A Windows megosztott könyvtárak kereszthivatkozása csak  Microsoft Internet Explorerben működik közvetlenül.
-A hivatkozást másolni és beszúrni ettől fügetlenül mndig tudod.';
-$lang['js']['mu_btn']          = 'Több fájl feltöltése egyszerre';
+$lang['accessdenied']          = 'Nincsen jogod az oldal megtekintésére.';
 $lang['mediausage']            = 'A következő formában hivatkozhatsz erre az állományra:';
 $lang['mediaview']             = 'Eredeti állomány megtekintése';
 $lang['mediaroot']             = 'kiindulási hely';
@@ -130,6 +160,10 @@ $lang['current']               = 'aktuális';
 $lang['yours']                 = 'A te változatod';
 $lang['diff']                  = 'a különbségeket mutatja az aktuális változathoz képest';
 $lang['diff2']                 = 'a különbségeket mutatja a kiválasztott változatok között';
+$lang['difflink']              = 'Összehasonlító nézet linkje';
+$lang['diff_type']             = 'Összehasonlítás módja:';
+$lang['diff_inline']           = 'Sorok között';
+$lang['diff_side']             = 'Kétoldalas';
 $lang['line']                  = 'sorszám';
 $lang['breadcrumb']            = 'Nyomvonal';
 $lang['youarehere']            = 'Itt vagy';
@@ -141,21 +175,27 @@ $lang['restored']              = 'az előző változat helyreállítva';
 $lang['external_edit']         = 'külső szerkesztés';
 $lang['summary']               = 'A változások összefoglalása';
 $lang['noflash']               = 'Ennek a tartalomnak a megtekintéséhez <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> szükséges.';
+$lang['download']              = 'Kódrészlet letöltése';
 $lang['mail_newpage']          = 'új oldal jött létre:';
 $lang['mail_changed']          = 'oldal megváltozott:';
+$lang['mail_subscribe_list']   = 'oldalak megváltoztak ebben a névtérben:';
 $lang['mail_new_user']         = 'Új felhasználó:';
 $lang['mail_upload']           = 'állományt töltöttek fel:';
-$lang['qb_alert']              = 'Írd be a formázandó szöveget.\nEz a dokumentum szövegének végéhez fog hozzáadódni.';
 $lang['qb_bold']               = 'Félkövér szöveg';
 $lang['qb_italic']             = 'Dőlt szöveg';
 $lang['qb_underl']             = 'Aláhúzott szöveg';
 $lang['qb_code']               = 'Forráskód szöveg';
 $lang['qb_strike']             = 'Áthúzott szöveg';
-$lang['qb_h1']                 = '1. színtű címsor';
-$lang['qb_h2']                 = '2. színtű címsor';
-$lang['qb_h3']                 = '3. színtű címsor';
-$lang['qb_h4']                 = '4. színtű címsor';
-$lang['qb_h5']                 = '5. színtű címsor';
+$lang['qb_h1']                 = '1. szintű címsor';
+$lang['qb_h2']                 = '2. szintű címsor';
+$lang['qb_h3']                 = '3. szintű címsor';
+$lang['qb_h4']                 = '4. szintű címsor';
+$lang['qb_h5']                 = '5. szintű címsor';
+$lang['qb_h']                  = 'Címsor';
+$lang['qb_hs']                 = 'Címsor kiválasztása';
+$lang['qb_hplus']              = 'Nagyobb címsor';
+$lang['qb_hminus']             = 'Kisebb címsor';
+$lang['qb_hequal']             = 'Azonos szintű címsor';
 $lang['qb_link']               = 'Belső hivatkozás';
 $lang['qb_extlink']            = 'Külső hivatkozás';
 $lang['qb_hr']                 = 'Vízszintes elválasztó vonal';
@@ -165,7 +205,7 @@ $lang['qb_media']              = 'Képek és más fájlok hozzáadása';
 $lang['qb_sig']                = 'Aláírás beszúrása';
 $lang['qb_smileys']            = 'Szmájlik';
 $lang['qb_chars']              = 'Speciális karakterek';
-$lang['del_confirm']           = 'Valóban törölni akarod a kiválasztott elem(ek)et?';
+$lang['upperns']               = 'Ugrás a szülő névtérhez';
 $lang['admin_register']        = 'Új felhasználó';
 $lang['metaedit']              = 'Meta-adatok szerkesztése';
 $lang['metasaveerr']           = 'A meta-adatok írása meghiúsult ';
@@ -181,11 +221,22 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Formátum';
 $lang['img_camera']            = 'Fényképező típusa';
 $lang['img_keywords']          = 'Kulcsszavak';
-$lang['subscribe_success']     = '%s feliratkozott a(z) %s oldal változás-követő hírlevelére';
-$lang['subscribe_error']       = 'Hiba történt, miközben %s feliratkozni próbált a(z) %s oldal változás-követő hírlevelére';
-$lang['subscribe_noaddress']   = 'Nincs beállítva az e-mail címed, így nem tudsz feliratkozni az oldal változás-követő hírlevelére';
-$lang['unsubscribe_success']   = '%s leiratkozott az oldal változás-követő hírleveléről';
-$lang['unsubscribe_error']     = 'Hiba történt, miközben %s leiratkozni próbált az oldal változás-követő hírleveléről';
+$lang['subscr_subscribe_success'] = '%s hozzáadva az értesítési listához: %s';
+$lang['subscr_subscribe_error'] = 'Hiba történt %s hozzáadásakor az értesítési listához: %s';
+$lang['subscr_subscribe_noaddress'] = 'Nincsen e-mail cím megadva az adataidnál, így a rendszer nem tudott hozzáadni az értesítési listához';
+$lang['subscr_unsubscribe_success'] = '%s eltávolítva az értesítési listából: %s';
+$lang['subscr_unsubscribe_error'] = 'Hiba történt %s eltávolításakor az értesítési listából: %s';
+$lang['subscr_already_subscribed'] = '%s már feliratkozott erre: %s';
+$lang['subscr_not_subscribed'] = '%s nincsen feliratkozva erre: %s';
+$lang['subscr_m_not_subscribed'] = 'Jelenleg nem vagy feliratkozva erre az oldalra vagy névtérre';
+$lang['subscr_m_new_header']   = 'Feliratkozás hozzáadása';
+$lang['subscr_m_current_header'] = 'Feliratkozások';
+$lang['subscr_m_unsubscribe']  = 'Leiratkozás';
+$lang['subscr_m_subscribe']    = 'Feliratkozás';
+$lang['subscr_m_receive']      = 'Küldj';
+$lang['subscr_style_every']    = 'e-mailt minden változásról';
+$lang['subscr_style_digest']   = 'összefoglaló e-mailt oldalanként (minden %.2f nap)';
+$lang['subscr_style_list']     = 'egy listát a módosított oldalakról a legutóbbi e-mail óta (minden %.2f nap)';
 $lang['authmodfailed']         = 'Hibás felhasználó-aznosítási módszer van beállítva. Légy szíves értesítsd a Wiki-gazdát!';
 $lang['authtempfail']          = 'A felhasználó azonosítás átmenetileg nem működik. Ha sokáig így lenne, légy szíves értesítsd a Wiki-gazdát!';
 $lang['i_chooselang']          = 'Válassz nyelvet';
@@ -207,9 +258,10 @@ $lang['i_success']             = 'A beállítás sikeresen befejeződött. Most
 $lang['i_failure']             = 'Hiba lépett fel a konfigurációs állományok írásakor. Ki kell javítanod kézzel, mielőtt használni kezded az <a href="doku.php">új DokuWikidet</a>.';
 $lang['i_policy']              = 'Kezdeti hozzáférési politika';
 $lang['i_pol0']                = 'Nyitott Wiki (mindenki olvashatja, írhatja, és fájlokat tölthet fel)';
-$lang['i_pol1']                = 'Publikus Wiki (mindenki olvashatja, de csak regisztrált felhasználók írhatják, és tölthetnek fel fáljokat)';
+$lang['i_pol1']                = 'Publikus Wiki (mindenki olvashatja, de csak regisztrált felhasználók írhatják, és tölthetnek fel fájlokat)';
 $lang['i_pol2']                = 'Zárt Wiki (csak regisztrált felhasználók olvashatják, írhatják és tölthetnek fel fájlokat)';
 $lang['i_retry']               = 'Újra';
+$lang['i_license']             = 'Kérlek válassz licenszt a feltöltött tartalomhoz:';
 $lang['mu_intro']              = 'Itt több fájlt is fel tudsz tölteni egyszerre. Kattints a "Kiválaszt" gombra és add hozzá a listához. Nyomd meg a Feltöltés gombot, amikor elkészültél.';
 $lang['mu_gridname']           = 'Fájlnév';
 $lang['mu_gridsize']           = 'Méret';
@@ -223,4 +275,14 @@ $lang['mu_fail']               = 'hibás';
 $lang['mu_authfail']           = 'session lejárt';
 $lang['mu_progress']           = '@PCT@% feltöltve';
 $lang['mu_filetypes']          = 'Megengedett fájltípusok';
+$lang['mu_info']               = 'Fájlok feltöltve.';
+$lang['mu_lasterr']            = 'Utolsó hiba:';
 $lang['recent_global']         = 'Jelenleg csak a <b>%s</b> névtér friss változásai látszanak. Megtekinthetők <a href="%s">a teljes wiki friss változásai</a> is.';
+$lang['years']                 = '%d évvel ezelőtt';
+$lang['months']                = '%d hónappal ezelőtt';
+$lang['weeks']                 = '%d héttel ezelőtt';
+$lang['days']                  = '%d nappal ezelőtt';
+$lang['hours']                 = '%d órával ezelőtt';
+$lang['minutes']               = '%d perccel ezelőtt';
+$lang['seconds']               = '%d másodperccel ezelőtt';
+$lang['wordblock']             = 'A változásokat nem sikerült menteni, mert tiltott tartalom van benne (spam)';
