@@ -4,12 +4,15 @@
  *
  * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author Giorgio Vecchiocattivi <giorgio@vecchio.it>
- * @author Roberto Bolli <http://www.rbnet.it/>
+ * @author Roberto Bolli [http://www.rbnet.it/]
  * @author Silvia Sargentoni <polinnia@tin.it>
  * @author Diego Pierotto <ita.translations@tiscali.it>
- * @author Diego Pierotto ita.translations@tiscali.it
- * @author ita.translations@tiscali.it
  * @author Lorenzo Breda <lbreda@gmail.com>
+ * @author snarchio@alice.it
+ * @author robocap <robocap1@gmail.com>
+ * @author Matteo Carnevali <rekstorm@gmail.com>
+ * @author Osman Tekin <osman.tekin93@hotmail.it>
+ * @author Jacopo Corbetta <jacopo.corbetta@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -38,44 +41,42 @@ $lang['btn_login']             = 'Entra';
 $lang['btn_logout']            = 'Esci';
 $lang['btn_admin']             = 'Amministrazione';
 $lang['btn_update']            = 'Aggiorna';
-$lang['btn_delete']            = 'Cancella';
+$lang['btn_delete']            = 'Elimina';
 $lang['btn_back']              = 'Indietro';
-$lang['btn_backlink']          = 'Backlinks';
+$lang['btn_backlink']          = 'Puntano qui';
 $lang['btn_backtomedia']       = 'Torna alla selezione file';
 $lang['btn_subscribe']         = 'Sottoscrivi modifiche';
-$lang['btn_unsubscribe']       = 'Cancella sottoscrizione';
-$lang['btn_subscribens']       = 'Sottoscrivi modifiche della categoria';
-$lang['btn_unsubscribens']     = 'Cancella sottoscrizione modifiche della categoria';
 $lang['btn_profile']           = 'Aggiorna profilo';
 $lang['btn_reset']             = 'Annulla';
 $lang['btn_resendpwd']         = 'Invia nuova password';
 $lang['btn_draft']             = 'Modifica bozza';
 $lang['btn_recover']           = 'Ripristina bozza';
-$lang['btn_draftdel']          = 'Cancella bozza';
+$lang['btn_draftdel']          = 'Elimina bozza';
+$lang['btn_revert']            = 'Ripristina';
+$lang['btn_register']          = 'Registrazione';
 $lang['loggedinas']            = 'Collegato come';
 $lang['user']                  = 'Nome utente';
 $lang['pass']                  = 'Password';
 $lang['newpass']               = 'Nuova password';
-$lang['oldpass']               = 'Conferma password corrente';
+$lang['oldpass']               = 'Conferma password attuale';
 $lang['passchk']               = 'Ripeti password';
-$lang['remember']              = 'Ricorda automaticamente';
+$lang['remember']              = 'Memorizza nome utente e password';
 $lang['fullname']              = 'Nome completo';
-$lang['email']                 = 'E-Mail';
-$lang['register']              = 'Registrazione';
+$lang['email']                 = 'Email';
 $lang['profile']               = 'Profilo utente';
 $lang['badlogin']              = 'Il nome utente o la password non sono validi.';
 $lang['minoredit']             = 'Modifiche minori';
 $lang['draftdate']             = 'Bozza salvata in automatico il';
-$lang['nosecedit']             = 'La pagina nel frattempo è cambiata, la sezione info è scaduta, caricata invece la pagina intera.';
+$lang['nosecedit']             = 'La pagina è stata modificata nel frattempo; è impossibile modificare solo la sezione scelta, quindi è stata caricata la pagina intera.';
 $lang['regmissing']            = 'Devi riempire tutti i campi.';
-$lang['reguexists']            = 'Il nome utente inserito esiste già .';
-$lang['regsuccess']            = 'L\'utente è stato creato. La password è stata spedita via e-mail.';
+$lang['reguexists']            = 'Il nome utente inserito esiste già.';
+$lang['regsuccess']            = 'L\'utente è stato creato. La password è stata spedita via email.';
 $lang['regsuccess2']           = 'L\'utente è stato creato.';
-$lang['regmailfail']           = 'Sembra che ci sia stato un errore nell\'invio della e-mail. Per favore contatta il tuo amministratore!';
-$lang['regbadmail']            = 'L\'indirizzo e-mail fornito sembra essere non valido - se pensi che ci sia un errore contatta il tuo amministratore';
+$lang['regmailfail']           = 'Sembra che ci sia stato un errore nell\'invio della email. Contatta l\'amministratore!';
+$lang['regbadmail']            = 'L\'indirizzo email fornito sembra essere non valido - se pensi che ci sia un errore contatta l\'amministratore';
 $lang['regbadpass']            = 'Le due password inserite non coincidono, prova di nuovo.';
-$lang['regpwmail']             = 'La tua password DokuWiki';
-$lang['reghere']               = 'Non hai ancora un accesso? Registrati qui.';
+$lang['regpwmail']             = 'La tua password per DokuWiki';
+$lang['reghere']               = 'Non sei ancora registrato? Registrati qui.';
 $lang['profna']                = 'Questo wiki non supporta modifiche al profilo';
 $lang['profnochange']          = 'Nessuna modifica, niente da aggiornare.';
 $lang['profnoempty']           = 'Nome o indirizzo email vuoti non sono consentiti.';
@@ -85,71 +86,101 @@ $lang['resendna']              = 'Questo wiki non supporta l\'invio di nuove pas
 $lang['resendpwd']             = 'Invia nuova password per';
 $lang['resendpwdmissing']      = 'Devi riempire tutti i campi.';
 $lang['resendpwdnouser']       = 'Impossibile trovare questo utente nel database.';
-$lang['resendpwdbadauth']      = 'Spiacente, questo codice di autorizzazione non è valido. Assicurati di aver usato il link completo di conferma.';
+$lang['resendpwdbadauth']      = 'Spiacenti, questo codice di autorizzazione non è valido. Assicurati di aver usato il link completo di conferma.';
 $lang['resendpwdconfirm']      = 'Un link di conferma è stato spedito via email.';
 $lang['resendpwdsuccess']      = 'La nuova password è stata spedita via email.';
-$lang['license']               = 'Ad eccezione da dove è diversamente indicato, il contenuto di questo wiki è sotto la seguente licenza:';
+$lang['license']               = 'Ad eccezione da dove è diversamente indicato, il contenuto di questo wiki è soggetto alla seguente licenza:';
 $lang['licenseok']             = 'Nota: modificando questa pagina accetti di rilasciare il contenuto sotto la seguente licenza:';
+$lang['searchmedia']           = 'Cerca file di nome:';
+$lang['searchmedia_in']        = 'Cerca in &s';
 $lang['txt_upload']            = 'Seleziona un file da caricare';
-$lang['txt_filename']          = 'Inserisci un "wikiname" (opzionale)';
+$lang['txt_filename']          = 'Carica come (opzionale)';
 $lang['txt_overwrt']           = 'Sovrascrivi file esistente';
 $lang['lockedby']              = 'Attualmente bloccato da';
 $lang['lockexpire']            = 'Il blocco scade alle';
 $lang['willexpire']            = 'Il tuo blocco su questa pagina scadrà tra circa un minuto.\nPer evitare incongruenze usa il pulsante di anteprima per prolungare il periodo di blocco.';
-$lang['notsavedyet']           = 'Le modifiche non salvate andranno perse.\nContinuare?';
+$lang['js']['notsavedyet']     = 'Le modifiche non salvate andranno perse.';
+$lang['js']['searchmedia']     = 'Cerca file';
+$lang['js']['keepopen']        = 'Tieni la finestra aperta durante la selezione';
+$lang['js']['hidedetails']     = 'Nascondi Dettagli';
+$lang['js']['mediatitle']      = 'Impostazioni link';
+$lang['js']['mediadisplay']    = 'Tipo link';
+$lang['js']['mediaalign']      = 'Allineamento';
+$lang['js']['mediasize']       = 'Dimensioni immagine';
+$lang['js']['mediatarget']     = 'Target del link';
+$lang['js']['mediaclose']      = 'Chiudi';
+$lang['js']['mediainsert']     = 'Inserisci';
+$lang['js']['mediadisplayimg'] = 'Mostra l\'immagine.';
+$lang['js']['mediadisplaylnk'] = 'Mostra solo il link.';
+$lang['js']['mediasmall']      = 'Versione piccola';
+$lang['js']['mediamedium']     = 'Versione media';
+$lang['js']['medialarge']      = 'Versione grande';
+$lang['js']['mediaoriginal']   = 'Versione originale';
+$lang['js']['medialnk']        = 'Link alla pagina dei dettagli';
+$lang['js']['mediadirect']     = 'Link all\'originale';
+$lang['js']['medianolnk']      = 'No link';
+$lang['js']['medianolink']     = 'Non linkare l\'immagine.';
+$lang['js']['medialeft']       = 'Allinea l\'immagine a sinistra.';
+$lang['js']['mediaright']      = 'Allinea l\'immagine a destra.';
+$lang['js']['mediacenter']     = 'Allinea l\'immagine al centro.';
+$lang['js']['medianoalign']    = 'Non allineare.';
+$lang['js']['nosmblinks']      = 'I collegamenti con le risorse condivise di Windows funzionano solo con Microsoft Internet Explorer.
+È comunque possibile copiare e incollare il collegamento.';
+$lang['js']['linkwiz']         = 'Collegamento guidato';
+$lang['js']['linkto']          = 'Collega a:';
+$lang['js']['del_confirm']     = 'Eliminare veramente questa voce?';
+$lang['js']['mu_btn']          = 'Carica più di un file alla volta';
 $lang['rssfailed']             = 'Si è verificato un errore cercando questo feed: ';
 $lang['nothingfound']          = 'Nessun risultato trovato.';
 $lang['mediaselect']           = 'Selezione dei file';
 $lang['fileupload']            = 'File caricato';
 $lang['uploadsucc']            = 'Invio riuscito';
-$lang['uploadfail']            = 'Invio fallito. Contatta l\'amministratore.';
+$lang['uploadfail']            = 'Invio fallito. È possibile che si tratti di un problema di permessi.';
 $lang['uploadwrong']           = 'Invio rifiutato. Questa estensione di file non è ammessa';
-$lang['uploadexist']           = 'Il file esiste già . Invio annullato.';
-$lang['uploadbadcontent']      = 'Il contenuto caricato non corrisponde all\'estensione del file %s.';
-$lang['uploadspam']            = 'Il caricamento è stato bloccato dalla lista nera di spam.';
-$lang['uploadxss']             = 'Il caricamento è stato bloccato perchè il contenuto potrebbe essere malizioso.';
+$lang['uploadexist']           = 'Il file esiste già. Invio annullato.';
+$lang['uploadbadcontent']      = 'Il tipo di contenuto caricato non corrisponde all\'estensione del file %s.';
+$lang['uploadspam']            = 'Il caricamento è stato bloccato come spam perché presente nella lista nera.';
+$lang['uploadxss']             = 'Il caricamento è stato bloccato perchè il contenuto potrebbe essere un virus o presentare problemi di sicurezza.';
 $lang['uploadsize']            = 'Il file caricato è troppo grande. (massimo %s)';
-$lang['deletesucc']            = 'Il file "%s" è stato cancellato.';
-$lang['deletefail']            = '"%s" non può essere cancellato - verifica i permessi.';
-$lang['mediainuse']            = 'Il file "%s" non è stato cancellato - è ancora in uso.';
+$lang['deletesucc']            = 'Il file "%s" è stato eliminato.';
+$lang['deletefail']            = '"%s" non può essere eliminato - verifica i permessi.';
+$lang['mediainuse']            = 'Il file "%s" non è stato eliminato - è ancora in uso.';
 $lang['namespaces']            = 'Categorie';
 $lang['mediafiles']            = 'File disponibili in';
-$lang['js']['keepopen']        = 'Tieni la finestra aperta durante la selezione';
-$lang['js']['hidedetails']     = 'Nascondi Dettagli';
-$lang['js']['nosmblinks']      = 'I collegamenti con le risorse condivise di Windows funzionano solo con Microsoft Internet Explorer.
-Puoi fare un copia/incolla di questo collegamento.';
-$lang['js']['mu_btn']          = 'Carica più di un file alla volta';
+$lang['accessdenied']          = 'Non sei autorizzato a vedere questa pagina.';
 $lang['mediausage']            = 'Usa la seguente sintassi per riferirti a questo file:';
 $lang['mediaview']             = 'Mostra file originale';
 $lang['mediaroot']             = 'directory principale';
-$lang['mediaupload']           = 'Carica un file nella categoria corrente. Per creare sottocategorie, falle precedere al nome del file nella casella "Carica come", separandole da due punti (:).';
+$lang['mediaupload']           = 'Carica un file nella categoria attuale. Per creare sottocategorie, falle precedere dal nome del file nella casella "Carica come", separandole da due punti (:).';
 $lang['mediaextchange']        = 'Estensione del file modificata da .%s a .%s!';
 $lang['reference']             = 'Riferimenti a';
-$lang['ref_inuse']             = 'Il file non può essere cancellato in quanto è ancora utilizzato dalle seguenti pagine:';
+$lang['ref_inuse']             = 'Il file non può essere eliminato in quanto è ancora utilizzato dalle seguenti pagine:';
 $lang['ref_hidden']            = 'Sono presenti alcuni riferimenti a pagine per le quali non hai i permessi di lettura';
 $lang['hits']                  = 'Occorrenze trovate';
 $lang['quickhits']             = 'Pagine trovate';
 $lang['toc']                   = 'Indice';
-$lang['current']               = 'versione corrente';
+$lang['current']               = 'versione attuale';
 $lang['yours']                 = 'la tua versione';
 $lang['diff']                  = 'differenze con la versione attuale';
 $lang['diff2']                 = 'differenze tra le versioni selezionate';
+$lang['difflink']              = 'Link a questa pagina di confronto';
 $lang['line']                  = 'Linea';
 $lang['breadcrumb']            = 'Traccia';
 $lang['youarehere']            = 'Ti trovi qui';
 $lang['lastmod']               = 'Ultima modifica';
 $lang['by']                    = 'da';
-$lang['deleted']               = 'cancellata';
+$lang['deleted']               = 'eliminata';
 $lang['created']               = 'creata';
 $lang['restored']              = 'versione precedente ripristinata';
 $lang['external_edit']         = 'modifica esterna';
 $lang['summary']               = 'Oggetto della modifica';
-$lang['noflash']               = 'E\' necessario <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> per visualizzare questo contenuto.';
+$lang['noflash']               = 'E\' necessario <a href="http://www.adobe.com/products/flashplayer/">il plugin Adobe Flash</a> per visualizzare questo contenuto.';
+$lang['download']              = 'Scarica lo "snippet"';
 $lang['mail_newpage']          = 'pagina aggiunta:';
 $lang['mail_changed']          = 'pagina modificata:';
-$lang['mail_new_user']         = 'Nuovo utente:';
+$lang['mail_subscribe_list']   = 'pagine modificate nella categoria:';
+$lang['mail_new_user']         = 'nuovo utente:';
 $lang['mail_upload']           = 'file caricato:';
-$lang['qb_alert']              = 'Puoi inserire il testo che vuoi formattare.\nSarà  aggiunto alla fine del documento.';
 $lang['qb_bold']               = 'Grassetto';
 $lang['qb_italic']             = 'Corsivo';
 $lang['qb_underl']             = 'Sottolineato';
@@ -160,6 +191,11 @@ $lang['qb_h2']                 = 'Intestazione di livello 2';
 $lang['qb_h3']                 = 'Intestazione di livello 3';
 $lang['qb_h4']                 = 'Intestazione di livello 4';
 $lang['qb_h5']                 = 'Intestazione di livello 5';
+$lang['qb_h']                  = 'Titolo';
+$lang['qb_hs']                 = 'Seleziona il titolo';
+$lang['qb_hplus']              = 'Titolo superiore';
+$lang['qb_hminus']             = 'Titolo inferiore';
+$lang['qb_hequal']             = 'Titolo dello stesso livello';
 $lang['qb_link']               = 'Collegamento interno';
 $lang['qb_extlink']            = 'Collegamento esterno';
 $lang['qb_hr']                 = 'Riga orizzontale';
@@ -169,7 +205,7 @@ $lang['qb_media']              = 'Inserisci immagini o altri file';
 $lang['qb_sig']                = 'Inserisci la firma';
 $lang['qb_smileys']            = 'Smiley';
 $lang['qb_chars']              = 'Caratteri speciali';
-$lang['del_confirm']           = 'Cancellare questa voce?';
+$lang['upperns']               = 'vai alla categoria principale';
 $lang['admin_register']        = 'Aggiungi un nuovo utente';
 $lang['metaedit']              = 'Modifica metadati';
 $lang['metasaveerr']           = 'Scrittura metadati fallita';
@@ -185,48 +221,69 @@ $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Formato';
 $lang['img_camera']            = 'Camera';
 $lang['img_keywords']          = 'Parole chiave';
-$lang['subscribe_success']     = '%s è stato aggiunto alla lista di sottoscrizione per la pagina %s';
-$lang['subscribe_error']       = 'Si è verificato un errore durante l\'aggiunta di %s alla lista di sottoscrizione per la pagina %s';
-$lang['subscribe_noaddress']   = 'Non c\'è alcun indirizzo associato con il tuo profilo, non puoi sottoscriverti ad alcuna lista';
-$lang['unsubscribe_success']   = '%s è stato rimosso dalla lista di sottoscrizione per la pagina %s';
-$lang['unsubscribe_error']     = 'Si è verificato un errore durante la rimozione di %s dalla lista di sottoscrizione per la pagina %s';
-$lang['authmodfailed']         = 'La configurazione dell\'autenticazione non è corretta. Per favore informa l\'amministratore di questo Wiki.';
-$lang['authtempfail']          = 'L\'autenticazione è temporaneamente non disponibile. Se questa situazione persiste, per favore informa l\'amministratore di questo Wiki.';
+$lang['subscr_subscribe_success'] = 'Aggiunto %s alla lista di sottoscrizioni %s';
+$lang['subscr_subscribe_error'] = 'Impossibile aggiungere %s alla lista di sottoscrizioni %s';
+$lang['subscr_subscribe_noaddress'] = 'Non esiste alcun indirizzo associato al tuo account, non puoi essere aggiunto alla lista di sottoscrizioni';
+$lang['subscr_unsubscribe_success'] = 'Rimosso %s dalla lista di sottoscrizioni %s';
+$lang['subscr_unsubscribe_error'] = 'Impossibile rimuovere %s dalla lista di sottoscrizioni %s';
+$lang['subscr_already_subscribed'] = '% è già iscritto a %s';
+$lang['subscr_not_subscribed'] = '% non è iscritto a %s';
+$lang['subscr_m_not_subscribed'] = 'Attualmente non sei iscritto alla pagina o categoria corrente';
+$lang['subscr_m_new_header']   = 'Aggiungi sottoscrizione';
+$lang['subscr_m_current_header'] = 'Sottoscrizioni attuali';
+$lang['subscr_m_unsubscribe']  = 'Rimuovi sottoscrizione';
+$lang['subscr_m_subscribe']    = 'Sottoscrivi';
+$lang['subscr_m_receive']      = 'Ricevi';
+$lang['subscr_style_every']    = 'email per ogni modifica';
+$lang['subscr_style_digest']   = 'email riassuntiva delle modifiche di ogni pagina';
+$lang['subscr_style_list']     = 'elenco delle pagine modificate dall\'ultima email';
+$lang['authmodfailed']         = 'La configurazione dell\'autenticazione non è corretta. Informa l\'amministratore di questo wiki.';
+$lang['authtempfail']          = 'L\'autenticazione è temporaneamente non disponibile. Se questa situazione persiste, informa l\'amministratore di questo wiki.';
 $lang['i_chooselang']          = 'Scegli la lingua';
-$lang['i_installer']           = 'Installazione DokuWiki';
+$lang['i_installer']           = 'Installazione di DokuWiki';
 $lang['i_wikiname']            = 'Nome Wiki';
 $lang['i_enableacl']           = 'Abilita ACL (consigliato)';
 $lang['i_superuser']           = 'Amministratore';
 $lang['i_problems']            = 'Si sono verificati problemi durante l\'installazione, indicati di seguito. Non è possibile continuare finché non saranno risolti.';
 $lang['i_modified']            = 'Per motivi di sicurezza questa procedura funziona solamente con un\'installazione Dokuwiki nuova e non modificata.
-                         Dovresti ri-estrarre i file dal pacchetto scaricato oppure consultare tutte le
-                         <a href="http://dokuwiki.org/install">istruzioni per l\'installazione di Dokuwiki</a>';
-$lang['i_funcna']              = 'La funzione PHP <code>%s</code> non è disponibile. Forse il tuo provider l\'ha disabilitata per qualche motivo?';
+Prova a estrarre di nuovo i file dal pacchetto scaricato oppure consulta le
+<a href="http://dokuwiki.org/install">istruzioni per l\'installazione di Dokuwiki</a>';
+$lang['i_funcna']              = 'La funzione PHP <code>%s</code> non è disponibile. Forse è stata disabilitata dal tuo provider per qualche motivo?';
 $lang['i_phpver']              = 'La versione di PHP <code>%s</code> è inferiore a quella richiesta <code>%s</code>. Devi aggiornare l\'installazione di PHP.';
 $lang['i_permfail']            = 'DokuWiki non può scrivere <code>%s</code>. E\' necessario correggere i permessi per questa directory!';
 $lang['i_confexists']          = '<code>%s</code> esiste già';
-$lang['i_writeerr']            = 'Impossibile creare <code>%s</code>. E\' necessario verificare i permessi della directory/file e creare il file manualmente.';
+$lang['i_writeerr']            = 'Impossibile creare <code>%s</code>. E\' necessario verificare i permessi della directory o del file oppure creare il file manualmente.';
 $lang['i_badhash']             = 'dokuwiki.php (hash=<code>%s</code>) non riconosciuto o modificato';
 $lang['i_badval']              = '<code>%s</code> - valore vuoto o non valido';
-$lang['i_success']             = 'La configurazione è stata completata correttamente. E\' ora possibile cancellare il file install.php. Continuare con
-                        <a href="doku.php">il nuovo DokuWiki</a>.';
-$lang['i_failure']             = 'Si sono verificati errori durante la scrittura dei file di configurazione. Potrebbe essere necessario correggerli manualmente prima di poter utilizzare <a href="doku.php">il nuovo DokuWiki</a>.';
-$lang['i_policy']              = 'Policy di accesso iniziali';
+$lang['i_success']             = 'La configurazione è stata completata correttamente. Ora è possibile eliminare il file install.php. Poi, visita <a href="doku.php">il tuo nuovo DokuWiki</a>.';
+$lang['i_failure']             = 'Si sono verificati errori durante la scrittura dei file di configurazione. Potrebbe essere necessario correggerli manualmente prima di poter utilizzare <a href="doku.php">il tuo nuovo DokuWiki</a>.';
+$lang['i_policy']              = 'Regole di accesso iniziali';
 $lang['i_pol0']                = 'Wiki Aperto (lettura, scrittura, caricamento file per tutti)';
 $lang['i_pol1']                = 'Wiki Pubblico (lettura per tutti, scrittura e caricamento file per gli utenti registrati)';
 $lang['i_pol2']                = 'Wiki Chiuso (lettura, scrittura, caricamento file solamente per gli utenti registrati)';
 $lang['i_retry']               = 'Riprova';
-$lang['mu_intro']              = 'Qui si possono caricare più di un file alla volta. Cliccare su "Sfoglia..." per aggiungere i file in coda. Cliccare "Carica" quando si è pronti.';
-$lang['mu_gridname']           = 'Nome del file';
+$lang['i_license']             = 'Per favore scegli la licenza sotto cui vuoi rilasciare il contenuto:';
+$lang['mu_intro']              = 'Qui si possono caricare più di un file alla volta. Scegliere "Sfoglia..." per aggiungere file alla coda. Alla fine, fai click su "Invia file".';
+$lang['mu_gridname']           = 'Nome file';
 $lang['mu_gridsize']           = 'Dimensione';
 $lang['mu_gridstat']           = 'Stato';
-$lang['mu_namespace']          = 'Namespace';
-$lang['mu_browse']             = 'Sfoglia...';
+$lang['mu_namespace']          = 'Categoria';
+$lang['mu_browse']             = 'Sfoglia';
 $lang['mu_toobig']             = 'troppo grande';
-$lang['mu_ready']              = 'pronto per l\'upload';
+$lang['mu_ready']              = 'pronto per caricare';
 $lang['mu_done']               = 'completo';
 $lang['mu_fail']               = 'fallito';
 $lang['mu_authfail']           = 'sessione scaduta';
 $lang['mu_progress']           = '@PCT@% caricato';
 $lang['mu_filetypes']          = 'Tipi di file permessi';
-$lang['recent_global']         = 'Stai attualmente vedendo le modifiche dentro l\'area <b>%s</b>. Puoi anche <a href="%s">vedere le modifiche recenti dell\'intero wiki</a>.';
+$lang['mu_info']               = 'file caricati.';
+$lang['mu_lasterr']            = 'Ultimo errore:';
+$lang['recent_global']         = 'Stai attualmente vedendo le modifiche effettuate nell\'area <b>%s</b>. Puoi anche <a href="%s">vedere le modifiche recenti dell\'intero wiki</a>.';
+$lang['years']                 = '%d anni fa';
+$lang['months']                = '%d mesi fa';
+$lang['weeks']                 = '%d settimane fa';
+$lang['days']                  = '%d giorni fa';
+$lang['hours']                 = '%d ore fa';
+$lang['minutes']               = '%d minuti fa';
+$lang['seconds']               = '%d secondi fa';
+$lang['wordblock']             = 'La modifica non è stata salvata perché contiene testo bloccato (spam).';
