@@ -10,7 +10,6 @@
  * @url http://svn.wikimedia.org/viewvc/mediawiki/trunk/phase3/languages/messages/MessagesMr.php?view=co
  * @author ghatothkach@hotmail.com
  * @author Padmanabh Kulkarni <kulkarnipadmanabh@gmail.com>
- * @author Padmanabh Kulkarni<kulkarnipadmanabh@gmail.com>
  * @author shantanoo@gmail.com
  */
 $lang['encoding']              = 'utf-8';
@@ -44,12 +43,17 @@ $lang['btn_delete']            = 'नष्ट';
 $lang['btn_back']              = 'मागॆ';
 $lang['btn_backlink']          = 'येथे काय जोडले आहे';
 $lang['btn_backtomedia']       = 'परत माध्यम फाइल निवडीकड़े';
+$lang['btn_subscribe']         = 'पृष्ठाच्या बदलांची पुरवणी (फीड) लावा ';
+$lang['btn_unsubscribe']       = 'पृष्ठाच्या बदलांची पुरवणी (फीड) बंद करा';
+$lang['btn_subscribens']       = 'नामसमुहाच्या (नेमस्पेस) बदलांची पुरवणी (फीड) लावा';
+$lang['btn_unsubscribens']     = 'नामसमुहाच्या (नेमस्पेस) बदलांची पुरवणी (फीड) बंद करा';
 $lang['btn_profile']           = 'प्रोफाइल अद्ययावत करा';
 $lang['btn_reset']             = 'रिसेट';
 $lang['btn_resendpwd']         = 'कृपया परवलीचा नवीन शब्द माझ्या इमेल पत्त्यावर पाठविणे.';
 $lang['btn_draft']             = 'प्रत संपादन';
 $lang['btn_recover']           = 'प्रत परत मिळवा';
 $lang['btn_draftdel']          = 'प्रत रद्द';
+$lang['btn_register']          = 'नोंदणी';
 $lang['loggedinas']            = 'लॉगिन नाव';
 $lang['user']                  = 'वापरकर्ता';
 $lang['pass']                  = 'परवलीचा शब्द';
@@ -59,7 +63,6 @@ $lang['passchk']               = 'परत एकदा';
 $lang['remember']              = 'लक्षात ठेवा';
 $lang['fullname']              = 'पूर्ण नावं';
 $lang['email']                 = 'इमेल';
-$lang['register']              = 'नोंदणी';
 $lang['profile']               = 'वापरकर्त्याची माहिती';
 $lang['badlogin']              = 'माफ़ करा, वापरकर्ता नावात किंवा परवलीच्या शब्दात चूक झाली आहे.';
 $lang['minoredit']             = 'छोटे बदल';
@@ -70,6 +73,7 @@ $lang['reguexists']            = 'या नावाने सदस्या
 $lang['regsuccess']            = 'सदस्याची नोंदणी झाली आहे आणि परवलीचा शब्द इमेल केला आहे.';
 $lang['regsuccess2']           = 'सदस्याची नोंदणी झाली.';
 $lang['regmailfail']           = 'परवलीचा शब्दाची इमेल पाठवण्यात चूक झाली आहे, क्रुपया संचालकांशी संपर्क साधा.';
+$lang['regbadmail']            = 'तुम्ही दिलेला ईमेल बरोबर नाही असे दिसते - तुमच्या मते ही चूक असल्यास साईटच्या व्यवस्थापकाशी संपर्क साधा.';
 $lang['regbadpass']            = 'आपला परवलीचा शब्द चुकीचा आहे.';
 $lang['regpwmail']             = 'तुमचा डोक्युविकि परवली.';
 $lang['reghere']               = 'अजुन तुमचे खाते नाही ? एक उघडून टाका.';
@@ -93,7 +97,7 @@ $lang['txt_overwrt']           = 'अस्तित्वात असलेल
 $lang['lockedby']              = 'सध्या लॉक करणारा :';
 $lang['lockexpire']            = 'सध्या लॉक करणारा :';
 $lang['willexpire']            = 'हे पृष्ठ संपादित करण्यासाठी मिळालेले लॉक एखाद्या मिनिटात संपणार आहे.\n चुका होऊ नयेत म्हणुन कृपया प्रीव्यू बटन दाबुन लॉक ची वेळ पुन्हा चालू करा.';
-$lang['notsavedyet']           = 'सुरक्षित न केलेले बदल नष्ट होतील. नक्की करू का ?';
+$lang['js']['notsavedyet']     = "सुरक्षित न केलेले बदल नष्ट होतील. नक्की करू का ?";
 $lang['rssfailed']             = 'ही पुरवणी आणण्यात काही चूक झाली:';
 $lang['nothingfound']          = 'काही सापडला नाही.';
 $lang['mediaselect']           = 'दृकश्राव्य फाइल';
@@ -105,10 +109,12 @@ $lang['uploadexist']           = 'फाइल आधीच अस्तित
 $lang['uploadbadcontent']      = 'अपलोड केलेली माहिती %s फाइल एक्सटेंशनशी मिळतिजुळति नाही.';
 $lang['uploadspam']            = 'अपलोड स्पॅम ब्लॅकलिस्टमुळे थोपवला आहे.';
 $lang['uploadxss']             = 'अपलोड संशयित हानिकारक मजकूर असल्याने थोपवला आहे.';
+$lang['uploadsize']            = 'अपलोड केलेली फाइल जास्तीच मोठी होती. (जास्तीत जास्त %s)';
 $lang['deletesucc']            = '%s ही फाइल नष्ट करण्यात आलेली आहे.';
 $lang['deletefail']            = '%s ही फाइल नष्ट करू शकलो नाही - कृपया परवानग्या तपासा.';
 $lang['mediainuse']            = '%s ही फाइल नष्ट केली नाही - ती अजुन वापरात आहे.';
 $lang['namespaces']            = 'नेमस्पेस';
+$lang['mediafiles']            = 'मध्ये उपलब्ध असलेल्या फाइल';
 $lang['js']['keepopen']        = 'निवड केल्यावर विण्डो उघडी ठेवा';
 $lang['js']['hidedetails']     = 'सविस्तर मजकूर लपवा';
 $lang['js']['nosmblinks']      = 'विन्डोज़ शेअर ला लिंक केल्यास ते फक्त मायक्रोसॉफ़्ट इन्टरनेट एक्स्प्लोरर वरच चालते. तरी तुम्ही लिंक कॉपी करू शकता.';
@@ -118,12 +124,16 @@ $lang['mediaview']             = 'मूळ फाइल बघू ';
 $lang['mediaroot']             = 'रूट';
 $lang['mediaupload']           = 'सध्याच्या नेमस्पेसमधे इथेच फाइल अपलोड करा. उप-नेमस्पेस बनवण्यासाठि त्याचे नाव तुमच्या "अपलोड उर्फ़" मधे दिलेल्या फाइल नावाच्या आधी विसर्गचिन्हाने वेगळे करून ते वापरा.';
 $lang['mediaextchange']        = 'फाइलचे एक्सटेंशन .%s चे बदलून  .%s केले आहे.';
+$lang['reference']             = 'च्या साठी संदर्भ';
 $lang['ref_inuse']             = 'फाइल नष्ट केली जाऊ शकत नाही. ती अजुन खालील पृष्ठे वापरत आहेत :';
 $lang['ref_hidden']            = 'काही संदर्भ तुम्हाला वाचण्याची परवानगी नसलेल्या पृष्ठावर आहेत';
+$lang['hits']                  = 'हिट्स';
 $lang['quickhits']             = 'जुळणारि पाने';
 $lang['toc']                   = 'अनुक्रमणिका';
 $lang['current']               = 'चालू';
 $lang['yours']                 = 'तुमची आवृत्ति';
+$lang['diff']                  = 'सध्याच्या आवृत्तिंशी फरक दाखवा';
+$lang['diff2']                 = 'निवडलेल्या आवृत्तिंमधील फरक दाखवा';
 $lang['line']                  = 'ओळ';
 $lang['breadcrumb']            = 'मागमूस';
 $lang['youarehere']            = 'तुम्ही इथे आहात';
@@ -131,26 +141,34 @@ $lang['lastmod']               = 'सर्वात शेवटचा बद
 $lang['by']                    = 'द्वारा';
 $lang['deleted']               = 'काढून टाकले';
 $lang['created']               = 'निर्माण केले';
+$lang['restored']              = 'जुनी आवृत्ति पुनर्स्थापित केली';
 $lang['external_edit']         = 'बाहेरून संपादित';
 $lang['summary']               = 'सारांश बदला';
+$lang['noflash']               = 'ही माहिती दाखवण्यासाठी <a href="http://www.adobe.com/products/flashplayer/">अडोब फ्लॅश प्लेअर</a> ची गरज आहे.';
 $lang['mail_newpage']          = 'पृष्ठ जोडले : ';
 $lang['mail_changed']          = 'पृष्ठ बदलले : ';
 $lang['mail_new_user']         = 'नवीन सदस्य : ';
 $lang['mail_upload']           = 'फाइल अपलोड केली : ';
-$lang['qb_alert']              = 'तुम्हाला फॉरमॅट करायचा मजकूर टाका. \n तो दस्तावेजाच्या शेवटी जोडला जाइल.';
 $lang['qb_bold']               = 'ठळक मजकूर';
 $lang['qb_italic']             = 'तिरका मजकूर';
 $lang['qb_underl']             = 'अधोरेखित मजकूर';
 $lang['qb_code']               = 'कोड मजकूर';
 $lang['qb_strike']             = 'रद्द मजकूर';
+$lang['qb_h1']                 = 'पहिल्या पातळीचे शीर्षक';
+$lang['qb_h2']                 = 'दुसर्या पातळीचे शीर्षक';
+$lang['qb_h3']                 = 'तिसर्या पातळीचे शीर्षक';
+$lang['qb_h4']                 = 'चवथ्या पातळीचे शीर्षक';
+$lang['qb_h5']                 = 'पाचव्या पातळीचे शीर्षक';
 $lang['qb_link']               = 'अंतर्गत लिंक';
 $lang['qb_extlink']            = 'बाह्य लिंक';
 $lang['qb_hr']                 = 'आडवी पट्टी';
+$lang['qb_ol']                 = 'अनुक्रमित यादीतील वस्तु';
+$lang['qb_ul']                 = 'साध्या यादीतील वस्तु';
 $lang['qb_media']              = 'प्रतिमा आणि इतर फाइल टाका';
 $lang['qb_sig']                = 'स्वाक्षरी टाका';
 $lang['qb_smileys']            = 'स्माइली';
 $lang['qb_chars']              = 'ख़ास चिन्ह';
-$lang['del_confirm']           = 'निवडलेल्या गोष्टी नक्की नष्ट करू का ?';
+$lang['js']['del_confirm']           = 'निवडलेल्या गोष्टी नक्की नष्ट करू का ?';
 $lang['admin_register']        = 'नवीन सदस्य';
 $lang['metaedit']              = 'मेटाडेटा बदला';
 $lang['metasaveerr']           = 'मेटाडेटा सुरक्षित झाला नाही';
