@@ -3,8 +3,7 @@
  * Nepali language file
  *
  * @author Saroj Kumar Dhakal <lotusnagarkot@gmail.com>
- * @author SarojKumar Dhakal <lotusnagarkot@yahoo.com>
- * @author Saroj Dhakal<lotusnagarkot@yahoo.com>
+ * @author Saroj Kumar Dhakal <lotusnagarkot@yahoo.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -47,6 +46,7 @@ $lang['btn_resendpwd']         = 'नयाँ प्रवेश शव्द(
 $lang['btn_draft']             = ' ड्राफ्ट सम्पादन गर्नुहोस् ';
 $lang['btn_recover']           = 'पहिलेको ड्राफ्ट हासिल गर्नुहोस ';
 $lang['btn_draftdel']          = ' ड्राफ्ट मेटाउनुहोस् ';
+$lang['btn_register']          = 'दर्ता  गर्नुहोस्';
 $lang['loggedinas']            = 'प्रवेश गर्नुहोस् ';
 $lang['user']                  = 'प्रयोगकर्ता ';
 $lang['pass']                  = 'प्रवेशशव्द';
@@ -56,7 +56,6 @@ $lang['passchk']               = 'एकपटक पुन:';
 $lang['remember']              = 'मलाई सम्झनु';
 $lang['fullname']              = 'पूरा नाम';
 $lang['email']                 = 'इमेल';
-$lang['register']              = 'दर्ता  गर्नुहोस्';
 $lang['profile']               = 'प्रयोगकर्ताको प्रोफाइल';
 $lang['badlogin']              = 'माफ गर्नुहोस् , प्रयोगकर्तानाम वा प्रवेशशव्द गलत भयो  ';
 $lang['minoredit']             = 'सामान्य परिवर्तन';
@@ -91,7 +90,7 @@ $lang['txt_overwrt']           = 'रहेको उहि नामको फ
 $lang['lockedby']              = 'अहिले ताल्चा लगाइएको';
 $lang['lockexpire']            = 'ताल्चा अवधि सकिने :';
 $lang['willexpire']            = 'तपाईलले यो पृष्ठ सम्पादन गर्न लगाउनु भएको ताल्चाको अवधि एक मिनेट भित्र सकिदै छ। \n द्वन्द हुन नदिन  पूर्वरुप वा ताल्चा समय परिवर्तन गर्नुहोस् ।';
-$lang['notsavedyet']           = 'तपाईले वचन गर्नु नभएको परिवर्रन हराउने छ। \n साच्चै जारी गर्नुहुन्छ ।';
+$lang['js']['notsavedyet']     = "तपाईले वचन गर्नु नभएको परिवर्रन हराउने छ। \n साच्चै जारी गर्नुहुन्छ ।";
 $lang['rssfailed']             = 'यो फिड लिइ आउदा गल्ति भयो ।';
 $lang['nothingfound']          = 'केहि पनि भेटिएन ।';
 $lang['mediaselect']           = 'मिडिया फाइलहरू ';
@@ -141,7 +140,6 @@ $lang['mail_newpage']          = 'थपिएको पृष्ठ';
 $lang['mail_changed']          = 'परिवर्तित पृष्ठ';
 $lang['mail_new_user']         = 'नयाँ प्रयोगकर्ता ';
 $lang['mail_upload']           = 'अपलोड गरिएको फाइल';
-$lang['qb_alert']              = 'तपाईले  ढाचाबद्ध गर्न चाहनु भएको  पाठ प्रविष्ठ गर्नुहोस्  ।\n यो कागजातको अन्तमा जोडिने छ।';
 $lang['qb_bold']               = 'मोटो पाठ(बोल्ड)';
 $lang['qb_italic']             = 'इटालिक पाठ';
 $lang['qb_underl']             = 'निम्न रेखांकित(अन्डरलाइन) पाठ';
@@ -161,7 +159,7 @@ $lang['qb_media']              = 'तस्विर र अरु फाइल
 $lang['qb_sig']                = 'हस्ताक्षर थप्नुहोस् ';
 $lang['qb_smileys']            = 'स्माइलीहरु ';
 $lang['qb_chars']              = 'विशेष वर्णहरु ';
-$lang['del_confirm']           = 'साच्चै छानिएका वस्तुहरु मेट्ने हो ?';
+$lang['js']['del_confirm']           = 'साच्चै छानिएका वस्तुहरु मेट्ने हो ?';
 $lang['admin_register']        = 'नयाँ प्रयोगकर्ता थप्नुहोस् ';
 $lang['metaedit']              = 'मेटाडेटा सम्पादन गर्नुहोस्';
 $lang['metasaveerr']           = 'मेटाडाटा लेखन असफल';
