@@ -6,6 +6,11 @@
  * @author Grzegorz Żur <grzegorz.zur@gmail.com>
  * @author Mariusz Kujawski <marinespl@gmail.com>
  * @author Maciej Kurczewski <pipijajko@gmail.com>
+ * @author Sławomir Boczek <slawkens@gmail.com>
+ * @author sleshek@wp.pl
+ * @author Leszek Stachowski <shazarre@gmail.com>
+ * @author maros <dobrimaros@yahoo.pl>
+ * @author Grzegorz Widła <dzesdzes@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -39,15 +44,14 @@ $lang['btn_back']              = 'Wstecz';
 $lang['btn_backlink']          = 'Odnośniki';
 $lang['btn_backtomedia']       = 'Powrót do wyboru pliku';
 $lang['btn_subscribe']         = 'Subskrybuj zmiany';
-$lang['btn_unsubscribe']       = 'Zaprzestań subskrypcji zmian';
-$lang['btn_subscribens']       = 'Subskrybuj zmiany w katalogu';
-$lang['btn_unsubscribens']     = 'Zaprzestań subskrypcji zmian w katalogu';
 $lang['btn_profile']           = 'Aktualizuj profil';
 $lang['btn_reset']             = 'Resetuj';
 $lang['btn_resendpwd']         = 'Prześlij nowe hasło';
 $lang['btn_draft']             = 'Edytuj szkic';
 $lang['btn_recover']           = 'Przywróć szkic';
 $lang['btn_draftdel']          = 'Usuń szkic';
+$lang['btn_revert']            = 'Przywróć';
+$lang['btn_register']          = 'Zarejestruj się!';
 $lang['loggedinas']            = 'Zalogowany jako';
 $lang['user']                  = 'Użytkownik';
 $lang['pass']                  = 'Hasło';
@@ -57,7 +61,6 @@ $lang['passchk']               = 'Powtórz hasło';
 $lang['remember']              = 'Zapamiętaj';
 $lang['fullname']              = 'Imię i nazwisko';
 $lang['email']                 = 'E-mail';
-$lang['register']              = 'Zarejestruj się!';
 $lang['profile']               = 'Profil użytkownika';
 $lang['badlogin']              = 'Nazwa użytkownika lub hasło są nieprawidłowe.';
 $lang['minoredit']             = 'Mniejsze zmiany';
@@ -86,13 +89,46 @@ $lang['resendpwdconfirm']      = 'Prośba o potwierdzenie została przesłana po
 $lang['resendpwdsuccess']      = 'Nowe hasło zostało wysłane pocztą.';
 $lang['license']               = 'Wszystkie treści w tym wiki, którym nie przyporządkowano licencji, podlegają licencji:';
 $lang['licenseok']             = 'Uwaga: edytując tę stronę zgadzasz się na publikowanie jej treści pod licencją:';
+$lang['searchmedia']           = 'Szukaj pliku o nazwie:';
+$lang['searchmedia_in']        = 'Szukaj w  %s';
 $lang['txt_upload']            = 'Wybierz plik do wysłania';
 $lang['txt_filename']          = 'Nazwa pliku (opcjonalnie)';
 $lang['txt_overwrt']           = 'Nadpisać istniejący plik?';
 $lang['lockedby']              = 'Aktualnie zablokowane przez';
 $lang['lockexpire']            = 'Blokada wygasa';
 $lang['willexpire']            = 'Za minutę Twoja blokada tej strony wygaśnie.\nW celu uniknięcia konfliktów wyświetl podgląd aby odnowić blokadę.';
-$lang['notsavedyet']           = 'Nie zapisane zmiany zostaną utracone.\nCzy na pewno kontynuować?';
+$lang['js']['notsavedyet']     = 'Nie zapisane zmiany zostaną utracone.
+Czy na pewno kontynuować?';
+$lang['js']['searchmedia']     = 'Szukaj plików';
+$lang['js']['keepopen']        = 'Nie zamykaj okna po wyborze';
+$lang['js']['hidedetails']     = 'Ukryj szczegóły';
+$lang['js']['mediatitle']      = 'Ustawienia odnośników';
+$lang['js']['mediadisplay']    = 'Typ odnośnika';
+$lang['js']['mediaalign']      = 'Położenie';
+$lang['js']['mediasize']       = 'Rozmiar grafiki';
+$lang['js']['mediatarget']     = 'Cel odnośnika';
+$lang['js']['mediaclose']      = 'Zamknij';
+$lang['js']['mediainsert']     = 'Wstaw';
+$lang['js']['mediadisplayimg'] = 'Pokaż grafikę';
+$lang['js']['mediadisplaylnk'] = 'Pokaż tylko odnośnik.';
+$lang['js']['mediasmall']      = 'Mały rozmiar';
+$lang['js']['mediamedium']     = 'Średni rozmiar';
+$lang['js']['medialarge']      = 'Duży rozmiar';
+$lang['js']['mediaoriginal']   = 'Wersja oryginalna';
+$lang['js']['medialnk']        = 'Odnośnik do strony ze szczegółami';
+$lang['js']['mediadirect']     = 'Bezpośredni odnośnik do oryginału';
+$lang['js']['medianolnk']      = 'Bez odnośnika';
+$lang['js']['medianolink']     = 'Nie ustawiaj odnośnika do grafiki';
+$lang['js']['medialeft']       = 'Ustaw położenie po lewej stronie.';
+$lang['js']['mediaright']      = 'Ustaw położenie po prawej stronie.';
+$lang['js']['mediacenter']     = 'Ustaw położenie po środku.';
+$lang['js']['medianoalign']    = 'Nie ustawiaj położenia.';
+$lang['js']['nosmblinks']      = 'Odnośniki do zasobów sieci Windows działają tylko w przeglądarce Internet Explorer.
+Możesz skopiować odnośnik.';
+$lang['js']['linkwiz']         = 'Tworzenie odnośników';
+$lang['js']['linkto']          = 'Link do';
+$lang['js']['del_confirm']     = 'Czy na pewno usunąć?';
+$lang['js']['mu_btn']          = 'Wyślij wiele plików na raz';
 $lang['rssfailed']             = 'Wystąpił błąd przy pobieraniu tych danych: ';
 $lang['nothingfound']          = 'Nic nie znaleziono.';
 $lang['mediaselect']           = 'Wysyłanie pliku';
@@ -104,16 +140,13 @@ $lang['uploadexist']           = 'Plik już istnieje, nie wykonano operacji.';
 $lang['uploadbadcontent']      = 'Typ pliku "%s" nie odpowiadał jego rozszerzeniu.';
 $lang['uploadspam']            = 'Plik zablokowany przez filtr antyspamowy.';
 $lang['uploadxss']             = 'Plik zablokowany ze względu na podejrzaną zawartość.';
+$lang['uploadsize']            = 'Plik jest za duży (maksymalny rozmiar %s)';
 $lang['deletesucc']            = 'Plik "%s" został usunięty.';
 $lang['deletefail']            = 'Plik "%s" nie został usunięty, sprawdź uprawnienia.';
 $lang['mediainuse']            = 'Plik "%s" nie został usunięty, ponieważ jest używany.';
 $lang['namespaces']            = 'Katalogi';
 $lang['mediafiles']            = 'Dostępne pliki';
-$lang['js']['keepopen']        = 'Nie zamykaj okna po wyborze';
-$lang['js']['hidedetails']     = 'Ukryj szczegóły';
-$lang['js']['nosmblinks']      = 'Odnośniki do zasobów sieci Windows działają tylko w przeglądarce Internet Explorer. 
-Możesz skopiować odnośnik.';
-$lang['js']['mu_btn']          = 'Wyślij wiele plików na raz';
+$lang['accessdenied']          = 'Nie masz uprawnień, żeby wyświetlić tę stronę.';
 $lang['mediausage']            = 'Użyj następującej składni w odnośniku do tego pliku:';
 $lang['mediaview']             = 'Pokaż oryginalny plik';
 $lang['mediaroot']             = 'główny';
@@ -129,6 +162,7 @@ $lang['current']               = 'aktualna';
 $lang['yours']                 = 'Twoja wersja';
 $lang['diff']                  = 'Pokaż różnice między wersjami';
 $lang['diff2']                 = 'Pokaż różnice między zaznaczonymi wersjami';
+$lang['difflink']              = 'Odnośnik do tego porównania';
 $lang['line']                  = 'Linia';
 $lang['breadcrumb']            = 'Ślad';
 $lang['youarehere']            = 'Jesteś tutaj';
@@ -140,11 +174,12 @@ $lang['restored']              = 'przywrócono poprzednią wersję';
 $lang['external_edit']         = 'edycja zewnętrzna';
 $lang['summary']               = 'Opis zmian';
 $lang['noflash']               = 'Plugin <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> jest niezbędny do obejrzenia tej zawartości.';
+$lang['download']              = 'Pobierz zrzut';
 $lang['mail_newpage']          = 'Strona dodana:';
 $lang['mail_changed']          = 'Strona zmieniona:';
+$lang['mail_subscribe_list']   = 'Zmienione strony w katalogu:';
 $lang['mail_new_user']         = 'Nowy użytkownik:';
 $lang['mail_upload']           = 'Umieszczono plik:';
-$lang['qb_alert']              = 'Wpisz tekst, który chcesz sformatować. \nBędzie on dołączony na koniec strony.';
 $lang['qb_bold']               = 'Pogrubienie';
 $lang['qb_italic']             = 'Pochylenie';
 $lang['qb_underl']             = 'Podkreślenie';
@@ -155,6 +190,11 @@ $lang['qb_h2']                 = 'Nagłówek 2 stopnia';
 $lang['qb_h3']                 = 'Nagłówek 3 stopnia';
 $lang['qb_h4']                 = 'Nagłówek 4 stopnia';
 $lang['qb_h5']                 = 'Nagłówek 5 stopnia';
+$lang['qb_h']                  = 'Nagłówek';
+$lang['qb_hs']                 = 'Wybierz nagłówek';
+$lang['qb_hplus']              = 'Nagłówek wyższego stopnia';
+$lang['qb_hminus']             = 'Nagłówek niższego stopnia';
+$lang['qb_hequal']             = 'Nagłówek tego samego stopnia';
 $lang['qb_link']               = 'Odnośnik wewnętrzny';
 $lang['qb_extlink']            = 'Odnośnik zewnętrzny';
 $lang['qb_hr']                 = 'Linia pozioma';
@@ -164,7 +204,7 @@ $lang['qb_media']              = 'Dodaj obrazek lub inny plik';
 $lang['qb_sig']                = 'Wstaw podpis';
 $lang['qb_smileys']            = 'Emotikony';
 $lang['qb_chars']              = 'Znaki specjalne';
-$lang['del_confirm']           = 'Czy na pewno usunąć?';
+$lang['upperns']               = 'Skok piętro wyżej';
 $lang['admin_register']        = 'Dodawanie użytkownika';
 $lang['metaedit']              = 'Edytuj metadane';
 $lang['metasaveerr']           = 'Zapis metadanych nie powiódł się';
@@ -180,11 +220,22 @@ $lang['img_copyr']             = 'Prawa autorskie';
 $lang['img_format']            = 'Format';
 $lang['img_camera']            = 'Aparat';
 $lang['img_keywords']          = 'Słowa kluczowe';
-$lang['subscribe_success']     = 'Dodano %s do listy subskrypcji strony %s';
-$lang['subscribe_error']       = 'Błąd przy dodawaniu %s do listy subskrypcji strony %s';
-$lang['subscribe_noaddress']   = 'Nie podałeś adresu e-mail przy rejestracji, nie możesz zostać dodany do listy subskrypcji.';
-$lang['unsubscribe_success']   = 'Usunięto %s z listy subskrypcji strony %s';
-$lang['unsubscribe_error']     = 'Błąd przy usuwaniu %s z listy subskrypcji strony %s';
+$lang['subscr_subscribe_success'] = 'Dodano %s do listy subskrypcji %s';
+$lang['subscr_subscribe_error'] = 'Błąd podczas dodawania %s do listy subskrypcji %s';
+$lang['subscr_subscribe_noaddress'] = 'Brak adresu skojarzonego z twoim loginem, nie możesz zostać dodany(a) do listy subskrypcji';
+$lang['subscr_unsubscribe_success'] = 'Usunięto %s z listy subskrypcji %s';
+$lang['subscr_unsubscribe_error'] = 'Błąd podczas usuwania %s z listy subskrypcji %s';
+$lang['subscr_already_subscribed'] = '%s jest już subskrybowany(a) przez %s';
+$lang['subscr_not_subscribed'] = '%s nie jest subskrybowany(a) przez %s';
+$lang['subscr_m_not_subscribed'] = 'Obecnie nie subskrybujesz bieżącej strony lub katalogu.';
+$lang['subscr_m_new_header']   = 'Dodaj subskrypcję';
+$lang['subscr_m_current_header'] = 'Aktualne subskrypcje';
+$lang['subscr_m_unsubscribe']  = 'Zrezygnuj z subskrypcji';
+$lang['subscr_m_subscribe']    = 'Subskrybuj';
+$lang['subscr_m_receive']      = 'Otrzymuj';
+$lang['subscr_style_every']    = 'email przy każdej zmianie';
+$lang['subscr_style_digest']   = 'email ze streszczeniem zmian dla każdej ze stron';
+$lang['subscr_style_list']     = 'lista zmienionych stron od czasu ostatniego emaila';
 $lang['authmodfailed']         = 'Błąd uwierzytelnienia. Powiadom administratora tego wiki.';
 $lang['authtempfail']          = 'Uwierzytelnienie użytkownika jest w tej chwili niemożliwe. Jeśli ta sytuacja się powtórzy, powiadom administratora tego wiki.';
 $lang['i_chooselang']          = 'Wybierz język';
@@ -209,6 +260,7 @@ $lang['i_pol0']                = 'Otwarte Wiki (odczyt, zapis i dodawanie plikó
 $lang['i_pol1']                = 'Publiczne Wiki (odczyt dla wszystkich, zapis i dodawanie plików tylko dla zarejestrowanych użytkowników)';
 $lang['i_pol2']                = 'Zamknięte Wiki (odczyt, zapis i dodawanie plików tylko dla zarejestrowanych użytkowników)';
 $lang['i_retry']               = 'Spróbuj ponownie';
+$lang['i_license']             = 'Wybierz licencję, na warunkach której chcesz udostępniać treści:';
 $lang['mu_intro']              = 'Możesz tutaj wysłać wiele plików na raz. Kliknij przycisk "Przeglądaj" aby dodać je do kolejki. Kliknij "Wyślij" gdy skończysz.';
 $lang['mu_gridname']           = 'Nazwa pliku';
 $lang['mu_gridsize']           = 'Rozmiar';
@@ -222,4 +274,14 @@ $lang['mu_fail']               = 'nie powiodło się';
 $lang['mu_authfail']           = 'sesja wygasła';
 $lang['mu_progress']           = '@PCT@% wysłano';
 $lang['mu_filetypes']          = 'Dozwolone typy plików';
+$lang['mu_info']               = 'wysłanych plików.';
+$lang['mu_lasterr']            = 'Ostatni błąd:';
 $lang['recent_global']         = 'W tej chwili przeglądasz zmiany w katalogu <b>%s</b>. Możesz przejrzeć także <a href="%s">zmiany w całym wiki</a>.';
+$lang['years']                 = '%d lat temu';
+$lang['months']                = '%d miesięcy temu';
+$lang['weeks']                 = '%d tygodni temu';
+$lang['days']                  = '%d dni temu';
+$lang['hours']                 = '%d godzin temu';
+$lang['minutes']               = '%d minut temu';
+$lang['seconds']               = '%d sekund temu';
+$lang['wordblock']             = 'Twoje ustawienia nie zostały zapisane ponieważ zawierają niedozwoloną treść (spam).';
