@@ -13,6 +13,10 @@
  * @author Jeferson Propheta <jeferson.propheta@gmail.com>
  * @author jair.henrique@gmail.com
  * @author Luis Dantas <luis@dantas.com>
+ * @author Luis Dantas <luisdantas@gmail.com>
+ * @author Jair Henrique <jair.henrique@gmail.com>
+ * @author Sergio Motta <sergio@cisne.com.br>
+ * @author Isaias Masiero Filho <masiero@masiero.org>
  * @author Frederico Guimarães <frederico@teia.bio.br>
  */
 $lang['encoding']              = 'utf-8';
@@ -38,7 +42,7 @@ $lang['btn_upload']            = 'Enviar';
 $lang['btn_cancel']            = 'Cancelar';
 $lang['btn_index']             = 'Índice';
 $lang['btn_secedit']           = 'Editar';
-$lang['btn_login']             = 'Autenticar-se';
+$lang['btn_login']             = 'Entrar';
 $lang['btn_logout']            = 'Sair';
 $lang['btn_admin']             = 'Administrar';
 $lang['btn_update']            = 'Atualizar';
@@ -46,26 +50,24 @@ $lang['btn_delete']            = 'Excluir';
 $lang['btn_back']              = 'Voltar';
 $lang['btn_backlink']          = 'Links reversos';
 $lang['btn_backtomedia']       = 'Voltar à seleção do arquivo de mídia';
-$lang['btn_subscribe']         = 'Monitorar alterações na página';
-$lang['btn_unsubscribe']       = 'Cancelar monitoramento da página';
-$lang['btn_subscribens']       = 'Monitorar alterações no espaço de nomes';
-$lang['btn_unsubscribens']     = 'Cancelar monitoramento do espaço de nomes';
+$lang['btn_subscribe']         = 'Monitorar alterações';
 $lang['btn_profile']           = 'Atualizar o perfil';
 $lang['btn_reset']             = 'Limpar';
-$lang['btn_resendpwd']         = 'Enviar uma nova senha';
+$lang['btn_resendpwd']         = 'Envie-me uma nova senha';
 $lang['btn_draft']             = 'Editar o rascunho';
 $lang['btn_recover']           = 'Recuperar o rascunho';
 $lang['btn_draftdel']          = 'Excluir o rascunho';
-$lang['loggedinas']            = 'Autenticado(a) como';
+$lang['btn_revert']            = 'Restaurar';
+$lang['btn_register']          = 'Cadastre-se';
+$lang['loggedinas']            = 'Identificado(a) como';
 $lang['user']                  = 'Nome de usuário';
 $lang['pass']                  = 'Senha';
 $lang['newpass']               = 'Nova senha';
 $lang['oldpass']               = 'Confirme a senha atual';
-$lang['passchk']               = 'mais uma vez';
+$lang['passchk']               = 'Outra vez';
 $lang['remember']              = 'Lembre-se de mim';
 $lang['fullname']              = 'Nome completo';
 $lang['email']                 = 'E-mail';
-$lang['register']              = 'Registrar';
 $lang['profile']               = 'Perfil do usuário';
 $lang['badlogin']              = 'Desculpe, mas o nome de usuário ou a senha estão incorretos.';
 $lang['minoredit']             = 'Alterações mínimas';
@@ -79,12 +81,12 @@ $lang['regmailfail']           = 'Aparentemente ocorreu um erro no envio da senh
 $lang['regbadmail']            = 'O endereço de e-mail fornecido é, aparentemente, inválido - se você acha que isso é um erro, entre em contato com o administrador';
 $lang['regbadpass']            = 'As senhas digitadas não são idênticas. Por favor, tente novamente.';
 $lang['regpwmail']             = 'A sua senha do DokuWiki';
-$lang['reghere']               = 'Ainda não tem uma conta? Cadastre-se para obter uma.';
+$lang['reghere']               = 'Ainda não tem uma conta? Crie uma';
 $lang['profna']                = 'Esse wiki não suporta modificações do perfil.';
 $lang['profnochange']          = 'Sem alterações, nada para fazer.';
 $lang['profnoempty']           = 'Não são permitidos nomes ou endereços de e-mail em branco.';
 $lang['profchanged']           = 'O perfil do usuário foi atualizado com sucesso.';
-$lang['pwdforget']             = 'Esqueceu sua senha? Obtenha uma nova.';
+$lang['pwdforget']             = 'Esqueceu sua senha? Solicite outra';
 $lang['resendna']              = 'Esse wiki não tem suporte para o reenvio de senhas.';
 $lang['resendpwd']             = 'Enviar a nova senha para';
 $lang['resendpwdmissing']      = 'Desculpe, você deve preencher todos os campos.';
@@ -94,13 +96,46 @@ $lang['resendpwdconfirm']      = 'Um link de confirmação foi enviado por e-mai
 $lang['resendpwdsuccess']      = 'Sua nova senha foi enviada por e-mail.';
 $lang['license']               = 'Exceto onde for informado ao contrário, o conteúdo neste wiki está sob a seguinte licença:';
 $lang['licenseok']             = 'Observe: editando esta página você aceita disponibilizar o seu conteúdo sob a seguinte licença:';
+$lang['searchmedia']           = 'Buscar arquivo:';
+$lang['searchmedia_in']        = 'Buscar em %s';
 $lang['txt_upload']            = 'Selecione o arquivo a ser enviado';
 $lang['txt_filename']          = 'Enviar como (opcional)';
 $lang['txt_overwrt']           = 'Substituir o arquivo existente';
 $lang['lockedby']              = 'Atualmente bloqueada por';
 $lang['lockexpire']            = 'O bloqueio expira em';
 $lang['willexpire']            = 'O seu bloqueio de edição deste página irá expirar em um minuto.\nPara evitar conflitos de edição, clique no botão de visualização para reiniciar o temporizador de bloqueio.';
-$lang['notsavedyet']           = 'As alterações não salvas serão perdidas.\nDeseja realmente continuar?';
+$lang['js']['notsavedyet']     = 'As alterações não salvas serão perdidas.
+Deseja realmente continuar?';
+$lang['js']['searchmedia']     = 'Buscar por arquivos';
+$lang['js']['keepopen']        = 'Manter a janela aberta na seleção';
+$lang['js']['hidedetails']     = 'Esconder detalhes';
+$lang['js']['mediatitle']      = 'Configurações do Link';
+$lang['js']['mediadisplay']    = 'Tipo de Link';
+$lang['js']['mediaalign']      = 'Alinhamento';
+$lang['js']['mediasize']       = 'Tamanho da Imagem';
+$lang['js']['mediatarget']     = 'Alvo do Link';
+$lang['js']['mediaclose']      = 'Fechar';
+$lang['js']['mediainsert']     = 'Inserir';
+$lang['js']['mediadisplayimg'] = 'Mostrar Imagem.';
+$lang['js']['mediadisplaylnk'] = 'Mostrar apenas Link.';
+$lang['js']['mediasmall']      = 'Versão Pequena';
+$lang['js']['mediamedium']     = 'Versão Média';
+$lang['js']['medialarge']      = 'Versão Grande';
+$lang['js']['mediaoriginal']   = 'Versão Original';
+$lang['js']['medialnk']        = 'Link para página de detalhes';
+$lang['js']['mediadirect']     = 'Link direto para original';
+$lang['js']['medianolnk']      = 'Sem Link';
+$lang['js']['medianolink']     = 'Sem link na imagem';
+$lang['js']['medialeft']       = 'Alinhamento de imagem a esquerda';
+$lang['js']['mediaright']      = 'Alinhamento de imagem a direita';
+$lang['js']['mediacenter']     = 'Alinhamento de imagem ao centro';
+$lang['js']['medianoalign']    = 'Sem alinhamento';
+$lang['js']['nosmblinks']      = 'Atalhos para pastas compartilhadas do Windows funcionam apenas no Microsoft Internet Explorer.
+Entretanto, você ainda pode copiar e colar o atalho.';
+$lang['js']['linkwiz']         = 'Link Wizard';
+$lang['js']['linkto']          = 'Link para:';
+$lang['js']['del_confirm']     = 'Deseja realmente excluir o(s) item(ns) selecionado(s)?';
+$lang['js']['mu_btn']          = 'Enviar vários arquivos de uma vez';
 $lang['rssfailed']             = 'Ocorreu um erro durante a atualização dessa fonte: ';
 $lang['nothingfound']          = 'Não foi encontrado nada.';
 $lang['mediaselect']           = 'Arquivos de mídia';
@@ -116,13 +151,9 @@ $lang['uploadsize']            = 'O arquivo transmitido era grande demais. (max.
 $lang['deletesucc']            = 'O arquivo "%s" foi excluído.';
 $lang['deletefail']            = 'Não foi possível excluir "%s" - verifique as permissões.';
 $lang['mediainuse']            = 'O arquivo "%s" não foi excluído - ele ainda está em uso.';
-$lang['namespaces']            = 'Espaços de nome';
+$lang['namespaces']            = 'Espaços de nomes';
 $lang['mediafiles']            = 'Arquivos disponíveis em';
-$lang['js']['keepopen']        = 'Manter a janela aberta na seleção';
-$lang['js']['hidedetails']     = 'Esconder detalhes';
-$lang['js']['nosmblinks']      = 'Atalhos para pastas compartilhadas do Windows funcionam apenas no Microsoft Internet Explorer.
-Entretanto, você ainda pode copiar e colar o atalho.';
-$lang['js']['mu_btn']          = 'Enviar vários arquivos de uma vez';
+$lang['accessdenied']          = 'Você não tem permissão para visualizar esta página.';
 $lang['mediausage']            = 'Use a seguinte sintaxe para referenciar esse arquivo:';
 $lang['mediaview']             = 'Ver o arquivo original';
 $lang['mediaroot']             = 'raiz';
@@ -138,6 +169,10 @@ $lang['current']               = 'atual';
 $lang['yours']                 = 'Sua versão';
 $lang['diff']                  = 'Mostrar diferenças com a revisão atual';
 $lang['diff2']                 = 'Mostrar diferenças entre as revisões selecionadas';
+$lang['difflink']              = 'Link para esta página de comparações';
+$lang['diff_type']             = 'Ver as diferenças:';
+$lang['diff_inline']           = 'Mescladas';
+$lang['diff_side']             = 'Lado a lado';
 $lang['line']                  = 'Linha';
 $lang['breadcrumb']            = 'Visitou';
 $lang['youarehere']            = 'Você está aqui';
@@ -148,22 +183,28 @@ $lang['created']               = 'criada';
 $lang['restored']              = 'revisão anterior restaurada';
 $lang['external_edit']         = 'edição externa';
 $lang['summary']               = 'Resumo da edição';
-$lang['noflash']               = 'O <a href="http://www.adobe.com/products/flashplayer/">Plugin Adobe Flash</a> é necessário para exibir este conteúdo.';
+$lang['noflash']               = 'O <a href="http://www.adobe.com/products/flashplayer/">plug-in Adobe Flash</a> é necessário para exibir este conteúdo.';
+$lang['download']              = 'Download Snippet';
 $lang['mail_newpage']          = 'página adicionada:';
 $lang['mail_changed']          = 'página modificada:';
+$lang['mail_subscribe_list']   = 'páginas alteradas no espaço de nomes:';
 $lang['mail_new_user']         = 'novo usuário:';
 $lang['mail_upload']           = 'arquivo enviado:';
-$lang['qb_alert']              = 'Por favor, insira o texto que você deseja formatar.\nEle será adicionado ao final do documento.';
 $lang['qb_bold']               = 'Texto em negrito';
 $lang['qb_italic']             = 'Texto em itálico';
 $lang['qb_underl']             = 'Texto sublinhado';
 $lang['qb_code']               = 'Texto de código';
-$lang['qb_strike']             = 'Texto riscado';
+$lang['qb_strike']             = 'Texto tachado';
 $lang['qb_h1']                 = 'Cabeçalho de nível 1';
 $lang['qb_h2']                 = 'Cabeçalho de nível 2';
 $lang['qb_h3']                 = 'Cabeçalho de nível 3';
 $lang['qb_h4']                 = 'Cabeçalho de nível 4';
 $lang['qb_h5']                 = 'Cabeçalho de nível 5';
+$lang['qb_h']                  = 'Cabeçalho';
+$lang['qb_hs']                 = 'Escolha o cabeçalho';
+$lang['qb_hplus']              = 'Cabeçalho de nível mais alto';
+$lang['qb_hminus']             = 'Cabeçalho de nível mais baixo';
+$lang['qb_hequal']             = 'Cabeçalho de mesmo nível';
 $lang['qb_link']               = 'Link interno';
 $lang['qb_extlink']            = 'Link externo';
 $lang['qb_hr']                 = 'Linha horizontal';
@@ -173,7 +214,7 @@ $lang['qb_media']              = 'Adicionar imagens e/ou outros arquivos';
 $lang['qb_sig']                = 'Inserir assinatura';
 $lang['qb_smileys']            = 'Carinhas';
 $lang['qb_chars']              = 'Caracteres especiais';
-$lang['del_confirm']           = 'Deseja realmente excluir o(s) item(ns) selecionado(s)?';
+$lang['upperns']               = 'Pular para namespace acima';
 $lang['admin_register']        = 'Adicionar novo usuário';
 $lang['metaedit']              = 'Editar metadados';
 $lang['metasaveerr']           = 'Não foi possível escrever os metadados';
@@ -189,11 +230,22 @@ $lang['img_copyr']             = 'Direitos autorais';
 $lang['img_format']            = 'Formato';
 $lang['img_camera']            = 'Câmera';
 $lang['img_keywords']          = 'Palavras-chave';
-$lang['subscribe_success']     = '%s foi adicionado à lista de monitoramento de %s';
-$lang['subscribe_error']       = 'Ocorreu um erro ao tentar adicionar %s à lista de monitoramento de %s';
-$lang['subscribe_noaddress']   = 'Não existe nenhum endereço de e-mail associado ao seu usuário, você não pode ser adicionado à lista de monitoramento.';
-$lang['unsubscribe_success']   = '%s foi removido da lista de monitoramento de %s';
-$lang['unsubscribe_error']     = 'Ocorreu um erro ao tentar remover %s da lista de monitoramento de %s';
+$lang['subscr_subscribe_success'] = 'Adicionado %s à lista de monitoramentos de %s';
+$lang['subscr_subscribe_error'] = 'Ocorreu um erro na adição de %s à lista de monitoramentos de %s';
+$lang['subscr_subscribe_noaddress'] = 'Como não há nenhum endereço associado ao seu usuário, você não pode ser adicionado à lista de monitoramento';
+$lang['subscr_unsubscribe_success'] = '%s foi removido da lista de monitoramento de %s';
+$lang['subscr_unsubscribe_error'] = 'Ocorreu um erro na remoção de %s da lista de monitoramentos de %s';
+$lang['subscr_already_subscribed'] = '%s já está monitorando s%';
+$lang['subscr_not_subscribed'] = 's% não está monitorando s%';
+$lang['subscr_m_not_subscribed'] = 'Você não está monitorando nem a página atual nem o espaço de nomes.';
+$lang['subscr_m_new_header']   = 'Adicionar monitoramento';
+$lang['subscr_m_current_header'] = 'Monitoramentos atuais';
+$lang['subscr_m_unsubscribe']  = 'Cancelar monitoramento';
+$lang['subscr_m_subscribe']    = 'Monitorar';
+$lang['subscr_m_receive']      = 'Receber';
+$lang['subscr_style_every']    = 'um e-mail a cada modificação';
+$lang['subscr_style_digest']   = 'um agrupamento de e-mails com as mudanças para cada página (a cada %.2f dias)';
+$lang['subscr_style_list']     = 'uma lista de páginas modificadas desde o último e-mail (a cada %.2f dias)';
 $lang['authmodfailed']         = 'A configuração da autenticação de usuário está com problemas. Por favor, informe ao administrador do wiki.';
 $lang['authtempfail']          = 'A autenticação de usuários está temporariamente desabilitada. Se essa situação persistir, por favor, informe ao administrador do Wiki.';
 $lang['i_chooselang']          = 'Selecione o seu idioma';
@@ -218,6 +270,7 @@ $lang['i_pol0']                = 'Wiki aberto (leitura, escrita e envio de arqui
 $lang['i_pol1']                = 'Wiki público (leitura por todos, escrita e envio de arquivos por usuários registrados)';
 $lang['i_pol2']                = 'Wiki fechado (leitura, escrita e envio de arquivos somente por usuários registrados)';
 $lang['i_retry']               = 'Tentar novamente';
+$lang['i_license']             = 'Por favor escolha a licença que voce deseja utilizar para seu conteúdo:';
 $lang['mu_intro']              = 'Aqui você pode enviar vários arquivos de uma só vez. Clique no botão de navegação e adicione-os à fila. Pressione Enviar quando estiver pronto.';
 $lang['mu_gridname']           = 'Nome do arquivo';
 $lang['mu_gridsize']           = 'Tamanho';
@@ -231,4 +284,14 @@ $lang['mu_fail']               = 'falhou';
 $lang['mu_authfail']           = 'a sessão expirou';
 $lang['mu_progress']           = '@PCT@% enviado';
 $lang['mu_filetypes']          = 'Tipos de arquivo permitidos';
+$lang['mu_info']               = 'arquivos enviados.';
+$lang['mu_lasterr']            = 'Erro mais recente:';
 $lang['recent_global']         = 'Você está observando as alterações dentro do espaço de nomes <b>%s</b>. Também é possível ver as <a href="%s">modificações recentes no wiki inteiro</a>.';
+$lang['years']                 = '%d anos atrás';
+$lang['months']                = '%d meses atrás';
+$lang['weeks']                 = '%d semanas atrás';
+$lang['days']                  = '%d dias atrás';
+$lang['hours']                 = '%d horas atrás';
+$lang['minutes']               = '%d minutos atrás';
+$lang['seconds']               = '%d segundos atrás';
+$lang['wordblock']             = 'Suas mudanças não foram salvas pois contem texto bloqueados (spam)';
