@@ -25,7 +25,7 @@ $lang['btn_preview']           = 'Náhľad';
 $lang['btn_top']               = 'Hore';
 $lang['btn_newer']             = '<< novšie';
 $lang['btn_older']             = 'staršie >>';
-$lang['btn_revs']              = 'Staršia verzia';
+$lang['btn_revs']              = 'Staršie verzie';
 $lang['btn_recent']            = 'Posledné úpravy';
 $lang['btn_upload']            = 'Nahrať';
 $lang['btn_cancel']            = 'Storno';
@@ -37,18 +37,17 @@ $lang['btn_admin']             = 'Admin';
 $lang['btn_update']            = 'Aktualizovať';
 $lang['btn_delete']            = 'Zmazať';
 $lang['btn_back']              = 'Späť';
-$lang['btn_backlink']          = 'Spätné linky';
+$lang['btn_backlink']          = 'Spätné odkazy';
 $lang['btn_backtomedia']       = 'Späť na výber média';
-$lang['btn_subscribe']         = 'Posielať zmeny';
-$lang['btn_unsubscribe']       = 'Neposielať zmeny';
-$lang['btn_subscribens']       = 'Posielať zmeny menných priestorov';
-$lang['btn_unsubscribens']     = 'Neposielať zmeny menných priestorov';
+$lang['btn_subscribe']         = 'Sledovať zmeny';
 $lang['btn_profile']           = 'Aktualizovať profil';
 $lang['btn_reset']             = 'Zrušiť';
 $lang['btn_resendpwd']         = 'Poslať nové heslo';
 $lang['btn_draft']             = 'Upraviť koncept';
 $lang['btn_recover']           = 'Obnoviť koncept';
 $lang['btn_draftdel']          = 'Zmazať koncept';
+$lang['btn_revert']            = 'Obnoviť';
+$lang['btn_register']          = 'Registrovať';
 $lang['loggedinas']            = 'Prihlásený(á) ako';
 $lang['user']                  = 'Užívateľské meno';
 $lang['pass']                  = 'Heslo';
@@ -58,27 +57,26 @@ $lang['passchk']               = 'Ešte raz znovu';
 $lang['remember']              = 'Zapamätaj si ma';
 $lang['fullname']              = 'Celé meno';
 $lang['email']                 = 'E-Mail';
-$lang['register']              = 'Registrovať';
 $lang['profile']               = 'Užívateľský profil';
 $lang['badlogin']              = 'Zadané užívateľské meno a heslo nie je správne.';
 $lang['minoredit']             = 'Menšie zmeny';
 $lang['draftdate']             = 'Koncept automaticky uložený';
-$lang['nosecedit']             = 'Skránka bola medzičasom zmenená, informácie o sekcii sú zastaralé a z tohto dôvodu bola nahraná celá stránka.';
+$lang['nosecedit']             = 'Stránka bola medzičasom zmenená, informácie o sekcii sú zastaralé a z tohto dôvodu bola nahraná celá stránka.';
 $lang['regmissing']            = 'Musíte vyplniť všetky údaje.';
 $lang['reguexists']            = 'Užívateľ s rovnakým menom je už zaregistrovaný.';
-$lang['regsuccess']            = 'Užívateľský účet bol vytvorený a heslo zaslané mailom.';
+$lang['regsuccess']            = 'Užívateľský účet bol vytvorený a heslo zaslané emailom.';
 $lang['regsuccess2']           = 'Užívateľský účet bol vytvorený.';
 $lang['regmailfail']           = 'Zdá sa, že nastala chyba pri posielaní mailu s heslom. Skúste kontaktovať správcu.';
-$lang['regbadmail']            = 'Zadaná mailová adresa nie je platná. Pokiaľ si myslíte, že to je zle, skúste kontaktovať správcu.';
-$lang['regbadpass']            = 'Dve zadané heslá nie sú rovnaké, skúste prosím znovu.';
+$lang['regbadmail']            = 'Zadaná emailová adresa nie je platná. Pokiaľ si myslíte, že to je zle, skúste kontaktovať správcu.';
+$lang['regbadpass']            = 'Zadané heslá nie sú rovnaké, zadajte ich prosím znovu.';
 $lang['regpwmail']             = 'Vaše heslo do systému DokuWiki';
-$lang['reghere']               = 'Nemáte uživateľský účet? Vytvorte si ho';
-$lang['profna']                = 'Toto wiki nepodporuje zmenu profilu';
+$lang['reghere']               = 'Nemáte užívateľský účet? Vytvorte si ho';
+$lang['profna']                = 'Táto wiki nepodporuje zmenu profilu';
 $lang['profnochange']          = 'Žiadne zmeny, nie je čo robiť.';
-$lang['profnoempty']           = 'Prázdne meno, alebo e-mailová adresa nie sú povolené.';
+$lang['profnoempty']           = 'Prázdne meno alebo mailová adresa nie sú povolené.';
 $lang['profchanged']           = 'Užívateľský účet úspešne zmenený.';
 $lang['pwdforget']             = 'Zabudli ste heslo? Získajte nové!';
-$lang['resendna']              = 'Toto wiki nepodporuje znovuposielanie hesla.';
+$lang['resendna']              = 'Táto wiki nepodporuje opätovné zasielanie hesla.';
 $lang['resendpwd']             = 'Pošli nové heslo pre';
 $lang['resendpwdmissing']      = 'Prepáčte, musíte vyplniť všetky polia.';
 $lang['resendpwdnouser']       = 'Prepáčte, nemôžeme nájsť zadaného užívateľa v databáze.';
@@ -87,13 +85,46 @@ $lang['resendpwdconfirm']      = 'Autorizačný odkaz bol zaslaný na e-mail.';
 $lang['resendpwdsuccess']      = 'Vaše nové heslo bolo zaslané na e-mail.';
 $lang['license']               = 'Ak nie je uvedené inak, obsah tejto wiki je uverejnený pod nasledujúcou licenciou:';
 $lang['licenseok']             = 'Poznámka: Zmenou tejto stránky súhlasíte s uverejnením obsahu pod nasledujúcou licenciou:';
+$lang['searchmedia']           = 'Hľadať meno súboru:';
+$lang['searchmedia_in']        = 'Hľadať v %s';
 $lang['txt_upload']            = 'Vyberte súbor ako prílohu';
-$lang['txt_filename']          = 'Wiki meno (volitelné)';
+$lang['txt_filename']          = 'Uložiť ako (voliteľné)';
 $lang['txt_overwrt']           = 'Prepísať existujúci súbor';
 $lang['lockedby']              = 'Práve zamknuté:';
-$lang['lockexpire']            = 'Zámok vyprší:';
-$lang['willexpire']            = 'Váš zámok pre editáciu za chvílu vyprší.\nAby ste predišli konfliktom, stlačte tlačítko Náhľad a zámok sa predĺži.';
-$lang['notsavedyet']           = 'Neuložené zmeny budú stratené.\nChcete naozaj pokračovať?';
+$lang['lockexpire']            = 'Zámok stratí platnosť:';
+$lang['willexpire']            = 'Váš zámok pre editáciu za chvíľu stratí platnosť.\nAby ste predišli konfliktom, stlačte tlačítko Náhľad a zámok sa predĺži.';
+$lang['js']['notsavedyet']     = 'Neuložené zmeny budú stratené.
+Chcete naozaj pokračovať?';
+$lang['js']['searchmedia']     = 'Hľadať súbory';
+$lang['js']['keepopen']        = 'Po vybraní súboru ponechať okno otvorené';
+$lang['js']['hidedetails']     = 'Skryť detaily';
+$lang['js']['mediatitle']      = 'Nastavenia odkazu';
+$lang['js']['mediadisplay']    = 'Typ odkazu';
+$lang['js']['mediaalign']      = 'Zarovnanie';
+$lang['js']['mediasize']       = 'Veľkosť obrázku';
+$lang['js']['mediatarget']     = 'Cieľ odkazu';
+$lang['js']['mediaclose']      = 'Zatvoriť';
+$lang['js']['mediainsert']     = 'Vložiť';
+$lang['js']['mediadisplayimg'] = 'Zobraziť obrázok.';
+$lang['js']['mediadisplaylnk'] = 'Zobraziť iba odkaz.';
+$lang['js']['mediasmall']      = 'Malý';
+$lang['js']['mediamedium']     = 'Stredný';
+$lang['js']['medialarge']      = 'Veľký';
+$lang['js']['mediaoriginal']   = 'Originál';
+$lang['js']['medialnk']        = 'Odkaz na stránku s detailným popisom';
+$lang['js']['mediadirect']     = 'Priamy odkaz na originál';
+$lang['js']['medianolnk']      = 'Žiadny odkaz';
+$lang['js']['medianolink']     = 'Bez odkazu na obrázok';
+$lang['js']['medialeft']       = 'Zarovnať obrázok vľavo.';
+$lang['js']['mediaright']      = 'Zarovnať obrázok vpravo.';
+$lang['js']['mediacenter']     = 'Zarovnať obrázok na stred.';
+$lang['js']['medianoalign']    = 'Nepoužívať zarovnanie.';
+$lang['js']['nosmblinks']      = 'Odkazovanie na zdieľané prostriedky Windows funguje len v Internet Exploreri.
+Aj napriek tomu tento odkaz môžete skopírovať a vložiť inde.';
+$lang['js']['linkwiz']         = 'Sprievodca odkazmi';
+$lang['js']['linkto']          = 'Odkaz na:';
+$lang['js']['del_confirm']     = 'Zmazať túto položku?';
+$lang['js']['mu_btn']          = 'Nahrať viac súborov súčasne';
 $lang['rssfailed']             = 'Nastala chyba pri vytváraní tohto RSS: ';
 $lang['nothingfound']          = 'Nič nenájdené.';
 $lang['mediaselect']           = 'Výber dokumentu';
@@ -101,7 +132,7 @@ $lang['fileupload']            = 'Nahrávanie dokumentu';
 $lang['uploadsucc']            = 'Prenos prebehol v poriadku';
 $lang['uploadfail']            = 'Chyba pri nahrávaní. Možno kvôli zle nastaveným právam?';
 $lang['uploadwrong']           = 'Prenos súboru s takouto príponou nie je dovolený.';
-$lang['uploadexist']           = 'Súbor skutočne existuje. Nie je čo robiť.';
+$lang['uploadexist']           = 'Súbor už existuje. Žiadna akcia.';
 $lang['uploadbadcontent']      = 'Nahraný obsah sa nezhoduje s príponou súboru %s.';
 $lang['uploadspam']            = 'Nahrávanie bolo zablokované spamovým blacklistom.';
 $lang['uploadxss']             = 'Nahrávanie bolo zablokované kvôli potenciálnemu škodlivému obsahu.';
@@ -111,42 +142,43 @@ $lang['deletefail']            = '"%s" nie je možné zmazať - skontrolujte opr
 $lang['mediainuse']            = 'Súbor "%s" nebol zmazaný - je stále používaný.';
 $lang['namespaces']            = 'Menné priestory';
 $lang['mediafiles']            = 'Dostupné súbory';
-$lang['js']['keepopen']        = 'Po vybraní súboru ponechať okno otvorené';
-$lang['js']['hidedetails']     = 'Skryť detaily';
-$lang['js']['nosmblinks']      = 'Odkazovanie na zdielané prostriedky Windows funguje len v Internet Explorer.
-Aj napriek tomu tento odkaz môžete skopírovat a vložit inde.';
-$lang['js']['mu_btn']          = 'Nahrať viac súborov naraz';
+$lang['accessdenied']          = 'Nemáte oprávnenie na zobrazenie požadovanej stránky.';
 $lang['mediausage']            = 'Pre odkázanie na súbor použite nasledujúcu syntax:';
 $lang['mediaview']             = 'Zobraziť pôvodný súbor';
 $lang['mediaroot']             = 'root';
-$lang['mediaupload']           = 'Nahrať súbor do aktuálneho menného priestoru. Pre vytvorenie menného podpriestoru, pridajte jeho názov na začiatok wiki mena (oddelený dvojbodkou)';
+$lang['mediaupload']           = 'Nahrať súbor do aktuálneho menného priestoru. Pre vytvorenie menného podpriestoru, pridajte jeho názov na začiatok mena súboru (oddelený dvojbodkou)';
 $lang['mediaextchange']        = 'Prípona súboru bola zmenená z .%s na .%s!';
 $lang['reference']             = 'Referencie pre';
 $lang['ref_inuse']             = 'Súbor nemôže byť zmazaný, pretože je stále používaný nasledujúcimi stránkami:';
-$lang['ref_hidden']            = 'Niektoré referencie sú na stránky pre ktoré nemáte právo na čítanie';
+$lang['ref_hidden']            = 'Niektoré referencie sú na stránky, pre ktoré nemáte právo na čítanie';
 $lang['hits']                  = '- počet výskytov';
 $lang['quickhits']             = 'Zodpovedajúce stránky';
 $lang['toc']                   = 'Obsah';
 $lang['current']               = 'aktuálne';
 $lang['yours']                 = 'Vaša verzia';
-$lang['diff']                  = 'zobrazit rozdiely voči aktuálnej verzii';
-$lang['diff2']                 = 'Ukázať rozdiely medzi vybranými verziami';
+$lang['diff']                  = 'Zobraziť rozdiely voči aktuálnej verzii';
+$lang['diff2']                 = 'Zobraziť rozdiely medzi vybranými verziami';
+$lang['difflink']              = 'Odkaz na tento prehľad zmien';
+$lang['diff_type']             = 'Prehľad zmien:';
+$lang['diff_inline']           = 'Vnorený';
+$lang['diff_side']             = 'Vedľa seba';
 $lang['line']                  = 'Riadok';
 $lang['breadcrumb']            = 'História';
 $lang['youarehere']            = 'Nachádzate sa';
 $lang['lastmod']               = 'Posledná úprava';
 $lang['by']                    = 'od';
-$lang['deleted']               = 'odstranené';
+$lang['deleted']               = 'odstránené';
 $lang['created']               = 'vytvorené';
-$lang['restored']              = 'stará verzia bola obnovena';
+$lang['restored']              = 'stará verzia bola obnovená';
 $lang['external_edit']         = 'externá úprava';
 $lang['summary']               = 'Komentár k úpravám';
 $lang['noflash']               = 'Pre zobrazenie tohto obsahu potrebujete <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
+$lang['download']              = 'Stiahnuť';
 $lang['mail_newpage']          = 'stránka pridaná:';
 $lang['mail_changed']          = 'stránka zmenená:';
-$lang['mail_new_user']         = 'Nový užívateľ:';
+$lang['mail_subscribe_list']   = 'stránky zmenené v mennom priestore:';
+$lang['mail_new_user']         = 'nový užívateľ:';
 $lang['mail_upload']           = 'nahraný súbor:';
-$lang['qb_alert']              = 'Vložte prosím text, ktorý chcete formátovať.\nTen bude pridaný na koniec dokumentu.';
 $lang['qb_bold']               = 'Tučné';
 $lang['qb_italic']             = 'Kurzíva';
 $lang['qb_underl']             = 'Podčiarknutie';
@@ -157,6 +189,11 @@ $lang['qb_h2']                 = 'Nadpis 2. úrovne';
 $lang['qb_h3']                 = 'Nadpis 3. úrovne';
 $lang['qb_h4']                 = 'Nadpis 4. úrovne';
 $lang['qb_h5']                 = 'Nadpis 5. úrovne';
+$lang['qb_h']                  = 'Nadpis';
+$lang['qb_hs']                 = 'Zvoliť nadpis';
+$lang['qb_hplus']              = 'Nadpis vyššej úrovne';
+$lang['qb_hminus']             = 'Nadpis nižšej úrovne';
+$lang['qb_hequal']             = 'Nadpis predchádzajúcej úrovne';
 $lang['qb_link']               = 'Interný odkaz';
 $lang['qb_extlink']            = 'Externý odkaz';
 $lang['qb_hr']                 = 'Horizontálna linka';
@@ -166,7 +203,7 @@ $lang['qb_media']              = 'Vložiť obrázky alebo iné súbory';
 $lang['qb_sig']                = 'Vložiť podpis';
 $lang['qb_smileys']            = 'Smajlíky';
 $lang['qb_chars']              = 'Špeciálne znaky';
-$lang['del_confirm']           = 'Zmazať túto položku?';
+$lang['upperns']               = 'návrat do nadradeného menného priestoru';
 $lang['admin_register']        = 'Pridaj nového užívateľa';
 $lang['metaedit']              = 'Upraviť metainformácie';
 $lang['metasaveerr']           = 'Zápis metainformácií zlyhal';
@@ -181,45 +218,68 @@ $lang['img_artist']            = 'Fotograf';
 $lang['img_copyr']             = 'Kopírovacie práva';
 $lang['img_format']            = 'Formát';
 $lang['img_camera']            = 'Fotoaparát';
-$lang['img_keywords']          = 'Klúčové slová';
-$lang['subscribe_success']     = 'Pridané %s do zoznamu objednávok pre %s';
-$lang['subscribe_error']       = 'Chyba pri pridaní %s do zoznamu objednávok pre %s';
-$lang['subscribe_noaddress']   = 'Nie je žiadna e-mailová adresa priradená k vašemu menu,nemôžte byť pridaný do zoznamu objednávok';
-$lang['unsubscribe_success']   = 'Odobrané %s zo zoznamu objednávok pre %s';
-$lang['unsubscribe_error']     = 'Chaba pri odobraní %s zo zoznamu objednávok pre %s';
-$lang['authmodfailed']         = 'Užívateľská autentifikácia nie je možná. Prosím informujte  správcu tohto systému.';
-$lang['authtempfail']          = 'Užívateľská autentifikácia je dočasne nedostupná. Ak táto situácia pretrvá, prosím informujte správcu tohto systému.';
+$lang['img_keywords']          = 'Kľúčové slová';
+$lang['subscr_subscribe_success'] = 'Používateľ %s bol pridaný do zoznamu hlásení o zmenách %s';
+$lang['subscr_subscribe_error'] = 'Chyba pri pridaní používateľa %s do zoznamu hlásení o zmenách %s';
+$lang['subscr_subscribe_noaddress'] = 'Vaše prihlasovacie meno nemá priradenú žiadnu email adresu, nemôžete byť pridaný do zoznamu hlásení o zmenách';
+$lang['subscr_unsubscribe_success'] = 'Používateľ %s bol odstránený zo zoznamu hlásení o zmenách %s';
+$lang['subscr_unsubscribe_error'] = 'Chyba pri odstránení používateľa %s zo zoznamu hlásení o zmenách %s';
+$lang['subscr_already_subscribed'] = 'Používateľ %s už je v zozname hlásení o zmenách %s';
+$lang['subscr_not_subscribed'] = 'Používateľ %s nie je v zozname hlásení o zmenách %s';
+$lang['subscr_m_not_subscribed'] = 'Momentálne nesledujete zmeny aktuálnej stránky alebo menného priestoru.';
+$lang['subscr_m_new_header']   = 'Pridať sledovanie zmien';
+$lang['subscr_m_current_header'] = 'Aktuálne sledované zmeny';
+$lang['subscr_m_unsubscribe']  = 'Nesledovať zmeny';
+$lang['subscr_m_subscribe']    = 'Sledovať zmeny';
+$lang['subscr_m_receive']      = 'Dostávať';
+$lang['subscr_style_every']    = 'email pri každej zmene';
+$lang['subscr_style_digest']   = 'email so zhrnutím zmien pre každú stránku (perióda %.2f dňa)';
+$lang['subscr_style_list']     = 'zoznam zmenených stránok od posledného emailu (perióda %.2f dňa)';
+$lang['authmodfailed']         = 'Užívateľská autentifikácia nie je možná. Prosím informujte správcu systému.';
+$lang['authtempfail']          = 'Užívateľská autentifikácia je dočasne nedostupná. Ak táto situácia pretrváva, prosím informujte správcu systému.';
 $lang['i_chooselang']          = 'Zvoľte váš jazyk';
 $lang['i_installer']           = 'DokuWiki inštalátor';
 $lang['i_wikiname']            = 'Názov Wiki';
 $lang['i_enableacl']           = 'Aktivovať ACL (doporučené)';
 $lang['i_superuser']           = 'Správca';
 $lang['i_problems']            = 'Inštalátor narazil na nižšie uvedené problémy. Nemôžete pokračovať, pokiaľ ich neodstránite.';
-$lang['i_modified']            = 'Z bezpečnostných dôvodov bude tento skript fungovať iba s novou, neupravenou inštaláciou Dokuwiki. Môžete buď znovu rozbaliť stiahnutý inštalačný balíček, alebo preštudovať <a href="http://dokuwiki.org/install"> inštalačné inštrukcie Dokuwiki</a>';
+$lang['i_modified']            = 'Z bezpečnostných dôvodov bude tento skript fungovať iba s novou, neupravenou inštaláciou Dokuwiki. Môžete buď znovu rozbaliť stiahnutý inštalačný balík alebo preštudovať <a href="http://dokuwiki.org/install"> inštalačné inštrukcie Dokuwiki</a>';
 $lang['i_funcna']              = 'PHP funkcia <code>%s</code> nie je dostupná. Je možné, že ju z určitých dôvodov zablokoval váš poskytovateľ webhostingu?';
-$lang['i_phpver']              = 'Vaša verzia PHP <code>%s</code> je nižšia ako požadovaná <code>%s</code>. Potrebujete aktualizovať Vašu instaláciu PHP.';
+$lang['i_phpver']              = 'Vaša verzia PHP <code>%s</code> je nižšia ako požadovaná <code>%s</code>. Potrebujete aktualizovať Vašu inštaláciu PHP.';
 $lang['i_permfail']            = '<code>%s</code> nie je zapisovateľný pre DokuWiki. Musíte zmeniť prístupové práva pre tento adresár!';
 $lang['i_confexists']          = '<code>%s</code> už existuje';
 $lang['i_writeerr']            = 'Nie je možné vytvoriť <code>%s</code>. Potrebujete skontrolovať prístupové práva pre adresár/súbor a vytvoriť ho manuálne.';
-$lang['i_badhash']             = 'nerozpoznaný, alebo zmenený súbor dokuwiki.php (hash=<code>%s</code>)';
-$lang['i_badval']              = '<code>%s</code> - bola zadaná nesprávna, alebo žiadna hodnota';
-$lang['i_success']             = 'Konfigurácia bola úspešne ukončená. Teraz môžte zmazať súbor install.php. Pokračujte vo
-                       <a href="doku.php">vašej novej DokuWiki</a>.';
-$lang['i_failure']             = 'Pri zápise konfiguračného súboru nastali nejaké chyby. Potrebujete ich opraviť manuálne pred tým ako budete môcť používať
-                         <a href="doku.php">vašu novú DokuWiki</a>.';
+$lang['i_badhash']             = 'neznámy alebo zmenený súbor dokuwiki.php (hash=<code>%s</code>)';
+$lang['i_badval']              = '<code>%s</code> - nesprávna alebo žiadna hodnota';
+$lang['i_success']             = 'Konfigurácia bola úspešne ukončená. Teraz môžete zmazať súbor install.php. Pokračujte vo <a href="doku.php">vašej novej DokuWiki</a>.';
+$lang['i_failure']             = 'Pri zápise konfiguračného súboru nastali nejaké chyby. Potrebujete ich opraviť manuálne pred tým, ako budete môcť používať <a href="doku.php">vašu novú DokuWiki</a>.';
 $lang['i_policy']              = 'Počiatočná ACL politika';
 $lang['i_pol0']                = 'Otvorená Wiki (čítanie, zápis a nahrávanie pre každého)';
 $lang['i_pol1']                = 'Verejná Wiki (čítanie pre každého, zápis a nahrávanie pre registrovaných užívateľov)';
 $lang['i_pol2']                = 'Uzatvorená Wiki (čítanie, zápis a nahrávanie len pre registrovaných užívateľov)';
 $lang['i_retry']               = 'Skúsiť znovu';
-$lang['mu_intro']              = 'Na tomto mieste môžete nahrávať viac súborov naraz. Tlačidlom Prehľadávať pridáte súbory do zoznamu. Tlačidlom Nahrať vykonáte prenos súborov.';
+$lang['i_license']             = 'Vyberte licenciu, pod ktorou chcete uložiť váš obsah:';
+$lang['mu_intro']              = 'Na tomto mieste môžete nahrávať viac súborov súčasne. Tlačidlom Prehľadávať pridáte súbory do zoznamu. Tlačidlom Nahrať vykonáte prenos súborov.';
 $lang['mu_gridname']           = 'Názov súboru';
 $lang['mu_gridsize']           = 'Veľkosť';
 $lang['mu_gridstat']           = 'Status';
-$lang['mu_namespace']          = 'Oblasť mien';
+$lang['mu_namespace']          = 'Menný priestor';
 $lang['mu_browse']             = 'Prehľadávať';
 $lang['mu_toobig']             = 'príliš veľký';
+$lang['mu_ready']              = 'pripravený na nahratie';
 $lang['mu_done']               = 'dokončený';
 $lang['mu_fail']               = 'neúspešný';
+$lang['mu_authfail']           = 'spojenie stratilo platnosť';
+$lang['mu_progress']           = '@PCT@% nahraných';
 $lang['mu_filetypes']          = 'Povolené typy súborov';
+$lang['mu_info']               = 'nahraných súborov.';
+$lang['mu_lasterr']            = 'Posledná chyba:';
 $lang['recent_global']         = 'Práve prehliadate zmeny v mennom priestore <b>%s</b>. Môžete si tiež pozrieť <a href="%s">aktuálne zmeny celej wiki</a>.';
+$lang['years']                 = 'pred %d rokmi';
+$lang['months']                = 'pred %d mesiacmi';
+$lang['weeks']                 = 'pred %d týždňami';
+$lang['days']                  = 'pred %d dňami';
+$lang['hours']                 = 'pred %d hodinami';
+$lang['minutes']               = 'pred %d minútami';
+$lang['seconds']               = 'pred %d sekundami';
+$lang['wordblock']             = 'Vaše zmeny neboli uložené, pretože obsahovali nepovolený text (spam).';
