@@ -14,6 +14,13 @@
  * @author gb@isis.u-strasbg.fr
  * @author stephane.gully@gmail.com
  * @author Guillaume Turri <guillaume.turri@gmail.com>
+ * @author Erik Pedersen <erik.pedersen@shaw.ca>
+ * @author olivier duperray <duperray.olivier@laposte.net>
+ * @author Vincent Feltz <psycho@feltzv.fr>
+ * @author Philippe Bajoit <philippe.bajoit@gmail.com>
+ * @author Florian Gaub <floriang@floriang.net>
+ * @author Samuel Dorsaz samuel.dorsaz@novelion.net
+ * @author Johan Guilbaud <guilbaud.johan@gmail.com>
  */
 $lang['admin_acl']             = 'Gestion de la liste des contrôles d\'accès (ACL)';
 $lang['acl_group']             = 'Groupe';
@@ -22,15 +29,15 @@ $lang['acl_perms']             = 'Permission pour';
 $lang['page']                  = 'Page';
 $lang['namespace']             = 'Catégorie';
 $lang['btn_select']            = 'Sélectionner';
-$lang['p_user_id']             = 'Permissions actuelles de l\'utilisateur <b class="acluser">%s</b> sur la page <b class="aclpage">%s</b>: <i>%s</i>.';
-$lang['p_user_ns']             = 'Permissions actuelles de l\'utilisateur <b class="acluser">%s</b> sur la catégorie <b class="aclns">%s</b>: <i>%s</i>.';
-$lang['p_group_id']            = 'Permissions actuelles des membres du groupe <b class="aclgroup">%s</b> sur la page <b class="aclpage">%s</b>: <i>%s</i>.';
-$lang['p_group_ns']            = 'Permissions actuelles des membres du groupe <b class="aclgroup">%s</b> sur la catégorie <b class="aclns">%s</b>: <i>%s</i>.';
-$lang['p_choose_id']           = 'Saisissez un nom <b>d\'utilisateur ou de groupe</b> dans le formulaire ci-dessus pour afficher ou éditer les permissions relatives à la page <b class="aclpage">%s</b>.';
-$lang['p_choose_ns']           = 'Saisissez un nom <b>d\'utilisateur ou de groupe</b> dans le formulaire ci-dessous pour afficher ou éditer les permissions relatives à la catégorie <b class="aclns">%s</b>.';
+$lang['p_user_id']             = 'Permissions actuelles de l\'utilisateur <strong class="acluser">%s</strong> sur la page <strong class="aclpage">%s</strong>: <em>%s</em>.';
+$lang['p_user_ns']             = 'Permissions actuelles de l\'utilisateur <strong class="acluser">%s</strong> sur la catégorie <strong class="aclns">%s</strong>: <em>%s</em>.';
+$lang['p_group_id']            = 'Permissions actuelles des membres du groupe <strong class="aclgroup">%s</strong> sur la page <strong class="aclpage">%s</strong>: <em>%s</em>.';
+$lang['p_group_ns']            = 'Permissions actuelles des membres du groupe <strong class="aclgroup">%s</strong> sur la catégorie <strong class="aclns">%s</strong>: <em>%s</em>.';
+$lang['p_choose_id']           = 'Saisissez un nom <strong>d\'utilisateur ou de groupe</strong> dans le formulaire ci-dessus pour afficher ou éditer les permissions relatives à la page <strong class="aclpage">%s</strong>.';
+$lang['p_choose_ns']           = 'Saisissez un nom <strong>d\'utilisateur ou de groupe</strong> dans le formulaire ci-dessous pour afficher ou éditer les permissions relatives à la catégorie <strong class="aclns">%s</strong>.';
 $lang['p_inherited']           = 'Note : Ces permissions n\'ont pas été explicitement fixées mais sont héritées d\'autres groupes ou catégories supérieures.';
 $lang['p_isadmin']             = 'Note : Le groupe ou l\'utilisateur sélectionné dispose de toutes les permissions car il est paramétré en tant que superutilisateur.';
-$lang['p_include']             = 'Les permissions les plus élevées induisent les plus faibles. Création, Télécharger, et Effacer, ne s\'appliquent qu\'aux catégories ; pas aux pages';
+$lang['p_include']             = 'Les permissions les plus élevées induisent les plus faibles. Création, Télécharger et Effacer ne s\'appliquent qu\'aux catégories, pas aux pages.';
 $lang['current']               = 'ACL actuelles';
 $lang['where']                 = 'Page/Catégorie';
 $lang['who']                   = 'Utilisateur/Groupe';
@@ -39,7 +46,7 @@ $lang['acl_perm0']             = 'Aucune';
 $lang['acl_perm1']             = 'Lecture';
 $lang['acl_perm2']             = 'Écriture';
 $lang['acl_perm4']             = 'Création';
-$lang['acl_perm8']             = 'Télécharger';
+$lang['acl_perm8']             = 'Téléverser';
 $lang['acl_perm16']            = 'Effacer';
 $lang['acl_new']               = 'Ajouter une nouvelle entrée';
 $lang['acl_mod']               = 'Modifier l\'entrée';
