@@ -6,29 +6,37 @@
  * @author Felipe Castro <fefcas@gmail.com>
  * @author Felipe Castro <fefcas (cxe) gmail (punkto) com>
  * @author Felipo Kastro <fefcas@gmail.com>
+ * @author Robert Bogenschneider <robog@gmx.de>
+ * @author Erik Pedersen <erik pedersen@shaw.ca>
+ * @author Erik Pedersen <erik.pedersen@shaw.ca>
+ * @author Robert Bogenschneider <robog@GMX.de>
+ * @author Robert BOGENSCHNEIDER <robog@gmx.de>
  */
 $lang['menu']                  = 'Agordaj Difinoj';
 $lang['error']                 = 'La difinoj ne estas ĝisdatigitaj pro malvalida valoro: kompleze reviziu viajn ŝanĝojn kaj resubmetu ilin.
-<br />La malkorekta(j) valoro(j) estas ĉirkaŭita(j) de ruĝa randaĵo.';
+<br />La malkorekta(j) valoro(j) estas ĉirkaŭita(j) de ruĝa kadro.';
 $lang['updated']               = 'La difinoj estis sukcese ĝisdatigitaj.';
 $lang['nochoice']              = '(neniu alia elekto disponeblas)';
 $lang['locked']                = 'La difin-dosiero ne povas esti ĝisdatigita; se tio ne estas intenca, <br /> certiĝu, ke la dosieroj de lokaj difinoj havas korektajn nomojn kaj permesojn.';
-$lang['_configuration_manager'] = 'Administrilo de Agordoj';
+$lang['danger']                = 'Danĝero: ŝanĝo tiun opcion povus igi vian vikion kaj la agordan menuon neatingebla.';
+$lang['warning']               = 'Averto: ŝanĝi tiun opcion povus rezulti en neatendita konduto.';
+$lang['security']              = 'Sekureca averto: ŝanĝi tiun opcion povus krei sekurecan riskon.';
+$lang['_configuration_manager'] = 'Administrilo de agordoj';
 $lang['_header_dokuwiki']      = 'Difinoj por DokuWiki';
-$lang['_header_plugin']        = 'Difinoj por Kromaĵoj';
-$lang['_header_template']      = 'Difinoj por Ŝablonoj';
-$lang['_header_undefined']     = 'Ceteraj Difinoj';
-$lang['_basic']                = 'Bazaj Difinoj';
-$lang['_display']              = 'Difinoj por Montrado';
-$lang['_authentication']       = 'Difinoj por Identiĝo';
-$lang['_anti_spam']            = 'Kontraŭ-spamaj Difinoj';
-$lang['_editing']              = 'Difinoj por Redakto';
-$lang['_links']                = 'Difinoj por Ligiloj';
-$lang['_media']                = 'Difinoj por Audvidaĵoj';
-$lang['_advanced']             = 'Fakaj Difinoj';
-$lang['_network']              = 'Difinoj por Reto';
-$lang['_plugin_sufix']         = 'Difinoj por Kromaĵoj';
-$lang['_template_sufix']       = 'Difinoj por Ŝablonoj';
+$lang['_header_plugin']        = 'Difinoj por kromaĵoj';
+$lang['_header_template']      = 'Difinoj por ŝablonoj';
+$lang['_header_undefined']     = 'Ceteraj difinoj';
+$lang['_basic']                = 'Bazaj difinoj';
+$lang['_display']              = 'Difinoj por montrado';
+$lang['_authentication']       = 'Difinoj por identiĝo';
+$lang['_anti_spam']            = 'Kontraŭ-spamaj difinoj';
+$lang['_editing']              = 'Difinoj por redakto';
+$lang['_links']                = 'Difinoj por ligiloj';
+$lang['_media']                = 'Difinoj por aŭdvidaĵoj';
+$lang['_advanced']             = 'Fakaj difinoj';
+$lang['_network']              = 'Difinoj por reto';
+$lang['_plugin_sufix']         = 'Difinoj por kromaĵoj';
+$lang['_template_sufix']       = 'Difinoj por ŝablonoj';
 $lang['_msg_setting_undefined'] = 'Neniu difinanta metadatenaro.';
 $lang['_msg_setting_no_class'] = 'Neniu difinanta klaso.';
 $lang['_msg_setting_no_default'] = 'Neniu apriora valoro.';
@@ -49,10 +57,10 @@ $lang['youarehere']            = 'Hierarkiaj paderoj';
 $lang['typography']            = 'Fari tipografiajn anstataŭigojn';
 $lang['htmlok']                = 'Ebligi enmeton de HTML-aĵoj';
 $lang['phpok']                 = 'Ebligi enmeton de PHP-aĵoj';
-$lang['dformat']               = 'Formato de datoj (vidu la PHP-an funkcion <a href="http://www.php.net/strftime">strftime</a>';
+$lang['dformat']               = 'Formato de datoj (vidu la PHP-an funkcion <a href="http://www.php.net/strftime">strftime</a>)';
 $lang['signature']             = 'Subskribo';
 $lang['toptoclevel']           = 'Supera nivelo por la enhavtabelo';
-$lang['tocminheads']           = 'Minimuma kvanto da kaplinioj, kiu difinas ĉu la TOC estas kreita.';
+$lang['tocminheads']           = 'Minimuma kvanto da ĉeftitoloj, kiu difinas ĉu la TOC estas kreita.';
 $lang['maxtoclevel']           = 'Maksimuma nivelo por la enhavtabelo';
 $lang['maxseclevel']           = 'Maksimuma nivelo por redakti sekciojn';
 $lang['camelcase']             = 'Uzi KamelUsklecon por ligiloj';
@@ -72,46 +80,49 @@ $lang['autopasswd']            = 'Aŭtomate krei pasvortojn';
 $lang['authtype']              = 'Tipo de identiĝo';
 $lang['passcrypt']             = 'Metodo por ĉifri pasvortojn';
 $lang['defaultgroup']          = 'Antaŭdifinita grupo';
-$lang['superuser']             = 'Superanto - grupo aŭ uzanto, kiu plene alireblas al ĉiuj paĝoj kaj funkcioj, sendepende de la reguloj ACL';
-$lang['manager']               = 'Administranto - grupo aŭ uzanto, kiu havas alirpermeson al kelkaj administraj funkcioj';
+$lang['superuser']             = 'Superanto - grupo, uzanto aŭ listo (apartite per komoj), kiu plene alireblas al ĉiuj paĝoj kaj funkcioj, sendepende de la reguloj ACL';
+$lang['manager']               = 'Administranto - grupo, uzanto aŭ listo (apartite per komoj), kiu havas alirpermeson al kelkaj administraj funkcioj';
 $lang['profileconfirm']        = 'Konfirmi ŝanĝojn en la trajtaro per pasvorto';
 $lang['disableactions']        = 'Malebligi DokuWiki-ajn agojn';
 $lang['disableactions_check']  = 'Kontroli';
 $lang['disableactions_subscription'] = 'Aliĝi/Malaliĝi';
-$lang['disableactions_nssubscription'] = 'Aliĝi/Malaliĝi al Nomspaco';
-$lang['disableactions_wikicode'] = 'Rigardi vikitekston/Eksporti Krudaĵon';
+$lang['disableactions_wikicode'] = 'Rigardi vikitekston/Eksporti krudaĵon';
 $lang['disableactions_other']  = 'Aliaj agoj (apartite per komoj)';
-$lang['sneaky_index']          = 'Apriore, DokuWiki montras ĉiujn nomspacojn en la indica modo. Ebligi tiun ĉi elekteblon kaŝus tion, kion la uzulon ne rajtas legi laŭ AKL. Tio povus rezulti ankaŭan kaŝon de alireblaj subnomspacoj. Kaj tiel la indekso estus neuzebla por kelkaj agordoj de AKL.';
-$lang['auth_security_timeout'] = 'Sekureca Templimo por Aŭtentikigo (sekundoj)';
-$lang['securecookie']          = 'Ĉu kuketoj difinitaj per HTTPS nur estu sendita de la foliumilo per HTTPS? Malebligu tiun ĉi opcion kiam nur la ensaluto al via vikio estas sekurigita per SSL, sed foliumado de la vikio estas farita malsekure.';
-$lang['updatecheck']           = 'Ĉu kontroli aktualigojn kaj sekurecajn avizojn? DokuWiki bezonas kontakti splitbrain.org por tiu ĉi trajto.';
-$lang['userewrite']            = 'Uzi malaĉajn URL-ojn';
+$lang['sneaky_index']          = 'Apriore, DokuWiki montras ĉiujn nomspacojn en la indeksa modo. Ebligi tiun ĉi elekteblon kaŝus tion, kion la uzanto ne rajtas legi laŭ ACL. Tio povus rezulti ankaŭan kaŝon de alireblaj subnomspacoj. Kaj tiel la indekso estus neuzebla por kelkaj agordoj de ACL.';
+$lang['auth_security_timeout'] = 'Sekureca Templimo por aŭtentigo (sekundoj)';
+$lang['securecookie']          = 'Ĉu kuketoj difinitaj per HTTPS nur estu senditaj de la foliumilo per HTTPS? Malebligu tiun ĉi opcion kiam nur la ensaluto al via vikio estas sekurigita per SSL, sed foliumado de la vikio estas farita malsekure.';
+$lang['xmlrpc']                = 'Ebligi/malebligi la interfacon XML-RPC.';
+$lang['xmlrpcuser']            = 'Permesi XML-RPC-an aliron al certaj grupoj aŭ uzantoj, bonvolu meti iliajn komoseparitajn nomojn tie ĉi. Alirebli de ĉiu, ĝin lasu malplena.';
+$lang['updatecheck']           = 'Ĉu kontroli aktualigojn kaj sekurecajn avizojn? DokuWiki bezonas kontakti update.dokuwiki.org por tiu ĉi trajto.';
+$lang['userewrite']            = 'Uzi netajn URL-ojn';
 $lang['useslash']              = 'Uzi frakcistrekon kiel apartigsignaĵo por nomspacoj en URL-oj';
 $lang['usedraft']              = 'Aŭtomate konservi skizon dum redaktado';
 $lang['sepchar']               = 'Apartigsignaĵo de vortoj en paĝnomoj';
 $lang['canonical']             = 'Uzi tute evidentajn URL-ojn';
+$lang['fnencode']              = 'Kodiga metodo por ne-ASCII-aj dosiernomoj.';
 $lang['autoplural']            = 'Kontroli pluralajn formojn en ligiloj';
-$lang['compression']           = 'Kompaktigmetodo por "subtegmentaj" dosieroj';
+$lang['compression']           = 'Kompaktigmetodo por arkivaj dosieroj';
 $lang['cachetime']             = 'Maksimuma aĝo por provizmemoro (sek.)';
 $lang['locktime']              = 'Maksimuma aĝo por serurdosierojn (sek.)';
 $lang['fetchsize']             = 'Maksimuma grandeco (bitokoj) permesita al "fetch.php" elŝuti el ekstere';
 $lang['notify']                = 'Sendi avizojn pri ŝanĝoj al tiu ĉi retadreso';
 $lang['registernotify']        = 'Sendi informon pri ĵus aliĝintoj al tiu ĉi retadreso';
 $lang['mailfrom']              = 'Retadreso uzota por aŭtomataj retmesaĝoj ';
-$lang['gzip_output']           = 'Uzi gzip-a Enhav-Enkodigo por XHTML';
+$lang['mailprefix']            = 'Retpoŝta temo-prefikso por uzi en aŭtomataj mesaĝoj';
+$lang['gzip_output']           = 'Uzi gzip-a enhav-enkodigo por XHTML';
 $lang['gdlib']                 = 'Versio de GD Lib';
 $lang['im_convert']            = 'Pado al la konvertilo de ImageMagick';
 $lang['jpg_quality']           = 'Kompaktiga kvalito de JPG (0-100)';
 $lang['subscribers']           = 'Ebligi subtenon de avizoj pri ŝanĝoj sur paĝoj';
+$lang['subscribe_time']        = 'Tempo, post kiu abonlistoj kaj kolektaĵoj sendiĝas (sek); Tio estu pli malgranda ol la tempo indikita en recent_days.';
 $lang['compress']              = 'Kompaktigi CSS-ajn kaj ĵavaskriptajn elmetojn';
-$lang['hidepages']             = 'Kaŝi kongruantajn paĝojn (laŭ ordinaraj esprimoj - "regular expressions")';
+$lang['hidepages']             = 'Kaŝi kongruantajn paĝojn (laŭ regulaj esprimoj)';
 $lang['send404']               = 'Sendi la mesaĝon "HTTP 404/Ne Trovita Paĝo" por ne ekzistantaj paĝoj';
 $lang['sitemap']               = 'Krei Guglan paĝarmapon "sitemap" (po kiom tagoj)';
 $lang['broken_iua']            = 'Ĉu la funkcio "ignore_user_abort" difektas en via sistemo? Tio povus misfunkciigi la serĉindekson. IIS+PHP/CGI estas konata kiel fuŝaĵo. Vidu <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Cimon 852</a> por pli da informoj.';
 $lang['xsendfile']             = 'Ĉu oni uzu la kaplinion X-Sendfile por ebligi al la retservilo liveri fiksajn dosierojn? Via retservilo bezonus subteni tion.';
-$lang['xmlrpc']                = 'Ebligi/malebligi la interfacon XML-RPC.';
-$lang['renderer_xhtml']        = 'Estetiko por la ĉefa vikia rezulto (xhtml)';
-$lang['renderer__core']        = '%s (dokuwiki-a nukleo)';
+$lang['renderer_xhtml']        = 'Prezentilo por la ĉefa vikia rezulto (xhtml)';
+$lang['renderer__core']        = '%s (DokuWiki-a nukleo)';
 $lang['renderer__plugin']      = '%s (kromaĵo)';
 $lang['rememberme']            = 'Permesi longdaŭran ensalutajn kuketojn (rememoru min)';
 $lang['rss_type']              = 'XML-a tipo de novaĵ-fluo';
@@ -126,15 +137,16 @@ $lang['target____extern']      = 'Parametro "target" (celo) por eksteraj ligiloj
 $lang['target____media']       = 'Parametro "target" (celo) por aŭdvidaĵaj ligiloj';
 $lang['target____windows']     = 'Parametro "target" (celo) por Vindozaj ligiloj';
 $lang['proxy____host']         = 'Retservilnomo de la "Proxy"';
-$lang['proxy____port']         = 'Pordo de la "Proxy"';
-$lang['proxy____user']         = 'Uzulnomo de la "Proxy"';
-$lang['proxy____pass']         = 'Pasvorto de la "Proxy"';
+$lang['proxy____port']         = 'Pordo ĉe la "Proxy"';
+$lang['proxy____user']         = 'Uzantonomo ĉe la "Proxy"';
+$lang['proxy____pass']         = 'Pasvorto ĉe la "Proxy"';
 $lang['proxy____ssl']          = 'Uzi SSL por konekti al la "Proxy"';
+$lang['proxy____except']       = 'Regula esprimo por URL-oj, kiujn la servilo preterrigardu.';
 $lang['safemodehack']          = 'Ebligi sekuran modon';
 $lang['ftp____host']           = 'FTP-a servilo por sekura modo';
 $lang['ftp____port']           = 'FTP-a pordo por sekura modo';
-$lang['ftp____user']           = 'FTP-a uzant-nomo por sekura modo';
-$lang['ftp____pass']           = 'FTP-a pasvonto por sekura modo';
+$lang['ftp____user']           = 'FTP-a uzantonomo por sekura modo';
+$lang['ftp____pass']           = 'FTP-a pasvorto por sekura modo';
 $lang['ftp____root']           = 'FTP-a superuzanta (root) subdosierujo por sekura modo';
 $lang['license_o_']            = 'Nenio elektite';
 $lang['typography_o_0']        = 'nenio';
@@ -155,7 +167,7 @@ $lang['rss_type_o_rss2']       = 'RSS 2.0';
 $lang['rss_type_o_atom']       = 'Atom 0.3';
 $lang['rss_type_o_atom1']      = 'Atom 1.0';
 $lang['rss_content_o_abstract'] = 'Resumo';
-$lang['rss_content_o_diff']    = 'Unuiĝita "Diff"';
+$lang['rss_content_o_diff']    = 'Unuigita "Diff"';
 $lang['rss_content_o_htmldiff'] = '"Diff" tabelo formatita laŭ HTML';
 $lang['rss_content_o_html']    = 'Enhavo laŭ kompleta HTML-paĝo';
 $lang['rss_linkto_o_diff']     = 'diferenca rigardo';
@@ -166,14 +178,15 @@ $lang['compression_o_0']       = 'nenio';
 $lang['compression_o_gz']      = 'gzip';
 $lang['compression_o_bz2']     = 'bz2';
 $lang['xsendfile_o_0']         = 'ne uzi';
-$lang['xsendfile_o_1']         = 'Posedata kaplinio "lighttpd" (antaŭ lanĉo 1.5)';
+$lang['xsendfile_o_1']         = 'Propra kaplinio "lighttpd" (antaŭ lanĉo 1.5)';
 $lang['xsendfile_o_2']         = 'Ordinara kaplinio X-Sendfile';
-$lang['xsendfile_o_3']         = 'Posedata kaplinio Nginx X-Accel-Redirect';
+$lang['xsendfile_o_3']         = 'Propra kaplinio Nginx X-Accel-Redirect';
 $lang['showuseras_o_loginname'] = 'Ensalut-nomo';
 $lang['showuseras_o_username'] = 'Kompleta nomo de uzanto';
 $lang['showuseras_o_email']    = 'Retadreso de uzanto (sekur-montrita laŭ agordo de \'mailguard\')';
 $lang['showuseras_o_email_link'] = 'Retadreso de uzanto kiel ligilo \'mailto:\'';
 $lang['useheading_o_0']        = 'Neniam';
-$lang['useheading_o_navigation'] = 'Foliumado Nur';
-$lang['useheading_o_content']  = 'Vikia Enhavo Nur';
+$lang['useheading_o_navigation'] = 'Nur foliumado';
+$lang['useheading_o_content']  = 'Nur vikia enhavo';
 $lang['useheading_o_1']        = 'Ĉiam';
+$lang['readdircache']          = 'Maksimuma daŭro de la dosieruja kaŝmemoro (sekundoj)';
