@@ -11,12 +11,24 @@
  * @author Manuel Meco <manuel.meco@gmail.com>
  * @author VictorCastelan <victorcastelan@gmail.com>
  * @author Jordan Mero  hack.jord@gmail.com
+ * @author Felipe Martinez <metalmartinez@gmail.com>
+ * @author Javier Aranda <internet@javierav.com>
+ * @author Zerial <fernando@zerial.org>
+ * @author Marvin Ortega <maty1206@maryanlinux.com>
+ * @author Daniel Castro Alvarado <dancas2@gmail.com>
+ * @author Fernando J. Gómez <fjgomez@gmail.com>
+ * @author Victor Castelan <victorcastelan@gmail.com>
+ * @author Mauro Javier Giamberardino <mgiamberardino@gmail.com>
+ * @author emezeta <emezeta@infoprimo.com>
  */
-$lang['menu']                  = 'Parámetros de Configuración';
+$lang['menu']                  = 'Parámetros de configuración';
 $lang['error']                 = 'Los parámetros no han sido actualizados a causa de un valor inválido, por favor revise los cambios y re-envíe el formulario. <br /> Los valores incorrectos se mostrarán con un marco rojo alrededor.';
-$lang['updated']               = 'Los parámetros se actualizaron con exito.';
+$lang['updated']               = 'Los parámetros se actualizaron con éxito.';
 $lang['nochoice']              = '(no hay otras alternativas disponibles)';
 $lang['locked']                = 'El archivo de configuración no ha podido ser actualizado, si esto no es lo deseado, <br /> asegúrese que el nombre del archivo local de configuraciones y los permisos sean los correctos.';
+$lang['danger']                = 'Atención: Cambiar esta opción podría hacer inaccesible el wiki y su menú de configuración.';
+$lang['warning']               = 'Advertencia:  Cambiar esta opción podría causar comportamientos no deseados.';
+$lang['security']              = 'Advertencia de Seguridad: Cambiar esta opción podría representar un riesgo de seguridad.';
 $lang['_configuration_manager'] = 'Administrador de configuración';
 $lang['_header_dokuwiki']      = 'Parámetros de DokuWiki';
 $lang['_header_plugin']        = 'Parámetros de Plugin';
@@ -28,25 +40,25 @@ $lang['_authentication']       = 'Parámetros de Autenticación';
 $lang['_anti_spam']            = 'Parámetros Anti-Spam';
 $lang['_editing']              = 'Parámetros de Edición';
 $lang['_links']                = 'Parámetros de Enlaces';
-$lang['_media']                = 'Parámetros de Almacenamiento';
+$lang['_media']                = 'Parámetros de Medios';
 $lang['_advanced']             = 'Parámetros Avanzados';
 $lang['_network']              = 'Parámetros de Red';
 $lang['_plugin_sufix']         = 'Parámetros de Plugins';
 $lang['_template_sufix']       = 'Parámetros de Plantillas';
 $lang['_msg_setting_undefined'] = 'Sin parámetros de metadata.';
-$lang['_msg_setting_no_class'] = 'Sin Clase (class) establecida.';
+$lang['_msg_setting_no_class'] = 'Sin clase establecida.';
 $lang['_msg_setting_no_default'] = 'Sin valor por defecto.';
 $lang['fmode']                 = 'Modo de creación de ficheros';
 $lang['dmode']                 = 'Modo de creación de directorios';
 $lang['lang']                  = 'Idioma';
-$lang['basedir']               = 'Directorio de Base';
-$lang['baseurl']               = 'URL de Base';
+$lang['basedir']               = 'Directorio de base';
+$lang['baseurl']               = 'URL de base';
 $lang['savedir']               = 'Directorio para guardar los datos';
 $lang['start']                 = 'Nombre de la página inicial';
-$lang['title']                 = 'Título del Wiki';
+$lang['title']                 = 'Título del wiki';
 $lang['template']              = 'Plantilla';
 $lang['license']               = '¿Bajo qué licencia será liberado tu contenido?';
-$lang['fullpath']              = 'Camino (path) completo en el pié de página';
+$lang['fullpath']              = 'Mostrar ruta completa en el pie de página';
 $lang['recent']                = 'Cambios recientes';
 $lang['breadcrumbs']           = 'Número de pasos de traza';
 $lang['youarehere']            = 'Traza jerárquica';
@@ -77,47 +89,49 @@ $lang['authtype']              = 'Método de Autenticación';
 $lang['passcrypt']             = 'Método de cifrado de contraseñas';
 $lang['defaultgroup']          = 'Grupo por defecto';
 $lang['superuser']             = 'Super-usuario - grupo ó usuario con acceso total a todas las páginas y funciones, configuraciones ACL';
-$lang['manager']               = 'Manager - grupo ó usuario con acceso a ciertas tareas de mantenimiento.';
+$lang['manager']               = 'Manager - grupo o usuario con acceso a ciertas tareas de mantenimiento';
 $lang['profileconfirm']        = 'Confirmar cambios en perfil con contraseña';
 $lang['disableactions']        = 'Deshabilitar acciones DokuWiki';
 $lang['disableactions_check']  = 'Controlar';
-$lang['disableactions_subscription'] = 'Subscribirse/Desubscribirse';
-$lang['disableactions_nssubscription'] = 'Directorio Subscribirse/Desubscribirse';
-$lang['disableactions_wikicode'] = 'Ver el fuente/Exportar en formato crudo (raw)';
+$lang['disableactions_subscription'] = 'Suscribirse/Cancelar suscripción';
+$lang['disableactions_wikicode'] = 'Ver la fuente/Exportar en formato raw';
 $lang['disableactions_other']  = 'Otras acciones (separadas por coma)';
 $lang['sneaky_index']          = 'Por defecto, DokuWiki mostrará todos los namespaces en el index. Habilitando esta opción los ocultará si el usuario no tiene permisos de lectura. Los sub-namespaces pueden resultar inaccesibles. El index puede hacerse poco usable dependiendo de las configuraciones ACL.';
 $lang['auth_security_timeout'] = 'Tiempo de Autenticación (en segundos), por motivos de seguridad';
-$lang['securecookie']          = 'Las cookies establecidas por HTTPS, el naveagdor solo puede enviarlas por HTTPS?
-Inhabilite esta opción cuando solo se asegure la entrada , pero no la navegación de su wiki.';
-$lang['updatecheck']           = 'Comprobar actualizaciones y advertencias de seguridad? Esta característica requiere que Dokuwiki se conecte a splitbrain.org.';
+$lang['securecookie']          = 'Las cookies establecidas por HTTPS, ¿el naveagdor solo puede enviarlas por HTTPS? Inhabilite esta opción cuando solo se asegure con SSL la entrada, pero no la navegación de su wiki.';
+$lang['xmlrpc']                = 'Habilitar/Deshabilitar interfaz XML-RPC';
+$lang['xmlrpcuser']            = 'Restringir el acceso XML-RPC a los grupos o usuarios separados por coma mencionados aquí. Dejar en blanco para dar acceso a todo el mundo. ';
+$lang['updatecheck']           = '¿Comprobar actualizaciones y advertencias de seguridad? Esta característica requiere que DokuWiki se conecte a update.dokuwiki.org.';
 $lang['userewrite']            = 'Usar URLs bonitas';
 $lang['useslash']              = 'Usar barra (/) como separador de espacios de nombres en las URLs';
 $lang['usedraft']              = 'Guardar automáticamente un borrador mientras se edita';
 $lang['sepchar']               = 'Separador de palabras en nombres de páginas';
 $lang['canonical']             = 'Usar URLs totalmente canónicas';
+$lang['fnencode']              = 'Método para codificar nombres de archivo no-ASCII.';
 $lang['autoplural']            = 'Controlar plurales en enlaces';
 $lang['compression']           = 'Método de compresión para archivos en el ático';
 $lang['cachetime']             = 'Edad máxima para caché (segundos)';
-$lang['locktime']              = 'Edad máxima para archivos de lock (segundos)';
+$lang['locktime']              = 'Edad máxima para archivos de bloqueo (segundos)';
 $lang['fetchsize']             = 'Tamaño máximo (bytes) que fetch.php puede descargar de sitios externos';
 $lang['notify']                = 'Enviar notificación de cambios a esta dirección de correo electrónico';
 $lang['registernotify']        = 'Enviar información cuando se registran nuevos usuarios a esta dirección de correo electrónico';
 $lang['mailfrom']              = 'Dirección de correo electrónico para emails automáticos';
+$lang['mailprefix']            = 'Asunto por defecto que se utilizará en mails automáticos.';
 $lang['gzip_output']           = 'Usar gzip Content-Encoding para xhtml';
 $lang['gdlib']                 = 'Versión de GD Lib';
 $lang['im_convert']            = 'Ruta a la herramienta de conversión de ImageMagick';
 $lang['jpg_quality']           = 'Calidad de compresión de JPG (0-100)';
 $lang['subscribers']           = 'Habilitar soporte para suscripción a páginas';
+$lang['subscribe_time']        = 'Tiempo después que alguna lista de suscripción fue enviada (seg); Debe ser menor que el tiempo especificado en días recientes.';
 $lang['compress']              = 'Compactar la salida de CSS y javascript';
 $lang['hidepages']             = 'Ocultar páginas con coincidencias (expresiones regulares)';
 $lang['send404']               = 'Enviar "HTTP 404/Page Not Found" para páginas no existentes';
 $lang['sitemap']               = 'Generar sitemap de Google (días)';
-$lang['broken_iua']            = '¿Se ha roto su sistema a causa de la función ignore_user_abort?. Esto puede causar que no funcione el index de búsqueda. Leer el <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a>para más información.';
+$lang['broken_iua']            = '¿Se ha roto (broken) la función ignore_user_abort en su sistema? Esto puede causar que no funcione el index de búsqueda. Se sabe que IIS+PHP/CGI está roto. Vea <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a>para más información.';
 $lang['xsendfile']             = 'Utilice el X-Sendfile header para permitirle sl servidor web enviar archivos estáticos? Su servidor web necesita tener la capacidad para hacerlo.';
-$lang['xmlrpc']                = 'Habilitar/Deshabilitar interfase XML-RPC';
 $lang['renderer_xhtml']        = 'Visualizador a usar para salida (xhtml) principal del wiki';
-$lang['renderer__core']        = '%s (nucleo dokuwiki)';
-$lang['renderer__plugin']      = '%s (complemento)';
+$lang['renderer__core']        = '%s (núcleo dokuwiki)';
+$lang['renderer__plugin']      = '%s (plugin)';
 $lang['rememberme']            = 'Permitir cookies para acceso permanente (recordarme)';
 $lang['rss_type']              = 'Tipo de resumen (feed) XML';
 $lang['rss_linkto']            = 'Feed XML enlaza a';
@@ -135,12 +149,13 @@ $lang['proxy____port']         = 'Puerto del servidor Proxy';
 $lang['proxy____user']         = 'Nombre de usuario para el servidor Proxy';
 $lang['proxy____pass']         = 'Contraseña para el servidor Proxy';
 $lang['proxy____ssl']          = 'Usar ssl para conectarse al servidor Proxy';
+$lang['proxy____except']       = 'Expresiones regulares para encontrar URLs que el proxy debería omitir.';
 $lang['safemodehack']          = 'Habilitar edición (hack) de modo seguro';
 $lang['ftp____host']           = 'Nombre del servidor FTP  para modo seguro';
 $lang['ftp____port']           = 'Puerto del servidor FTP  para modo seguro';
-$lang['ftp____user']           = 'Nombre de usuario para el servidor FTP  para modo seguro';
-$lang['ftp____pass']           = 'Contraseña para el servidor FTP  para modo seguro';
-$lang['ftp____root']           = 'Directorio raiz para el servidor FTP  para modo seguro';
+$lang['ftp____user']           = 'Nombre de usuario para el servidor FTP para modo seguro';
+$lang['ftp____pass']           = 'Contraseña para el servidor FTP para modo seguro';
+$lang['ftp____root']           = 'Directorio raiz para el servidor FTP para modo seguro';
 $lang['license_o_']            = 'No se eligió ninguna';
 $lang['typography_o_0']        = 'ninguno';
 $lang['typography_o_1']        = 'Dobles comillas solamente';
@@ -148,9 +163,9 @@ $lang['typography_o_2']        = 'Todas las comillas (puede ser que no siempre f
 $lang['userewrite_o_0']        = 'ninguno';
 $lang['userewrite_o_1']        = '.htaccess';
 $lang['userewrite_o_2']        = 'Interno de DokuWiki';
-$lang['deaccent_o_0']          = 'Apagado';
-$lang['deaccent_o_1']          = 'Eliminar tildes';
-$lang['deaccent_o_2']          = 'Romanizar';
+$lang['deaccent_o_0']          = 'apagado';
+$lang['deaccent_o_1']          = 'eliminar tildes';
+$lang['deaccent_o_2']          = 'romanizar';
 $lang['gdlib_o_0']             = 'GD Lib no está disponible';
 $lang['gdlib_o_1']             = 'Versión 1.x';
 $lang['gdlib_o_2']             = 'Autodetección';
@@ -167,18 +182,19 @@ $lang['rss_linkto_o_diff']     = 'ver las diferencias';
 $lang['rss_linkto_o_page']     = 'la página revisada';
 $lang['rss_linkto_o_rev']      = 'lista de revisiones';
 $lang['rss_linkto_o_current']  = 'la página actual';
-$lang['compression_o_0']       = 'Ninguna';
+$lang['compression_o_0']       = 'ninguna';
 $lang['compression_o_gz']      = 'gzip';
 $lang['compression_o_bz2']     = 'bz2';
-$lang['xsendfile_o_0']         = 'No utiliazar';
+$lang['xsendfile_o_0']         = 'no utilizar';
 $lang['xsendfile_o_1']         = 'Encabezado propietario de lighttpd (antes de la versión 1.5)';
 $lang['xsendfile_o_2']         = 'Encabezado X-Sendfile estándar';
 $lang['xsendfile_o_3']         = 'Encabezado propietario Nginx X-Accel-Redirect';
 $lang['showuseras_o_loginname'] = 'Nombre de entrada';
 $lang['showuseras_o_username'] = 'Nombre completo del usuario';
-$lang['showuseras_o_email']    = 'Dirección de correo electrónico del usuario (Ofuscada según la configuración de "mailguard")';
+$lang['showuseras_o_email']    = 'Dirección de correo electrónico del usuario (ofuscada según la configuración de "mailguard")';
 $lang['showuseras_o_email_link'] = 'Dirección de correo de usuario como enlace de envío de correo';
 $lang['useheading_o_0']        = 'Nunca';
-$lang['useheading_o_navigation'] = 'Solamente Navegacion';
-$lang['useheading_o_content']  = 'Contenido Wiki solamente';
+$lang['useheading_o_navigation'] = 'Solamente Navegación';
+$lang['useheading_o_content']  = 'Contenido wiki solamente';
 $lang['useheading_o_1']        = 'Siempre';
+$lang['readdircache']          = 'Tiempo máximo para la cache readdir (en segundos)';
