@@ -4,14 +4,18 @@
  *
  * @author otto@valjakko.net
  * @author Otto Vainio <otto@valjakko.net>
+ * @author Teemu Mattila <ghcsystems@gmail.com>
  */
 $lang['menu']                  = 'Asetukset';
 $lang['error']                 = 'Asetuksia ei päivitetty väärän arvon vuoksi. Tarkista muutokset ja lähetä sivu uudestaan.
 <br />Väärät arvot on merkitty punaisella reunuksella.';
 $lang['updated']               = 'Asetukset päivitetty onnistuneesti.';
 $lang['nochoice']              = '(ei muita valintoja saatavilla)';
-$lang['locked']                = 'Asetustiedosta ei voi päivittää. Jos tämä ei ole tarkoitus, <br />
+$lang['locked']                = 'Asetustiedosta ei voi päivittää. Jos tämä ei ole tarkoitus <br />
 niin varmista, että paikallisten asetusten tiedoston nimi ja oikeudet ovat kunnossa.';
+$lang['danger']                = 'Vaara: tämän asetuksen muuttaminen saattaa estää wikisi ja asetusvalikon toimimisen.';
+$lang['warning']               = 'Varoitus: tämän asetuksen muuttaminen saattaa aiheuttaa olettamattomia toimintoja.';
+$lang['security']              = 'Turvallisuusvaroitus: tämän asetuksen muuttaminen saattaa aiheuttaa tietoturva-aukon.';
 $lang['_configuration_manager'] = 'Asetusten hallinta';
 $lang['_header_dokuwiki']      = 'DokuWikin asetukset';
 $lang['_header_plugin']        = 'Liitännäisten asetukset';
@@ -26,7 +30,7 @@ $lang['_links']                = 'Linkkien asetukset';
 $lang['_media']                = 'Media-asetukset';
 $lang['_advanced']             = 'Lisäasetukset';
 $lang['_network']              = 'Verkkoasetukset';
-$lang['_plugin_sufix']         = 'Liitännäisten asetukset';
+$lang['_plugin_sufix']         = 'liitännäisen asetukset';
 $lang['_template_sufix']       = 'Sivumallin asetukset';
 $lang['_msg_setting_undefined'] = 'Ei asetusten metadataa.';
 $lang['_msg_setting_no_class'] = 'Ei asetusluokkaa.';
@@ -34,7 +38,7 @@ $lang['_msg_setting_no_default'] = 'Ei oletusarvoa';
 $lang['fmode']                 = 'Tiedoston luontioikeudet';
 $lang['dmode']                 = 'Hakemiston luontioikeudet';
 $lang['lang']                  = 'Kieli';
-$lang['basedir']               = 'Peruhakemisto';
+$lang['basedir']               = 'Perushakemisto';
 $lang['baseurl']               = 'Perus URL';
 $lang['savedir']               = 'Hakemisto tietojen tallennukseen.';
 $lang['start']                 = 'Alkusivun nimi';
@@ -57,8 +61,8 @@ $lang['maxseclevel']           = 'Kappale-editoinnin suurin syvyys.';
 $lang['camelcase']             = 'Käytä CamelCase linkkejä';
 $lang['deaccent']              = 'Siivoa sivun nimet';
 $lang['useheading']            = 'Käytä ensimmäistä otsikkoriviä sivun nimenä.';
-$lang['refcheck']              = 'Median viitteen tarkistus';
-$lang['refshow']               = 'Montako media viitettä näytetään';
+$lang['refcheck']              = 'Mediaviitteen tarkistus';
+$lang['refshow']               = 'Montako mediaviitettä näytetään';
 $lang['allowdebug']            = 'Salli debuggaus <b>pois, jos ei tarvita!</b>';
 $lang['usewordblock']          = 'Estä spam sanalistan avulla';
 $lang['indexdelay']            = 'Aikaraja indeksoinnille (sek)';
@@ -74,43 +78,46 @@ $lang['defaultgroup']          = 'Oletusryhmä';
 $lang['superuser']             = 'Pääkäyttäjä. Ryhmä tai käyttäjä, jolla on täysi oikeus kaikkiin sivuihin ja toimintoihin käyttöoikeuksista huolimatta';
 $lang['manager']               = 'Ylläpitäjä. Ryhmä tai käyttäjä, jolla on pääsy joihinkin ylläpitotoimintoihin';
 $lang['profileconfirm']        = 'Vahvista profiilin päivitys salasanan avulla';
-$lang['disableactions']        = 'Estä DokuWiki toimintojen käyttö';
+$lang['disableactions']        = 'Estä DokuWiki-toimintojen käyttö';
 $lang['disableactions_check']  = 'Tarkista';
 $lang['disableactions_subscription'] = 'Tilaa/Peruuta tilaus';
-$lang['disableactions_nssubscription'] = 'Nimiavaruuden tilaus/tilauksen poisto';
 $lang['disableactions_wikicode'] = 'Näytä lähdekoodi/Vie raakana';
 $lang['disableactions_other']  = 'Muut toiminnot (pilkulla erotettuna)';
-$lang['sneaky_index']          = 'Oletuksena DokuWiki näyttää kaikki nimiavaruudet index-näkymäsä. Tämä asetus piilottaa ne, joihin käyttäjällä ei ole lukuoikeuksia. Tämä voi piilottaa joitakin sallittuja ali-nimiavaruuksia. Tästä johtuen index-näkymä voi olla käyttökelvoton joillakin ACL-asetuksilla';
+$lang['sneaky_index']          = 'Oletuksena DokuWiki näyttää kaikki nimiavaruudet index-näkymäsä. Tämä asetus piilottaa ne, joihin käyttäjällä ei ole lukuoikeuksia. Tämä voi piilottaa joitakin sallittuja alinimiavaruuksia. Tästä johtuen index-näkymä voi olla käyttökelvoton joillakin ACL-asetuksilla';
 $lang['auth_security_timeout'] = 'Autentikoinnin aikakatkaisu (sekunteja)';
-$lang['securecookie']          = 'Lähetetäänkö HTTPS kautta asetetut cookies tiedot HTTPS yhdeydellä? Kytke pois, jos vain kirjautuminen wikisi on suojattu SSL:n avulla, mutta muuten wikiä käytetään ilman suojausta.';
-$lang['updatecheck']           = 'Tarkista päivityksiä ja turvavaroituksia? Tätä varten DokuWikin pitää ottaa yhteys splitbrain.orgiin.';
+$lang['securecookie']          = 'Lähetetäänkö HTTPS:n kautta asetetut evästetiedot HTTPS-yhteydellä? Kytke pois, jos vain wikisi kirjautuminen on suojattu SSL:n avulla, mutta muuten wikiä käytetään ilman suojausta.';
+$lang['xmlrpc']                = 'Käytä/poista XML-RPC liityntää';
+$lang['xmlrpcuser']            = 'Estä XML-RPC:n käyttö pilkulla erotetun listan ryhmille tai käyttäjille. Jätä tyhjäksi salliaksesi käyttö kaikille.';
+$lang['updatecheck']           = 'Tarkista päivityksiä ja turvavaroituksia? Tätä varten DokuWikin pitää ottaa yhteys update.dokuwiki.orgiin.';
 $lang['userewrite']            = 'Käytä siivottuja URLeja';
 $lang['useslash']              = 'Käytä kauttaviivaa nimiavaruuksien erottimena URL-osoitteissa';
-$lang['usedraft']              = 'Automaattisesti tallenna vedos muokkaustilassa';
+$lang['usedraft']              = 'Tallenna vedos muokkaustilassa automaattisesti ';
 $lang['sepchar']               = 'Sivunimen sanaerotin';
-$lang['canonical']             = 'Käytä "Canonical URL"';
+$lang['canonical']             = 'Käytä kanonisoituja URLeja';
+$lang['fnencode']              = 'Muita kuin ASCII merkkejä sisältävien tiedostonimien koodaustapa.';
 $lang['autoplural']            = 'Etsi monikkomuotoja linkeistä';
-$lang['compression']           = 'Attic tiedostojen pakkausmenetelmä';
+$lang['compression']           = 'Attic-tiedostojen pakkausmenetelmä';
 $lang['cachetime']             = 'Välimuisti-tiedostojen maksimi-ikä (sek)';
 $lang['locktime']              = 'Lukitustiedostojen maksimi-ikä (sek)';
 $lang['fetchsize']             = 'Suurin koko (bytejä), jonka fetch.php voi ladata ulkopuolisesta lähteestä';
-$lang['notify']                = 'Lähetä muutos ilmoitukset tähän osoitteeseen';
+$lang['notify']                = 'Lähetä muutosilmoitukset tähän osoitteeseen';
 $lang['registernotify']        = 'Lähetä ilmoitus uusista rekisteröitymisistä tähän osoitteeseen';
 $lang['mailfrom']              = 'Sähköpostiosoite automaattisia postituksia varten';
-$lang['gzip_output']           = 'Käytä gzip "Content.Encoding" tapaa xhtml varten';
+$lang['mailprefix']            = 'Etuliite automaattisesti lähetettyihin dähköposteihin';
+$lang['gzip_output']           = 'Käytä gzip "Content-Encoding"-otsaketta xhtml-tiedostojen lähettämiseen';
 $lang['gdlib']                 = 'GD Lib versio';
-$lang['im_convert']            = 'ImageMagick muunnostyökalun polku';
-$lang['jpg_quality']           = 'JPG pakkauslaatu';
+$lang['im_convert']            = 'ImageMagick-muunnostyökalun polku';
+$lang['jpg_quality']           = 'JPG pakkauslaatu (0-100)';
 $lang['subscribers']           = 'Salli tuki sivujen tilaamiselle';
+$lang['subscribe_time']        = 'Aika jonka jälkeen tilauslinkit ja yhteenveto lähetetään (sek). Tämän pitäisi olla pienempi, kuin recent_days aika.';
 $lang['compress']              = 'Pakkaa CSS ja javascript';
 $lang['hidepages']             = 'Piilota seuraavat sivut (säännönmukainen lauseke)';
 $lang['send404']               = 'Lähetä "HTTP 404/Page Not Found" puuttuvista sivuista';
 $lang['sitemap']               = 'Luo Google sitemap (päiviä)';
-$lang['broken_iua']            = 'Onko "ignore_user_abort" toiminto rikki systeemissäsi. Tämä voi aiheuttaa toimimattoman index-näkymän.
+$lang['broken_iua']            = 'Onko "ignore_user_abort" toiminto rikki järjestelmässäsi? Tämä voi aiheuttaa toimimattoman index-näkymän.
 IIS+PHP/CGI on tunnetusti rikki. Katso <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> lisätietoja varten.';
 $lang['xsendfile']             = 'Käytä X-Sendfile otsikkoa, kun web-palvelin lähettää staattisia tiedostoja? Palvelimesi pitää tukea tätä.';
-$lang['xmlrpc']                = 'Käytä/poista XML-RPC liityntää';
-$lang['renderer_xhtml']        = 'Renderöinti, jota käytetään wikin pääasialliseen (xhtml) outputtiin';
+$lang['renderer_xhtml']        = 'Renderöinti, jota käytetään wikin pääasialliseen (xhtml) tulostukseen';
 $lang['renderer__core']        = '%s (dokuwiki core)';
 $lang['renderer__plugin']      = '%s (liitännäinen)';
 $lang['rememberme']            = 'Salli pysyvät kirjautumis-cookiet (muista minut)';
@@ -130,6 +137,7 @@ $lang['proxy____port']         = 'Proxy portti';
 $lang['proxy____user']         = 'Proxy käyttäjän nimi';
 $lang['proxy____pass']         = 'Proxy salasana';
 $lang['proxy____ssl']          = 'Käytä ssl-yhteyttä kytkeytyäksesi proxy-palvelimeen';
+$lang['proxy____except']       = 'Säännönmukainen lause, URLiin, jolle proxy ohitetaan.';
 $lang['safemodehack']          = 'Käytä safemode kiertoa';
 $lang['ftp____host']           = 'FTP-palvelin safemode kiertoa varten';
 $lang['ftp____port']           = 'FTP-portti safemode kiertoa varten';
@@ -138,7 +146,7 @@ $lang['ftp____pass']           = 'FTP-salasana safemode kiertoa varten';
 $lang['ftp____root']           = 'FTP-juurihakemisto safemode kiertoa varten';
 $lang['license_o_']            = 'ei mitään valittuna';
 $lang['typography_o_0']        = 'ei mitään';
-$lang['typography_o_1']        = 'paitsi yksinkertaiset lainausmerkit';
+$lang['typography_o_1']        = 'ilman yksinkertaisia lainausmerkkejä';
 $lang['typography_o_2']        = 'myös yksinkertaiset lainausmerkit (ei aina toimi)';
 $lang['userewrite_o_0']        = 'ei mitään';
 $lang['userewrite_o_1']        = '.htaccess';
@@ -156,7 +164,7 @@ $lang['rss_type_o_atom']       = 'Atom 0.3';
 $lang['rss_type_o_atom1']      = 'Atom 1.0';
 $lang['rss_content_o_abstract'] = 'Yhteenveto';
 $lang['rss_content_o_diff']    = 'Yhdistetty erot';
-$lang['rss_content_o_htmldiff'] = 'HTML muotoiltu erot lista';
+$lang['rss_content_o_htmldiff'] = 'HTML-muotoiltu eroavuuslista';
 $lang['rss_content_o_html']    = 'Täysi HTML-sivu';
 $lang['rss_linkto_o_diff']     = 'erot-näkymä';
 $lang['rss_linkto_o_page']     = 'muutettu sivu';
@@ -171,9 +179,10 @@ $lang['xsendfile_o_2']         = 'Standardi X-sendfile header';
 $lang['xsendfile_o_3']         = 'Oma Nginx X-Accel-Redirect header';
 $lang['showuseras_o_loginname'] = 'Kirjautumisnimi';
 $lang['showuseras_o_username'] = 'Käyttäjän koko nimi';
-$lang['showuseras_o_email']    = 'Käyttäjän sähköpostiosoite. (sumennettu mailguard asetusten mukaisesti)';
+$lang['showuseras_o_email']    = 'Käyttäjän sähköpostiosoite (sumennettu mailguard-asetusten mukaisesti)';
 $lang['showuseras_o_email_link'] = 'Käyttäjän sähköpostiosoite mailto: linkkinä';
 $lang['useheading_o_0']        = 'Ei koskaan';
 $lang['useheading_o_navigation'] = 'Vain Navigointi';
-$lang['useheading_o_content']  = 'Vain Wiki Sisältö';
+$lang['useheading_o_content']  = 'Vain Wiki-sisältö';
 $lang['useheading_o_1']        = 'Aina';
+$lang['readdircache']          = 'Maksimiaika readdir cachelle (sek)';
