@@ -12,10 +12,13 @@ $lang['updated']               = 'Nastavenia úspešne aktualizované.';
 $lang['nochoice']              = '(žiadne ďalšie dostupné voľby)';
 $lang['locked']                = 'Súbor s nastaveniami nemôže byť aktualizovaný, ak toto nie je zámerom, <br />
 uistite sa, že názov a práva lokálneho súboru sú správne.';
+$lang['danger']                = 'Nebezpečie: Zmeny tohto nastavenia môžu spôsobiť nedostupnosť wiki a nastavovacieho menu.';
+$lang['warning']               = 'Varovanie: Zmena tohto nastavenia môže viesť neželanému správaniu.';
+$lang['security']              = 'Bezpečnostné riziko: Zmenou tohto nastavenie môže vzniknúť bezpečnostné riziko.';
 $lang['_configuration_manager'] = 'Správa konfigurácie';
 $lang['_header_dokuwiki']      = 'Nastavenia DokuWiki';
 $lang['_header_plugin']        = 'Nastavenia plug-inov';
-$lang['_header_template']      = 'Nastavenia šablón';
+$lang['_header_template']      = 'Nastavenia šablóny';
 $lang['_header_undefined']     = 'Nešpecifikované nastavenia';
 $lang['_basic']                = 'Základné nastavenia';
 $lang['_display']              = 'Nastavenia zobrazovania';
@@ -28,6 +31,8 @@ $lang['_advanced']             = 'Rozšírené nastavenia';
 $lang['_network']              = 'Nastavenia siete';
 $lang['_plugin_sufix']         = 'Nastavenia plug-inu';
 $lang['_template_sufix']       = 'Nastavenia šablóny';
+$lang['_msg_setting_undefined'] = 'Nenastavené metadata.';
+$lang['_msg_setting_no_class'] = 'Nenastavená trieda.';
 $lang['_msg_setting_no_default'] = 'Žiadna predvolená hodnota.';
 $lang['fmode']                 = 'Spôsob vytvárania súborov';
 $lang['dmode']                 = 'Spôsob vytvárania adresárov';
@@ -57,7 +62,7 @@ $lang['deaccent']              = 'Upraviť názvy stránok';
 $lang['useheading']            = 'Použiť nadpis pre názov stránky';
 $lang['refcheck']              = 'Kontrolovať odkazy na médiá (pred vymazaním)';
 $lang['refshow']               = 'Počet zobrazených odkazov na médiá';
-$lang['allowdebug']            = 'Povoliť ladenie chýb <b>deaktivujte, pokiaľ nepotrebujete!</b>';
+$lang['allowdebug']            = 'Povoliť ladenie chýb <b>deaktivujte, ak nie je potrebné!</b>';
 $lang['usewordblock']          = 'Blokovať spam na základe zoznamu známych slov';
 $lang['indexdelay']            = 'Časové oneskorenie pred indexovaním (sek)';
 $lang['relnofollow']           = 'Používať rel="nofollow" pre externé odkazy';
@@ -74,19 +79,21 @@ $lang['manager']               = 'Manažér - skupina, používateľ alebo čiar
 $lang['profileconfirm']        = 'Potvrdzovať zmeny profilu heslom';
 $lang['disableactions']        = 'Zakázať DokuWiki akcie';
 $lang['disableactions_check']  = 'Skontrolovať';
-$lang['disableactions_subscription'] = 'Prihlásiť/Odhlásiť informovanie o zmenách stránky';
-$lang['disableactions_nssubscription'] = 'Prihlásiť/Odhlásiť informovanie o zmenách v mennom priestore';
+$lang['disableactions_subscription'] = 'Povoliť/Zrušiť informovanie o zmenách stránky';
 $lang['disableactions_wikicode'] = 'Pozrieť zdroj/Exportovať zdroj';
 $lang['disableactions_other']  = 'Iné akcie (oddelené čiarkou)';
 $lang['sneaky_index']          = 'DokuWiki implicitne ukazuje v indexe všetky menné priestory. Povolením tejto voľby sa nezobrazia menné priestory, ku ktorým nemá používateľ právo na čítanie. Dôsledkom môže byť nezobrazenie vnorených prístupných menných priestorov. Táto voľba môže mať za následok nepoužiteľnosť indexu s určitými ACL nastaveniami.';
 $lang['auth_security_timeout'] = 'Časový limit pri prihlasovaní (v sekundách)';
 $lang['securecookie']          = 'Mal by prehliadač posielať cookies nastavené cez HTTPS posielať iba cez HTTPS (bezpečné) pripojenie? Vypnite túto voľbu iba v prípade, ak je prihlasovanie do Vašej wiki zabezpečené SSL, ale prezeranie wiki je nezabezpečené.';
-$lang['updatecheck']           = 'Kontrolovať aktualizácie a bezpečnostné upozornenia? DokuWiki potrebuje pre túto funkciu prístup k splitbrain.org.';
+$lang['xmlrpc']                = 'Povoliť/zakázať XML-RPC rozhranie.';
+$lang['xmlrpcuser']            = 'Obmedziť XML-RPC prístup iba pre uvedené skupiny alebo používateľov (oddelených čiarkami).';
+$lang['updatecheck']           = 'Kontrolovať aktualizácie a bezpečnostné upozornenia? DokuWiki potrebuje pre túto funkciu prístup k update.dokuwiki.org.';
 $lang['userewrite']            = 'Používať nice URLs';
 $lang['useslash']              = 'Používať lomku (/) ako oddeľovač v URL';
 $lang['usedraft']              = 'Automaticky ukladať koncept počas úpravy stránky';
 $lang['sepchar']               = 'Oddeľovač slov v názvoch stránok';
 $lang['canonical']             = 'Používať plne kanonické URL názvy';
+$lang['fnencode']              = 'Spôsob kódovania non-ASCII mien súborov.';
 $lang['autoplural']            = 'Kontrolovať množné číslo v odkazoch';
 $lang['compression']           = 'Metóda kompresie pre staré verzie stránok';
 $lang['cachetime']             = 'Maximálne trvanie cache (sek)';
@@ -95,18 +102,19 @@ $lang['fetchsize']             = 'Maximálna veľkosť (v bajtoch) pri sťahovan
 $lang['notify']                = 'Posielať upozornenia na zmeny na túto e-mailovú adresu';
 $lang['registernotify']        = 'Posielať informáciu o nových užívateľoch na túto e-mailovú adresu';
 $lang['mailfrom']              = 'E-mailová adresa na automatické e-maily';
+$lang['mailprefix']            = 'Prefix predmetu emailovej spravy zasielanej automaticky';
 $lang['gzip_output']           = 'Používať gzip Content-Encoding pre xhtml';
 $lang['gdlib']                 = 'Verzia GD Lib';
 $lang['im_convert']            = 'Cesta k ImageMagick convert tool';
 $lang['jpg_quality']           = 'Kvalita JPG kompresie (0-100)';
 $lang['subscribers']           = 'Povoliť podporu informovania o zmenách stránky';
+$lang['subscribe_time']        = 'Časový inteval, po uplynutí ktorého sú zasielané informácie o zmenách stránky alebo menného priestoru (sek); hodnota by mala byť menšia ako čas zadaný pri položke recent_days.';
 $lang['compress']              = 'Komprimovať CSS a javascript výstup';
 $lang['hidepages']             = 'Skryť zodpovedajúce stránky (regulárne výrazy)';
 $lang['send404']               = 'Poslať "HTTP 404/Page Not Found" pre neexistujúce stránky';
 $lang['sitemap']               = 'Generovať Google sitemap (dni)';
 $lang['broken_iua']            = 'Je vo Vašom systéme funkcia ignore_user_abort poškodená? Môže to mať za následok nefunkčnosť vyhľadávania v indexe. IIS+PHP/CGI je známy tým, že nefunguje správne. Pozrite <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> pre dalšie informácie.';
-$lang['xsendfile']             = 'Používať X-Sendfile hlavičku pre doručenie statických suborov webserverom? Webserver musí túto funkcionalitu podporovať.';
-$lang['xmlrpc']                = 'Povoliť/zakázať XML-RPC rozhranie.';
+$lang['xsendfile']             = 'Používať X-Sendfile hlavičku pre doručenie statických súborov webserverom? Webserver musí túto funkcionalitu podporovať.';
 $lang['renderer_xhtml']        = 'Používané vykresľovacie jadro pre hlavný (xhtml) wiki výstup';
 $lang['renderer__core']        = '%s (dokuwiki jadro)';
 $lang['renderer__plugin']      = '%s (plugin)';
@@ -127,6 +135,7 @@ $lang['proxy____port']         = 'Proxy server - port';
 $lang['proxy____user']         = 'Proxy server - užívateľské meno';
 $lang['proxy____pass']         = 'Proxy server - heslo';
 $lang['proxy____ssl']          = 'Proxy server - použiť SSL';
+$lang['proxy____except']       = 'Regulárny výraz popisujúci URL odkazy, pre ktoré by proxy nemala byť použitá.';
 $lang['safemodehack']          = 'Povoliť "safemode hack"';
 $lang['ftp____host']           = 'FTP server pre "safemode hack"';
 $lang['ftp____port']           = 'FTP port pre "safemode hack"';
@@ -174,3 +183,4 @@ $lang['useheading_o_0']        = 'Nikdy';
 $lang['useheading_o_navigation'] = 'Iba navigácia';
 $lang['useheading_o_content']  = 'Iba Wiki obsah';
 $lang['useheading_o_1']        = 'Vždy';
+$lang['readdircache']          = 'Maximálne trvanie readdir cache (sek)';
