@@ -182,8 +182,8 @@ if (!class_exists('configuration')) {
       if ($this->_format == 'php') {
           $out .= '<'.'?php'."\n".
                 "/*\n".
-                " * ".$header." \n".
-                " * Auto-generated by ".$id." plugin \n".
+                " * ".$header."\n".
+                " * Auto-generated by ".$id." plugin\n".
                 " * Run for user: ".$_SERVER['REMOTE_USER']."\n".
                 " * Date: ".date('r')."\n".
                 " */\n\n";
@@ -340,6 +340,12 @@ if (!class_exists('setting')) {
     var $_error = false;            // only used by those classes which error check
     var $_input = NULL;             // only used by those classes which error check
 
+    var $_cautionList = array(
+        'basedir' => 'danger', 'baseurl' => 'danger', 'savedir' => 'danger', 'useacl' => 'danger', 'authtype' => 'danger', 'superuser' => 'danger', 'userewrite' => 'danger',
+        'start' => 'warning', 'camelcase' => 'warning', 'deaccent' => 'warning', 'sepchar' => 'warning', 'compression' => 'warning', 'xsendfile' => 'warning', 'renderer_xhtml' => 'warning', 'fnencode' => 'warning',
+        'allowdebug' => 'security', 'htmlok' => 'security', 'phpok' => 'security', 'iexssprotect' => 'security', 'xmlrpc' => 'security', 'fullpath' => 'security'
+    );
+
     function setting($key, $params=NULL) {
         $this->_key = $key;
 
@@ -439,9 +445,21 @@ if (!class_exists('setting')) {
     function is_default() { return !$this->is_protected() && is_null($this->_local); }
     function error() { return $this->_error; }
 
-    function _out_key($pretty=false) {
+    function caution() {
+        if (!array_key_exists($this->_key, $this->_cautionList)) return false;
+        return $this->_cautionList[$this->_key];
+    }
+
+    function _out_key($pretty=false,$url=false) {
         if($pretty){
-            return str_replace(CM_KEYMARKER,"&raquo;",$this->_key);
+            $out = str_replace(CM_KEYMARKER,"&raquo;",$this->_key);
+            if ($url && !strstr($out,'&raquo;')) {//provide no urls for plugins, etc.
+                if ($out == 'start') //one exception
+                    return '<a href="http://www.dokuwiki.org/config:startpage">'.$out.'</a>';
+                else
+                    return '<a href="http://www.dokuwiki.org/config:'.$out.'">'.$out.'</a>';
+            }
+            return $out;
         }else{
             return str_replace(CM_KEYMARKER,"']['",$this->_key);
         }
@@ -510,8 +528,42 @@ if (!class_exists('setting_password')) {
 }
 
 if (!class_exists('setting_email')) {
+  if (!defined('SETTING_EMAIL_PATTERN')) define('SETTING_EMAIL_PATTERN','<^'.PREG_PATTERN_VALID_EMAIL.'$>');
+
   class setting_email extends setting_string {
-    var $_pattern = '#^\s*(([a-z0-9\-_.]+?)@([\w\-]+\.([\w\-\.]+\.)*[\w]+)(,\s*([a-z0-9\-_.]+?)@([\w\-]+\.([\w\-\.]+\.)*[\w]+))*)?\s*$#i';
+    var $_pattern = SETTING_EMAIL_PATTERN;       // no longer required, retained for backward compatibility - FIXME, may not be necessary
+    var $_multiple = false;
+
+    /**
+     *  update setting with user provided value $input
+     *  if value fails error check, save it
+     *
+     *  @return true if changed, false otherwise (incl. on error)
+     */
+    function update($input) {
+        if (is_null($input)) return false;
+        if ($this->is_protected()) return false;
+
+        $value = is_null($this->_local) ? $this->_default : $this->_local;
+        if ($value == $input) return false;
+
+        if ($this->_multiple) {
+            $mails = array_filter(array_map('trim', split(',', $input)));
+        } else {
+            $mails = array($input);
+        }
+
+        foreach ($mails as $mail) {
+            if (!mail_isvalid($mail)) {
+              $this->_error = true;
+              $this->_input = $input;
+              return false;
+            }
+        }
+
+        $this->_local = $input;
+        return true;
+    }
   }
 }
 
@@ -545,7 +597,7 @@ if (!class_exists('setting_richemail')) {
           $addr = $test;
         }
 
-        if ($this->_pattern && !preg_match($this->_pattern,$addr)) {
+        if ($test !== '' && !mail_isvalid($addr)) {
           $this->_error = true;
           $this->_input = $input;
           return false;
@@ -564,8 +616,25 @@ if (!class_exists('setting_numeric')) {
     // This allows for many PHP syntax errors...
     // var $_pattern = '/^[-+\/*0-9 ]*$/';
     // much more restrictive, but should eliminate syntax errors.
-    var $_pattern = '/^[-]?[0-9]+(?:[-+*][0-9]+)*$/';
-    //FIXME - make the numeric error checking better.
+    var $_pattern = '/^[-+]? *[0-9]+ *(?:[-+*] *[0-9]+ *)*$/';
+    var $_min = null;
+    var $_max = null;
+
+    function update($input) {
+        $local = $this->_local;
+        $valid = parent::update($input);
+        if ($valid && !(is_null($this->_min) && is_null($this->_max))) {
+            $numeric_local = (int) eval('return '.$this->_local.';');
+            if ((!is_null($this->_min) && $numeric_local < $this->_min) ||
+                (!is_null($this->_max) && $numeric_local > $this->_max)) {
+                $this->_error = true;
+                $this->_input = $input;
+                $this->_local = $local;
+                $valid = false;
+            }
+        }
+        return $valid;
+    }
 
     function out($var, $fmt='php') {
 
@@ -575,7 +644,8 @@ if (!class_exists('setting_numeric')) {
       $out = '';
 
       if ($fmt=='php') {
-        $out .=  '$'.$var."['".$this->_out_key()."'] = ".$this->_local.";\n";
+        $local = $this->_local === '' ? "''" : $this->_local;
+        $out .=  '$'.$var."['".$this->_out_key()."'] = ".$local.";\n";
       }
 
     return $out;
