@@ -6,6 +6,10 @@
  * @author Tomas Valenta <t.valenta@sh.cvut.cz>
  * @author Zbynek Krivka <zbynek.krivka@seznam.cz>
  * @author Bohumir Zamecnik <bohumir@zamecnik.org>
+ * @author tomas@valenta.cz
+ * @author Marek Sacha <sachamar@fel.cvut.cz>
+ * @author Lefty <lefty@multihost.cz>
+ * @author Vojta Beran <xmamut@email.cz>
  */
 $lang['menu']                  = 'Správa pluginů';
 $lang['download']              = 'Stáhnout a instalovat plugin';
@@ -23,7 +27,7 @@ $lang['source']                = 'Zdroj:';
 $lang['unknown']               = 'neznámý';
 $lang['updating']              = 'Aktualizuji ...';
 $lang['updated']               = 'Modul %s úspěšně aktualizován';
-$lang['updates']               = 'Následjící pluginy byly úspěšně aktualizovány';
+$lang['updates']               = 'Následující pluginy byly úspěšně aktualizovány';
 $lang['update_none']           = 'Žádné aktualizace nenalezeny.';
 $lang['deleting']              = 'Probíhá mazání ...';
 $lang['deleted']               = 'Plugin %s smazán.';
@@ -46,9 +50,10 @@ $lang['error_download']        = 'Nelze stáhnout soubor s pluginem: %s';
 $lang['error_badurl']          = 'URL je zřejmě chybná - nelze z ní určit název souboru';
 $lang['error_dircreate']       = 'Nelze vytvořit dočasný adresář ke stažení dat';
 $lang['error_decompress']      = 'Správce pluginů nemůže rozbalit stažený soubor. Toto může být způsobeno chybou při stahování. Můžete se pokusit stahování opakovat. Chyba může být také v kompresním formátu souboru. V tom případě bude nutné stáhnout a nainstalovat plugin ručně.';
-$lang['error_copy']            = 'Došlo k chybě při instalaci pluginu <em>%s</em>. Je možné, že na disku není volné místo, nebo mohou být špatně nastavena přístupová práva. Pozor, mohlo dojít k častečné a tudíž chybné instalaci pluginu a tím může být ohrožena stabilita wiki.';
+$lang['error_copy']            = 'Došlo k chybě při instalaci pluginu <em>%s</em>. Je možné, že na disku není volné místo, nebo mohou být špatně nastavena přístupová práva. Pozor, mohlo dojít k částečné a tudíž chybné instalaci pluginu a tím může být ohrožena stabilita wiki.';
 $lang['error_delete']          = 'Došlo k chybě při pokusu o smazání pluginu <em>%s</em>. Nejspíše je chyba v nastavení přístupových práv k některým souborům či adresářům.';
 $lang['enabled']               = 'Plugin %s aktivován.';
 $lang['notenabled']            = 'Plugin %s nelze aktivovat, zkontrolujte práva k souborům.';
 $lang['disabled']              = 'Plugin %s deaktivován.';
 $lang['notdisabled']           = 'Plugin %s nelze deaktivovat, zkontrolujte práva k souborům.';
+$lang['packageinstalled']      = 'Plugin package (%d plugin%s: %s) úspěšně nainstalován.';
