@@ -7,15 +7,15 @@
  *
  * @author Thanos Massias <tm@thriasio.gr>
  * @author Αθανάσιος Νταής <homunculus@wana.gr>
+ * @author Konstantinos Koryllos <koryllos@gmail.com>
+ * @author George Petsagourakis <petsagouris@gmail.com>
  */
 $lang['menu']                  = 'Αποκατάσταση κακόβουλων αλλαγών σελίδων';
 $lang['filter']                = 'Αναζήτηση σελίδων που περιέχουν spam';
 $lang['revert']                = 'Επαναφορά παλαιότερων εκδόσεων των επιλεγμένων σελίδων';
 $lang['reverted']              = 'Η σελίδα %s επεναφέρθηκε στην έκδοση %s';
 $lang['removed']               = 'Η σελίδα %s διαγράφηκε';
-$lang['revstart']              = 'Η διαδικασία αποκατάστασης άρχισε. Αυτό ίσως πάρει αρκετό χρόνο. 
-                         Εάν η εφαρμογή υπερβεί το διαθέσιμο χρονικό όριο και τερματιστεί 
-                         πριν τελειώσει, θα χρειαστεί να επαναλάβετε αυτή τη διαδικασία για μικρότερα τμήματα.';
+$lang['revstart']              = 'Η διαδικασία αποκατάστασης άρχισε. Αυτό ίσως πάρει αρκετό χρόνο. Εάν η εφαρμογή υπερβεί το διαθέσιμο χρονικό όριο και τερματιστεί πριν τελειώσει, θα χρειαστεί να επαναλάβετε αυτή τη διαδικασία για μικρότερα τμήματα.';
 $lang['revstop']               = 'Η διαδικασία αποκατάστασης ολοκληρώθηκε με επιτυχία.';
 $lang['note1']                 = '<br />Σημείωση: η αναζήτηση επηρεάζεται από το εάν οι χαρακτήρες είναι πεζοί ή κεφαλαίοι';
 $lang['note2']                 = '<br />Σημείωση: η σελίδα θα επαναφερθεί στην πλέον πρόσφατη έκδοση που δεν περιέχει τον όρο <i>%s</i>.';
