@@ -12,4 +12,4 @@ $lang['removed']               = '% dzēsts';
 $lang['revstart']              = 'Atjaunošana uzsākta. Tas var aizņemt ilgāku laiku. Ja darbība pārtrūkst noilguma dēļ, atjaunošana jāveic pa mazākām porcijām.';
 $lang['revstop']               = 'Atjaunošana veiksmīgi  pabeigta. ';
 $lang['note1']                 = 'Ievēro: Meklēšana atšķir lielos un mazos burtus.';
-$lang['note2']                 = 'Ievēro: LApu atjaunos ar pēdējo verisjau, kas nesatur uzdoto spama vārdu <i>%s</i>.';
+$lang['note2']                 = 'Ievēro: Lapu atjaunos ar pēdējo versiju, kas nesatur uzdoto spama vārdu <i>%s</i>.';
