@@ -4,7 +4,7 @@
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 
-index = {
+var index = {
 
      /**
      * Delay in ms before showing the throbber.
