@@ -10,6 +10,7 @@ function sack(file){
   this.URLString = "";
   this.encodeURIString = true;
   this.execute = false;
+  this.asynchronous = true;
 
   this.onLoading = function() { };
   this.onLoaded = function() { };
@@ -86,9 +87,9 @@ function sack(file){
         var self = this;
         if (this.method == "GET") {
           var totalurlstring = this.requestFile + "?" + this.URLString;
-          this.xmlhttp.open(this.method, totalurlstring, true);
+          this.xmlhttp.open(this.method, totalurlstring, this.asynchronous);
         } else {
-          this.xmlhttp.open(this.method, this.requestFile, true);
+          this.xmlhttp.open(this.method, this.requestFile, this.asynchronous);
         }
         if (this.method == "POST"){
           try {
